<?php

namespace App\Http\Controllers;

use App\Models\AccountGroup;
use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Validator;

class AccountGroupController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $groups = AccountGroup::where('account_type', 2)->get();
        $baseGroups = AccountGroup::where('parent_id', 0)->get();
        return view('admin.accountgroup.index', compact('groups', 'baseGroups'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request): RedirectResponse
    {
        $validator = Validator::make($request->all(), [
            'groupName' => 'required|unique:account_groups,name|max:255',
            'basegroup' => 'required|exists:account_groups,id',
        ],
        [
            'groupName.required' => 'Group name is required !',
            'groupName.unique' => 'Group name exist.',
            'groupName.max' => 'Group name should not be greater than 255 characters.',
            'basegroup.required' => 'Base Group is required !',
            'basegroup.exists' => 'Base group not exist.',
        ]);

        if($validator->fails())
        {
            return redirect()->route('accountGroup.index')->withErrors($validator)->withInput();
        }

        $account = new AccountGroup;
        $account->name = $request->groupName;
        $account->parent_id = $request->basegroup;
        $account->account_type = '2';
        $account->save();
        return redirect()->route('accountGroup.index')->with('success', 'Group Created.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\AccountGroup  $accountGroup
     * @return \Illuminate\Http\Response
     */
    public function show(AccountGroup $accountGroup)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\AccountGroup  $accountGroup
     * @return \Illuminate\Http\Response
     */
    public function edit(AccountGroup $accountGroup)
    {
        $baseGroups = AccountGroup::where('parent_id', 0)->get();
        return view('admin.accountgroup.edit', compact('accountGroup', 'baseGroups'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\AccountGroup  $accountGroup
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, AccountGroup $accountGroup): RedirectResponse
    {
        $validator = Validator::make($request->all(), [
            'groupName' => 'required|unique:account_groups,name,'.$accountGroup->id.'|max:255',
            'basegroup' => 'required|exists:account_groups,id',
        ],
        [
            'groupName.required' => 'Group name is required !',
            'groupName.unique' => 'Group name exist.',
            'groupName.max' => 'Group name should not be greater than 255 characters.',
            'basegroup.required' => 'Base Group is required !',
            'basegroup.exists' => 'Base group not exist.',
        ]);

        if($validator->fails())
        {
            return redirect()->route('accountGroup.index')->withErrors($validator)->withInput();
        }

        $accountGroup->name = $request->groupName;
        $accountGroup->parent_id = $request->basegroup;
        $accountGroup->save();
        return redirect()->route('accountGroup.index')->with('success', 'Group Updated.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\AccountGroup  $accountGroup
     * @return \Illuminate\Http\Response
     */
    public function destroy(AccountGroup $accountGroup)
    {
        $accountGroup->delete();
        return redirect()->route('accountGroup.index')->with('success','Group deleted successfully.');
    }
}
