<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests\Auth\LoginRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use App\Http\Requests\ChangePasswordRequest;
use App\Models\User;
use App\Models\ProductMaster;
use App\Models\Sale;
use App\Models\Purchase;
use App\Models\Transaction;
use App\Services\TransactionService;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;

class AdminController extends Controller
{
    public function index()
    {
        return view('admin.auth.login');
    }

    public function login(LoginRequest $request)
    {
        $request->authenticate();

        $request->session()->regenerate();

        return redirect()->intended(route('adminDashboard'));
    }

    public function logout(Request $request)
    {
        Auth::guard('web')->logout();

        $request->session()->invalidate();

        $request->session()->regenerateToken();
        return redirect()->intended(route('loginform'));
    }

    public function dashboard()
    {
        try
        {
            $currentYear = Carbon::now()->year;
            $currentMonth = Carbon::now()->month;
            $data = [];
            //$data['todaysBookingCount'] = Booking::whereDate('created_at', Carbon::today())->where('is_cancelled', 0)->where('is_completely_rescheduled', 0)->count(); // ->where('is_rescheduled', 0)
            // $data['totalsalerevenue'] = Sale::where('status', '1')->sum('grand_total');
            $data['totalsalerevenue'] = Sale::select(
                                            DB::raw('SUM(grand_total) as grand_total'),
                                            DB::raw('SUM(CASE WHEN MONTH(sale_date) = ' . $currentMonth . ' THEN grand_total ELSE 0 END) as current_month_sum'),
                                            DB::raw('SUM(CASE WHEN YEAR(sale_date) = ' . $currentYear . ' THEN grand_total ELSE 0 END) as current_year_sum')
                                        )->where('status', '1')->first();
            // $data['totalpurchaserevenue'] = Purchase::where('status', '1')->sum('grand_total');
            $data['totalpurchaserevenue'] = Purchase::select(
                                                DB::raw('SUM(grand_total) as grand_total'),
                                                DB::raw('SUM(CASE WHEN MONTH(purchase_date) = ' . $currentMonth . ' THEN grand_total ELSE 0 END) as current_month_sum'),
                                                DB::raw('SUM(CASE WHEN YEAR(purchase_date) = ' . $currentYear . ' THEN grand_total ELSE 0 END) as current_year_sum')
                                            )->where('status', '1')->first();
            $transactions = Transaction::with('branch', 'customer')->has('customer')->selectRaw('sum(credit_amount) as credit_amount, sum(debit_amount) as debit_amount, customer_id, branch_id')->groupBy('customer_id', 'branch_id')->get();
            $sumAmount = 0;
            foreach($transactions as $transaction)
            {
                $dueAmount = ($transaction->debit_amount - $transaction->credit_amount);
                if($dueAmount > 0)
                {
                    $sumAmount = $sumAmount + $dueAmount;
                }
            }
            $data['totalcreditamount'] = abs($sumAmount);

            $sumDebtAmount = 0;
            foreach($transactions as $transaction)
            {
                $dueAmount = ($transaction->credit_amount - $transaction->debit_amount);
                if($dueAmount > 0)
                {
                    $sumDebtAmount = $sumDebtAmount + $dueAmount;
                }
            }
            $data['totaldebtamount'] = abs($sumDebtAmount);

            $data['expenceAmount'] = 0;
            $fromDate = null;
            $toDate = null;
            $month = $currentMonth;
            $year = null;
            $group = 4;

            $transactionData = (new TransactionService())->getTransactionAmount($fromDate, $toDate, $month, $year, $group);
            if($transactionData->getData()->success)
            {
                $data['expenceAmount'] = abs($transactionData->getData()->data->totalDebit);
            }

            return view('admin.demo', compact('data',));
        }
        catch (\Exception $e)
        {
            return $this->handleError($e->getMessage(), '',$e->getCode());
        }
    }

    public function changePassword()
    {
        return view('admin.security.index');
    }

    public function changePasswordSave(ChangePasswordRequest $request)
    {
        if(!Hash::check($request->currentPassword, auth()->user()->password))
        {
            return back()->with("error", "Your current password does not matches with the password you provided. Please try again.");
        }

        if(strcmp($request->currentPassword, $request->newPassword) == 0)
        {
            //Current password and new password are same
            return redirect()->back()->with("error","New Password cannot be same as your current password. Please choose a different password.");
        }

        User::whereId(auth()->user()->id)->update([
            'password' => Hash::make($request->newPassword)
        ]);

        return back()->with('success', "Password Changed Successfully");
    }


    public function autoComplete(Request $request)
    {
        $draw = $request->get('draw');
        $start = $request->get("start");
        $rowperpage = $request->get("length"); // Rows display per page

        $columnIndex_arr = $request->get('order');
        $columnName_arr = $request->get('columns');
        $order_arr = $request->get('order');
        $search_arr = $request->get('search');

        $columnIndex = $columnIndex_arr[0]['column']; // Column index
        $columnName = $columnName_arr[$columnIndex]['data']; // Column name
        $columnSortOrder = $order_arr[0]['dir']; // asc or desc
        $searchValue = $search_arr['value']; // Search value

        // Total records
        $totalRecords = ProductMaster::WhereHas('stockqty', function ($q){
                $q->where('primary_qty', '<', 1);
            })->select('count(*) as allcount')->count();
        $totalRecordswithFilter = ProductMaster::WhereHas('stockqty', function ($q){
                $q->where('primary_qty', '<', 1);
            })->select('count(*) as allcount')->where('name', 'like', '%' .$searchValue . '%')->count();

        // Fetch records
        $records = ProductMaster::with('category', 'manufacturer', 'price', 'stockqty')
            ->WhereHas('stockqty', function ($q){
                $q->where('primary_qty', '<', 1);
            })
            ->where(function($query) use ($searchValue) {
                $query->where('product_masters.name', 'like', '%' .$searchValue . '%')->orwhere('product_masters.code', 'like', '%' .$searchValue . '%');
            })
            ->orderBy($columnName,$columnSortOrder)
            ->select('product_masters.*')->skip($start)->take($rowperpage)->get();

        $data_arr = array();

        $c=0;
        foreach($records as $record)
        {
            $c++;
            $id = $c;//$record->id;
            $code = $record->code;
            $name = $record->name;
            $hsncode = $record->hsncode;
            $closigstock= $record->stockqty->primary_qty;
            $category = $record->category->name;
            $manufacturer = $record->manufacturer->name;
            $price = $record->price->mrp;
            $sales_rate = $record->price->sales_rate;
            $landing=$record->price->cost;

            $buttons = "<a class='btn text-primary btn-sm viewbtn' href='".route('product.show', $record->id)."' data-bs-toggle='tooltip' data-bs-original-title='View'><span class='fe fe-eye fs-14'></span></a>";

            $data_arr[] = array("id" => $id, "code" => $code, "name" => $name, "hsncode" => $hsncode,"closigstock" => $closigstock, "category" => $category, "manufacturer" => $manufacturer, "price" => $price, "sales_rate" => $sales_rate, "landing" => $landing, "buttons" => $buttons);
        }

        $response = array(
           "draw" => intval($draw),
           "iTotalRecords" => $totalRecords,
           "iTotalDisplayRecords" => $totalRecordswithFilter,
           "aaData" => $data_arr
        );

        return response()->json($response);
    }
}
