<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Area;
use App\Http\Requests\StoreAreaPostRequest;
use App\Http\Requests\UpdateAreaRequest;
use App\Services\AreaService;

class AreaController extends Controller
{
    public function index()
    {
        $areas = Area::get();
        return view('admin.area.index', compact('areas'));
    }

    public function store(StoreAreaPostRequest $request, AreaService $areaService)
    {
        try
        {
            $arearesult = $areaService->store($request->validated());
            if($arearesult->getData()->success)
            {
                return redirect()->route('areaList')->with('success','Area created successfully');
            }
            else
            {
                return redirect()->route('areaList')->with('error',$arearesult->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('areaList')->with('error',$e->getMessage());
        }
    }

    public function edit($area)
    {
        $area = Area::find($area);
        return view('admin.area.edit', compact('area'));
    }

    public function update(UpdateAreaRequest $request, $id, AreaService $areaService)
    {
        try
        {
            $area = Area::find($id);
            $arearesult = $areaService->update($request->validated(), $area);
            if($arearesult->getData()->success)
            {
                return redirect()->route('areaList')->with('success','Area updated successfully');
            }
            else
            {
                return redirect()->route('areaList')->with('error',$arearesult->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('areaList')->with('error',$e->getMessage());
        }
    }

    public function destroy($id)
    {
        $area = Area::find($id);
        $area->delete();
        return redirect()->route('areaList')->with('success','Area deleted successfully');
    }
}
