<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CompanyProfile;
use App\Models\Sale;
use App\Models\SaleItem;
use App\Models\SaleClient;
use App\Models\SaleClientItems;
use Illuminate\Support\Facades\DB;

class BillProcessController extends Controller
{
    public function index()
    {
        $companys = CompanyProfile::where('status', 1)->get();
        return view('admin.adjust.index', compact('companys'));
    }

    public function billDetails(Request $request)
    {
        $from_date = $request->fromdate;
        //$to_date = $request->todate;
        $branch = $request->branch;
        $companys = CompanyProfile::where('status', 1)->get();
        if(Sale::where('branch_id', $branch)->where('correction_status', false)->whereDate('sale_date', $from_date)->exists())
        {
            $sales = SaleItem::whereHas('sale', function ($query) use ($request) {
                return $query->where('branch_id', $request->branch)->where('correction_status', false)->where('settled', true)->whereDate('sale_date', $request->fromdate);
            })->whereHas('product', function ($query) {
                return $query->where('item_class', '=', 4);
            })->selectRaw('product_master_id, SUM(quantity) as totalqty')->groupBy('product_master_id')->get();

            return view('admin.adjust.index', compact('sales', 'companys', 'from_date', 'branch'));
        }
        else
        {
            return redirect()->route('bill.process')->with('error', 'No data exist.');
        }
    }

    public function billAdjust(Request $request)
    {
        $from_date = base64_decode($request->frmdte);
        $branch = base64_decode($request->branch);
        $itemIds = array();
        foreach($request->totitem as $key => $itemsTotal)
        {
            $product = base64_decode($request->product[$key]);
            $cutper = (float) $request->cutper[$key];
            if($cutper > 0)
            {
                $totalitem = (float) base64_decode($itemsTotal);
                $percentage = round((($cutper * $totalitem) / 100));

                $sales = SaleItem::whereHas('sale', function ($query) use ($from_date, $branch) {
                    return $query->where('branch_id', $branch)->where('correction_status', false)->where('settled', true)->whereDate('sale_date', $from_date);
                })->whereHas('product', function ($query) {
                    return $query->where('item_class', '=', 4);
                })->where('product_master_id', $product)->get()->sortByDesc('quantity')->sortByDesc('product_master_id');

                //echo($percentage.'<br>');

                foreach($sales as $saleitem)
                {
                    /*****Change Here Start*****/
                    
                    if($saleitem->quantity > 1)
                    {
                        $reduceqty = ($saleitem->quantity - 1);
                        if($percentage >= $reduceqty)
                        {
                            $percentage = ($percentage - $reduceqty);
                        }
                        else if($percentage <= $reduceqty && $percentage > 0)
                        {
                            $reduceqty = $percentage;
                            $percentage = $percentage - $reduceqty;
                        }
                        else
                        {
                            $reduceqty=$percentage;
                            $percentage = 0 ;
                        }
                        $saleitem->quantity = ($saleitem->quantity - $reduceqty);
                        $saleitem->save();
                        $itemIds[] = $saleitem->id;
                        $this->reCalculatePrice($saleitem->id, $saleitem->product_master_id);
                    }
                    else
                    {
                        if($percentage != 0)
                        {
                            $count = SaleItem::where('sales_id', $saleitem->sales_id)->count();
                            if($count > 1)
                            {
                                $saleitem->delete();
                                $percentage = $percentage - 1;
                            }
                        }
                        
                    }
                    //echo('Prd:'.$saleitem->product_master_id.' - '.$saleitem->quantity.' - '.$reduceqty.' - '.$percentage.'<br>');

                    /*****Change Here End*****/
                }
            }
        }
        $this->reCalculateTotal($itemIds);
        return redirect()->route('bill.process')->with('success', 'Record Updated.');
    }

    public function reCalculatePrice($riwId, $productId)
    {
        $saleItems = SaleItem::with('sale')->find($riwId);
        $grossamt = ($saleItems->quantity * $saleItems->unit_price);
        $discountamount = (($grossamt * $saleItems->discount_percentage) / 100);
        $taxableamount = $grossamt - $discountamount;
        $commonTax = (($taxableamount * $saleItems->sale->total_discount_percentage) / 100);
        $commonTaxamt = ($taxableamount - $commonTax);
        $taxvalue = (($commonTaxamt * $saleItems->cgst) / 100);
        $saleItems->gross_amount = $grossamt;
        $saleItems->discount_amount = $discountamount;
        $saleItems->taxable_amount = $taxableamount;
        $saleItems->cgst_amount = ($taxvalue / 2);
        $saleItems->sgst_amount = ($taxvalue / 2);
        $saleItems->item_total = ($taxableamount + $taxvalue);
        $saleItems->save();
    }

    public function reCalculateTotal($itemids)
    {
        $sales = Sale::with('saleDetails')->whereHas('saleDetails', function ($query) use ($itemids) {
                    return $query->whereIntegerInRaw('id', $itemids);
                })->where('correction_status', false)->where('settled', true)->get();
        //dd($sale);
        foreach($sales as $sale)
        {
            $grossTotal = 0; $discountAmountTotal = 0; $taxableAmountTotal = 0; $totalTaxAmount = 0; $cgstAmount = 0; $sgstAmount = 0; $netValueAmount = 0;

            //$saleItemLists = SaleItem::with('sale')->where('sales_id', $saleItems->sales_id)->get();
            foreach($sale->saleDetails as $saleItemList)
            {
                $grossTotal = $grossTotal + $saleItemList->gross_amount;
                $discountAmountTotal = $discountAmountTotal + $saleItemList->discount_amount;
                $taxableAmountTotal = $taxableAmountTotal + $saleItemList->taxable_amount;
                $taxamt = $saleItemList->cgst_amount + $saleItemList->sgst_amount;
                $totalTaxAmount = $totalTaxAmount + $taxamt;
                $cgstAmount = $cgstAmount + $saleItemList->cgst_amount;
                $sgstAmount = $sgstAmount + $saleItemList->sgst_amount;
                $netValueAmount = $netValueAmount + $saleItemList->item_total;
            }

            $cessAmount = $sale->cess;
            $addCessAmount = $sale->add_cess;

            $totalDiscountAmount = (($taxableAmountTotal * $sale->total_discount_percentage) / 100);
            $taxableAmountVal = $taxableAmountTotal - $totalDiscountAmount;
            $cessAmountValue = (($taxableAmountVal * $cessAmount) / 100);
            $addcessAmountValue = (($taxableAmountVal * $addCessAmount) / 100);
            $netvalueTotal = $netValueAmount + $cessAmountValue + $addcessAmountValue + $sale->freight_coolie + $sale->otherexp + $sale->cost_factor;
            $billTotal = $netvalueTotal - $sale->cash_discount;

            $sale->total_amount = $grossTotal;
            $sale->total_cgst_amount = $cgstAmount;
            $sale->total_sgst_amount = $sgstAmount;
            $sale->total_tax_amount = $totalTaxAmount;
            $sale->total_taxable_amt = $taxableAmountVal;
            $sale->total_discount_amount = $totalDiscountAmount;
            $sale->total_item_discount = $discountAmountTotal;
            $sale->sales_total = $taxableAmountVal;
            $sale->netvalue = $netvalueTotal;
            $sale->grand_total = $billTotal;
            $sale->correction_status = true;
            $sale->save();
        }
    }
}
