<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CompanyProfile;
use App\Http\Requests\Company\StoreCompanyRequest;
use App\Http\Requests\Company\UpdateCompanyRequest;
use App\Services\CompanyService;

class CompanyController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $companys = CompanyProfile::get();
        return view('admin.company.index', compact('companys'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreCompanyRequest $request, CompanyService $companyservice)
    {
        try
        {
            $resultres = $companyservice->store($request->only(['code', 'com_type', 'name', 'address', 'printing_address', 'print_subHead', 'print_footerText', 'print_footerSubText', 'city', 'country', 'state', 'phoneno', 'pincode', 'emailid', 'gstuin', 'fssai_code', 'financialyearstart', 'financialyearend', 'bank_details']));
            if($resultres->getData()->success)
            {
                return redirect()->route('company.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('company.index')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('company.index')->with('error',$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(CompanyProfile $company)
    {
        return response()->json($company);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(CompanyProfile $company)
    {
        return view('admin.company.edit', compact('company'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateCompanyRequest $request, CompanyProfile $company, CompanyService $companyservice)
    {
        try
        {
            $resultres = $companyservice->update($request->only(['code', 'name', 'address', 'printing_address', 'print_subHead', 'print_footerText', 'print_footerSubText', 'city', 'country', 'state', 'phoneno', 'pincode', 'emailid', 'gstuin', 'fssai_code', 'financialyearstart', 'financialyearend', 'bank_details']), $company);
            if($resultres->getData()->success)
            {
                return redirect()->route('company.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('company.index')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('company.index')->with('error',$e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(CompanyProfile $company)
    {
        $company->delete();
        return redirect()->route('company.index')->with('success','Company deleted successfully');
    }
}
