<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CustomerMaster;
use App\Http\Requests\Customer\StoreCustomerRequest;
use App\Http\Requests\Customer\UpdateCustomerRequest;
use App\Services\CustomerService;

class CustomerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $customers = CustomerMaster::where('supplierstatus', false)->get();
        return view('admin.customer.index', compact('customers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.customer.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreCustomerRequest $request, CustomerService $customerservice)
    {
        try
        {
            $resultres = $customerservice->store($request->only(['code', 'regional', 'name', 'emailid', 'mobile_no', 'phone', 'address', 'remarks', 'state_pos', 'area', 'gst_no', 'creditLimit', 'discount', 'active_status']));
            if($resultres->getData()->success)
            {
                return redirect()->route('customer.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('customer.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('customer.create')->with('error',$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(CustomerMaster $customer)
    {
        return view('admin.customer.view', compact('customer'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(CustomerMaster $customer)
    {
        return view('admin.customer.edit', compact('customer'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateCustomerRequest $request, CustomerMaster $customer, CustomerService $customerservice)
    {
        try
        {
            $resultres = $customerservice->update($request->only(['code', 'regional', 'name', 'emailid', 'mobile_no', 'phone', 'address', 'remarks', 'state_pos', 'area', 'gst_no', 'creditLimit', 'discount', 'active_status']), $customer);
            if($resultres->getData()->success)
            {
                return redirect()->route('customer.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('customer.edit')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('customer.edit')->with('error',$e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(CustomerMaster $customer)
    {
        $customer->delete();
        return redirect()->route('customer.index')->with('success','Customer deleted successfully');
    }

    public function customerSearch(Request $request)
    {
        $customer = [];
        if($request->has('q')){
            $search = $request->q;
            $customer = CustomerMaster::select("id", "name")
            ->where(function($query_titles) use ($search){
                $query_titles->where('name', 'like', '%'.$search.'%');
            })->get(); // ->where('supplierstatus', false)
        }
        return response()->json($customer);
    }

    public function customerDetails(Request $request)
    {
        $customer = CustomerMaster::select(["name", "address", "mobile"])->find($request->customer_id); // ->where('supplierstatus', false)
        return response()->json($customer);
    }
}
