<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\DriverMaster;
use App\Models\Vendor;
use Illuminate\Support\Facades\Auth;

class DriverController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $drivers = DriverMaster::get();
        return view('admin.driver.index', compact('drivers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.driver.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try
        {
            //$unserializeData = [];
            //parse_str($request->formsdata, $unserializeData);

            $validatedData = $request->validate([
              'name' => 'required',
              'mobile_no' => 'required|unique:driver_masters,mobile|max:255',
              // 'vendor_id' => 'required'
            ]);

            $save = new DriverMaster;
            $save->name = $request->name;
            $save->address = $request->address;
            $save->mobile = $request->mobile_no;
            // $save->vendor_id = $request->vendor_id;
            $save->status = (isset($request->active_status) && $request->active_status == 1)? true : false;
            $save->created_by = Auth::id();
            $save ->save();
            return response()->json(['success' => true, 'message' => 'Driver Created Successfully!'], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(DriverMaster $driver)
    {
        return view('admin.driver.view', compact('driver'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(DriverMaster $driver)
    {
        $vendors = Vendor::get();
        return view('admin.driver.edit', compact('driver', 'vendors'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, DriverMaster $driver)
    {
        try
        {
            $driver->name = $request->name;
            $driver->address = $request->address;
            $driver->mobile = $request->mobile_no;
            // $driver->vendor_id = $request->vendor_id;
            $driver->status = (isset($request->active_status) && $request->active_status == 1)? true : false;
            $driver ->save();
            return redirect()->route('driver.index')->with('success','Driver updated successfully');
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return redirect()->route('admin.driver.edit', $driver)->with('error', $errormessage);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(DriverMaster $driver)
    {
        $driver->delete();
        return redirect()->route('driver.index')->with('success','Driver deleted successfully');
    }
}
