<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\EmployeeMaster;
use App\Models\CompanyProfile;
use Spatie\Permission\Models\Role;
use App\Http\Requests\Employee\StoreEmployeeRequest;
use App\Http\Requests\Employee\UpdateEmployeeRequest;
use App\Services\EmployeeService;

class EmployeeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $employees = EmployeeMaster::get();
        return view('admin.employee.index', compact('employees'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $companys = CompanyProfile::where('status', '1')->get();
        $roles = Role::whereNotIn('name', ['Super Admin'])->get();
        return view('admin.employee.create', compact('roles', 'companys'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreEmployeeRequest $request, EmployeeService $employeeservice)
    {
        try
        {
            $resultres = $employeeservice->store($request->only(['code', 'name', 'emailid', 'mobile_no', 'gender', 'blood_group', 'address', 'userrole', 'usercompany', 'workstart_time', 'workend_time', 'commission', 'salary', 'active_status']));
            if($resultres->getData()->success)
            {
                return redirect()->route('employee.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('employee.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('employee.create')->with('error',$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(EmployeeMaster $employee)
    {
        return view('admin.employee.view', compact('employee'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(EmployeeMaster $employee)
    {
        $roles = Role::whereNotIn('name', ['Super Admin'])->get();
        return view('admin.employee.edit', compact('employee', 'roles'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateEmployeeRequest $request, EmployeeMaster $employee, EmployeeService $employeeservice)
    {
        try
        {
            $resultres = $employeeservice->update($request->only(['code', 'name', 'emailid', 'mobile_no', 'gender', 'blood_group', 'address', 'userrole', 'usercompany', 'workstart_time', 'workend_time', 'commission', 'salary', 'active_status']), $employee);
            if($resultres->getData()->success)
            {
                return redirect()->route('employee.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('employee.edit')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('employee.edit')->with('error',$e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(EmployeeMaster $employee)
    {
        $employee->delete();
        $employee->user->delete();
        return redirect()->route('employee.index')->with('success','Employee deleted successfully');
    }
}
