<?php

namespace App\Http\Controllers;

use App\Models\Ledger;
use App\Models\AccountGroup;
use App\Models\CompanyProfile;
use App\Models\Transaction;
use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Validator;

class LedgerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $groups = Ledger::latest()->get();
        $baseGroups = AccountGroup::where('status', true)->get();
        return view('admin.ledger.index', compact('groups', 'baseGroups'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request): RedirectResponse
    {
        $validator = Validator::make($request->all(), [
            'accountCode' => 'required|unique:ledgers,name|max:255',
            'ledgerName' => 'required|unique:ledgers,name|max:255',
            'accountGroup' => 'required|exists:account_groups,id',
        ],
        [
            'accountCode.required' => 'Account Code is required !',
            'accountCode.unique' => 'Account Code exist.',
            'accountCode.max' => 'Account Code should not be greater than 255 characters.',
            'ledgerName.required' => 'Ledger name is required !',
            'ledgerName.unique' => 'Ledger name exist.',
            'ledgerName.max' => 'Ledger name should not be greater than 255 characters.',
            'accountGroup.required' => 'Account Group is required !',
            'accountGroup.exists' => 'Account Group not exist.',
        ]);

        if($validator->fails())
        {
            return redirect()->route('ledger.index')->withErrors($validator)->withInput();
        }

        try
        {
            $account = new Ledger;
            $account->code = $request->accountCode;
            $account->name = $request->ledgerName;
            $account->account_group_id = $request->accountGroup;
            $account->description = $request->ledgerDescription;
            $account->inbuilt = 0;
            $account->save();
            return redirect()->route('ledger.index')->with('success', 'Ledger Created.');
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return redirect()->route('ledger.index')->with('error', $errormessage);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Ledger  $ledger
     * @return \Illuminate\Http\Response
     */
    public function show(Ledger $ledger)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Ledger  $ledger
     * @return \Illuminate\Http\Response
     */
    public function edit(Ledger $ledger)
    {
        $baseGroups = AccountGroup::where('status', true)->get();
        return view('admin.ledger.edit', compact('ledger', 'baseGroups'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Ledger  $ledger
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Ledger $ledger): RedirectResponse
    {
        $validator = Validator::make($request->all(), [
            'accountCode' => 'required|unique:ledgers,name,'.$ledger->id.'|max:255',
            'ledgerName' => 'required|unique:ledgers,name,'.$ledger->id.'|max:255',
            'accountGroup' => 'required|exists:account_groups,id',
        ],
        [
            'accountCode.required' => 'Account Code is required !',
            'accountCode.unique' => 'Account Code exist.',
            'accountCode.max' => 'Account Code should not be greater than 255 characters.',
            'ledgerName.required' => 'Ledger name is required !',
            'ledgerName.unique' => 'Ledger name exist.',
            'ledgerName.max' => 'Ledger name should not be greater than 255 characters.',
            'accountGroup.required' => 'Account Group is required !',
            'accountGroup.exists' => 'Account Group not exist.',
        ]);

        if($validator->fails())
        {
            return redirect()->route('ledger.index')->withErrors($validator)->withInput();
        }

        try
        {
            $ledger->code = $request->accountCode;
            $ledger->name = $request->ledgerName;
            $ledger->account_group_id = $request->accountGroup;
            $ledger->description = $request->ledgerDescription;
            $ledger->inbuilt = 0;
            $ledger->save();
            return redirect()->route('ledger.index')->with('success', 'Ledger Updated.');
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return redirect()->route('ledger.index')->with('error', $errormessage);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Ledger  $ledger
     * @return \Illuminate\Http\Response
     */
    public function destroy(Ledger $ledger)
    {
        $ledger->delete();
        return redirect()->route('ledger.index')->with('success','Ledger deleted successfully.');
    }

    public function getLedger($id)
    {
        $ledger_id = $id;
        $companys = CompanyProfile::where('status', 1)->where('id', 1)->first();
        $transactionList = Transaction::with('customer', 'ledger', 'branch')->where('ledger_id', $ledger_id)->get()->toArray();
        if(!empty($transactionList))
        {
            $pagedata['companys'] = $companys;
            $pagedata['dates'] = 'From Begining';
            $invoice = $transactionList;
            return view('admin.report.transaction.transactionList', compact('pagedata', 'invoice'));
        }
        else
        {
            return redirect()->back()->with('error', 'No record found.');   
        }
    }
}
