<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Manufacturer;
use App\Http\Requests\StoreManufacturerRequest;
use App\Http\Requests\UpdateManufacturerRequest;
use App\Services\ManufacturerService;

class ManufacturerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $manufacturer = Manufacturer::get();
        return view('admin.manufacturer.index', compact('manufacturer'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreManufacturerRequest $request, ManufacturerService $manufacturerservice)
    {
        try
        {
            $resultres = $manufacturerservice->store($request->validated());
            if($resultres->getData()->success)
            {
                return redirect()->route('manufacturer.index')->with('success','Manufacturer created successfully');
            }
            else
            {
                return redirect()->route('manufacturer.index')->with('error',$resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('manufacturer.index')->with('error',$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Manufacturer $manufacturer)
    {
        return view('admin.manufacturer.edit', compact('manufacturer'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateManufacturerRequest $request, Manufacturer $manufacturer, ManufacturerService $manufacturerservice)
    {
        
        try
        {
            $resultres = $manufacturerservice->update($request->validated(), $manufacturer);
            if($resultres->getData()->success)
            {
                return redirect()->route('manufacturer.index')->with('success','Area updated successfully');
            }
            else
            {
                return redirect()->route('manufacturer.index')->with('error',$resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('manufacturer.index')->with('error',$e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Manufacturer $manufacturer)
    {
        $manufacturer->delete();
        return redirect()->route('manufacturer.index')->with('success','Manufacturer deleted successfully');
    }
}
