<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\ProductMaster;
use App\Http\Requests\Product\StoreProductRequest;
use App\Http\Requests\Product\UpdateProductRequest;
use App\Services\ProductService;
use App\Models\Category;
use App\Models\CompanyProfile;

class ProductController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $products = ProductMaster::get();
        return view('admin.product.index', compact('products'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.product.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, ProductService $productservice)
    {
        try
        {
            $resultres = $productservice->store($request->only(['code', 'barcode', 'name', 'regionalname', 'hsn_code', 'category', 'manufacturer', 'rol', 'rack', 'openstock', 'gstval', 'igstval', 'sale_incl', 'purchase_incl', 'cessval', 'addcessval', 'purchase_rate', 'sale_rate', 'mrpval', 'unitval', 'alter_unit', 'ucfactor', 'item_class', 'spcom', 'expiry_item', 'active_status', 'remarks', 'remarks_one', 'remarks_two']));
            if($resultres->getData()->success)
            {
                return redirect()->route('product.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('product.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('product.create')->with('error',$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(ProductMaster $product)
    {
        $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
        if(!empty($companys[0]['print_address']))
        {
            $companyTitle = $companys[0]['print_address'];
        }
        else
        {
            $companyTitle = $companys[0]['name'];
        }

        return view('admin.product.view', compact('product', 'companyTitle'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(ProductMaster $product)
    {
        return view('admin.product.edit', compact('product'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, ProductMaster $product, ProductService $productservice)
    {
        try
        {
            $resultres = $productservice->update($request->only(['code', 'barcode', 'name', 'regionalname', 'hsn_code', 'category', 'manufacturer', 'rol', 'rack', 'gstval', 'igstval', 'sale_incl', 'purchase_incl', 'cessval', 'addcessval', 'purchase_rate', 'sale_rate', 'mrpval', 'costval', 'unitval', 'alter_unit', 'ucfactor', 'item_class', 'spcom', 'expiry_item', 'active_status', 'remarks', 'remarks_one', 'remarks_two']), $product);
            if($resultres->getData()->success)
            {
                return redirect()->route('product.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('product.edit', $product)->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('product.edit', $product)->with('error',$e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(ProductMaster $product)
    {
        $product->delete();
        $product->tax->delete();
        $product->price->delete();
        $product->unit->delete();
        return redirect()->route('product.index')->with('success','Product deleted successfully');
    }

    public function autoComplete(Request $request)
    {
        $draw = $request->get('draw');
        $start = $request->get("start");
        $rowperpage = $request->get("length"); // Rows display per page

        $columnIndex_arr = $request->get('order');
        $columnName_arr = $request->get('columns');
        $order_arr = $request->get('order');
        $search_arr = $request->get('search');

        $columnIndex = $columnIndex_arr[0]['column']; // Column index
        $columnName = $columnName_arr[$columnIndex]['data']; // Column name
        $columnSortOrder = $order_arr[0]['dir']; // asc or desc
        $searchValue = $search_arr['value']; // Search value

        // Total records
        $totalRecords = ProductMaster::select('count(*) as allcount')->count();
        $totalRecordswithFilter = ProductMaster::select('count(*) as allcount')->where('name', 'like', '%' .$searchValue . '%')->count();

        // Fetch records
        $records = ProductMaster::with('category', 'manufacturer', 'price')->orderBy($columnName,$columnSortOrder)->where('product_masters.name', 'like', '%' .$searchValue . '%')->orwhere('product_masters.code', 'like', '%' .$searchValue . '%')->select('product_masters.*')->skip($start)->take($rowperpage)->get();

        $data_arr = array();

        $c=0;
        foreach($records as $record)
        {
            $c++;
            $id = $c;//$record->id;
            $code = $record->code;
            $name = $record->name;
            $hsncode = $record->hsncode;
            $closigstock= $record->stockqty->primary_qty;
            $category = $record->category->name;
            $manufacturer = $record->manufacturer->name;
            $price = $record->price->mrp;
            $sales_rate = $record->price->sales_rate;
            $landing=$record->price->cost;

            $buttons = "<a class='btn text-primary btn-sm' href='".route('product.edit', $record->id)."' data-bs-toggle='tooltip' data-bs-original-title='Edit'><span class='fe fe-edit fs-14'></span></a><a class='btn text-primary btn-sm viewbtn' href='".route('product.show', $record->id)."' data-bs-toggle='tooltip' data-bs-original-title='View'><span class='fe fe-eye fs-14'></span></a><form action='".route('product.destroy', $record->id)."' method='POST' onsubmit='return confirm('Are you sure?');' class='d-inline-block'> ".csrf_field()." ".method_field('DELETE')." <button class='btn btn-sm text-danger' type='submit' data-bs-toggle='tooltip' data-bs-original-title='Delete'><span class='fe fe-trash-2 fs-14'></span></button></form>";

            $data_arr[] = array("id" => $id, "code" => $code, "name" => $name, "hsncode" => $hsncode,"closigstock" => $closigstock, "category" => $category, "manufacturer" => $manufacturer, "price" => $price, "sales_rate" => $sales_rate, "landing" => $landing, "buttons" => $buttons);
        }

        $response = array(
           "draw" => intval($draw),
           "iTotalRecords" => $totalRecords,
           "iTotalDisplayRecords" => $totalRecordswithFilter,
           "aaData" => $data_arr
        );

        return response()->json($response);
    }

    public function priceList()
    {
        $categories = Category::where('status', 1)->get();
        return view('admin.product.priceList', compact('categories'));
    }

    public function categoryProductList(Request $request)
    {
        $category = $request->cat_id;
        if($category == 'All')
        {
            $products = ProductMaster::with('price', 'tax')->where('status', 0)->get();
        }
        else
        {
            $products = ProductMaster::with('price', 'tax')->where('catagory_id', $category)->where('status', 0)->get();
        }
        if(!empty($products))
        {
            return response()->json(['success' => true, 'products' => $products], 200);
        }
        else
        {
            return response()->json(['success' => false, 'message' => 'No Products.'], 401);
        }
    }

    public function priceListUpdate(Request $request)
    {
        try
        {
            foreach($request->prdid as $key => $productid)
            {
                $product = ProductMaster::with('price', 'tax')->find($productid);
                if($product)
                {
                    $product->price->price1 = $request->price1[$key];
                    $product->price->price2 = $request->price2[$key];
                    $product->price->price3 = $request->price3[$key];
                    $product->price->margin = $request->margin[$key];
                    $product->push();
                }
            }
            return redirect()->route('product.price.list')->with('success', 'Price Updated');
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return redirect()->route('product.price.list')->with('error', $errormessage);
        }
    }

    public function priceListUpdateItem(Request $request)
    {
        $productid = $request->productid;
        try
        {
            $product = ProductMaster::with('price', 'tax')->find($productid);
            if($product)
            {
                $product->price->price1 = $request->pricelist1;
                $product->price->price2 = $request->pricelist2;
                $product->price->price3 = $request->pricelist3;
                $product->price->margin = $request->margin;
                $product->push();
            }
            return response()->json(['success' => true, 'message' => 'Price Updated'], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 200);
        }
    }

    public function productSearch(Request $request)
    {
        $product = [];
        if($request->has('q'))
        {
            $search = $request->q;
            $product = ProductMaster::select("id", "name")
            ->where(function($query_titles) use ($search){
                $query_titles->where('name', 'like', '%'.$search.'%');
            })->get();
        }
        else
        {
            $product = ProductMaster::orderby('name','asc')->select('id','name')->limit(5)->get();
        }
        return response()->json($product);
    }
}
