<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\ProductMaster;
use App\Services\ProductService;
use App\Models\BillOfMaterial;
use App\Models\BillOfMaterialItem;
use App\Models\Stock;
use App\Models\Production;
use Illuminate\Support\Facades\Auth;

class ProductionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $materials = BillOfMaterial::get();
        return view('admin.production.index', compact('materials'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $products = ProductMaster::where('item_class', 4)->get();
        return view('admin.production.create', compact('products'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $product = $request->product;
        $material = $request->material;
        $quantity = $request->quantity;

        if(BillOfMaterial::where('product_master_id', $product)->exists())
        {
            $bom = BillOfMaterial::where('product_master_id', $product)->first();
        }
        else
        {
            $bom = BillOfMaterial::create(['product_master_id' => $product]);
        }

        $bomItem = BillOfMaterialItem::create(['material_id' => $bom->id, 'product_master_id' => $material, 'quantity' => $quantity]);
        $data['bomitems'] = BillOfMaterialItem::with('product')->where('material_id', $bom->id)->get();
        return response()->json($data);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(BillOfMaterial $production)
    {
        return view('admin.production.show', compact('production'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function autoCompleteSearchBOM(Request $request, ProductService $productservice)
    {
        $filterResult = $productservice->productSearchBOM($request);
        return $filterResult;
    }

    public function bomItemDelete(Request $request)
    {
        $idval = $request->idval;
        $bomItem = BillOfMaterialItem::find($idval);
        if($bomItem)
        {
            $bomItem->delete();
        }
        return response()->json(['success' => true, 'message' => 'Deleted Successfully!'], 200);
    }

    public function bomLists(Request $request)
    {
        $product = $request->prd_id;
        $bom = BillOfMaterial::with('bomItems', 'bomItems.product')->where('product_master_id', $product)->latest()->first();
        return response()->json($bom);
    }

    public function productionList()
    {
        $production = Production::get();
        return view('admin.production.productionList', compact('production'));
    }

    public function productionCreate()
    {
        $products = ProductMaster::where('item_class', 4)->get();
        return view('admin.production.productionAdd', compact('products')); // , compact('products')
    }

    public function productionItemStore(Request $request)
    {
        if(ProductMaster::where('id', $request->product)->exists())
        {
            $quantity = $request->quantity;
            $product = ProductMaster::with('billMaterial')->find($request->product);
            if($product->billMaterial()->exists())
            {
                foreach($product->billMaterial->bomItems as $material)
                {
                    $reqquantity = $quantity * $material->quantity;
                    if(Stock::where('product_master_id', $material->product_master_id)->exists())
                    {
                        $mainstock = Stock::where('product_master_id', $material->product_master_id)->first();
                        $mainstock->primary_qty = ($mainstock->primary_qty - $reqquantity);
                        $mainstock->secondary_qty = ($mainstock->secondary_qty - 0);
                        $mainstock->measure_finder = $mainstock->measure_finder;
                        $mainstock->save();
                    }
                    else
                    {
                        $mainstock = new Stock;
                        $mainstock->product_master_id = $material->product_master_id;
                        $mainstock->primary_qty = (-1 * abs($reqquantity));
                        $mainstock->secondary_qty = 0;
                        $mainstock->measure_finder = 0;
                        $mainstock->save();
                    }
                }

                if(Stock::where('product_master_id', $product->id)->exists())
                {
                    $mainstock = Stock::where('product_master_id', $product->id)->first();
                    $mainstock->primary_qty = ($mainstock->primary_qty + $quantity);
                    $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                    $mainstock->measure_finder = $mainstock->measure_finder;
                    $mainstock->save();
                }
                else
                {
                    $mainstock = new Stock;
                    $mainstock->product_master_id = $product->id;
                    $mainstock->primary_qty = $quantity;
                    $mainstock->secondary_qty = 0;
                    $mainstock->measure_finder = 0;
                    $mainstock->save();
                }

                $production = Production::create(['product_master_id' => $product->id, 'quantity' => $quantity, 'created_by' => Auth::id()]);
                return redirect()->route('product.production.create')->with('success', 'Production added.');
            }
            else
            {
                return redirect()->route('product.production.create')->with('error', 'BOM not added.');
            }
        }
        else
        {
            return redirect()->route('product.production.create')->with('error', 'Product not exist.');
        }
    }
}
