<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\ProductMaster;
use App\Models\Vendor;
use App\Models\CustomerMaster;
use App\Models\CompanyProfile;
use App\Models\EmployeeMaster;
use App\Models\Purchase;
use App\Services\ProductService;
use App\Services\PurchaseService;
use App\Models\PurchaseReturn;
use Illuminate\Support\Facades\Auth;

class PurchaseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $purchases = Purchase::where('status', 1)->when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->get();
        return view('admin.purchase.index', compact('purchases'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vendors = CustomerMaster::where('supplierstatus', true)->where('activestatus', true)->get(); // Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.purchase.create', compact('vendors', 'companys', 'employees'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, PurchaseService $purchaseService)
    {
        try
        {
            $resultres = $purchaseService->store($request->all());
            if($resultres->getData()->success)
            {
                return redirect()->route('purchase.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('purchase.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('purchase.create')->with('error',$e->getMessage());
        }
    }

    public function approvePurchase(Request $request, PurchaseService $purchaseService)
    {
        try
        {
            $resultres = $purchaseService->approveData($request->only(['refval']));
            if($resultres->getData()->success)
            {
                return redirect()->route('purchase.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('purchase.index')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('purchase.index')->with('error',$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Purchase $purchase)
    {
        $vendors = CustomerMaster::where('supplierstatus', true)->where('activestatus', true)->get(); // Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $employees = EmployeeMaster::where('activestatus', true)->get();
        return view('admin.purchase.show', compact('purchase', 'vendors', 'companys', 'employees'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Purchase $purchase)
    {
        $vendors = CustomerMaster::where('supplierstatus', true)->where('activestatus', true)->get(); // Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.purchase.edit', compact('purchase', 'vendors', 'companys', 'employees'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Purchase $purchase, PurchaseService $purchaseService)
    {
        try
        {
            $resultres = $purchaseService->update($request->all(), $purchase);
            if($resultres->getData()->success)
            {
                return redirect()->route('purchase.index')->with('success','Purchase updated successfully');
            }
            else
            {
                return redirect()->route('purchase.index')->with('error',$resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('purchase.index')->with('error',$e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function itemDelete(Request $request, PurchaseService $purchaseService)
    {
        try
        {
            $resultres = $purchaseService->purchaseItemDelete($request->all());
            if($resultres->getData()->success)
            {
                return response()->json(['success' => true, 'message' => $resultres->getData()->message], 200);
            }
            else
            {
                return response()->json(['success' => false, 'message' => $resultres->getData()->message], 200);
            }
        }
        catch (\Exception $e)
        {
            return response()->json(['success' => false, 'message' => $e->getMessage()], 200);
        }
    }

    public function autoCompleteSearch(Request $request, ProductService $productservice)
    {
        $filterResult = $productservice->productSearch($request);
        return $filterResult;
    }

    public function returnIndex()
    {
        $purchases = PurchaseReturn::where('status', 1)->when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->latest()->get();
        return view('admin.purchase.returnIndex', compact('purchases'));
    }

    public function returnCreate()
    {
        $vendors = CustomerMaster::where('supplierstatus', true)->where('activestatus', true)->get(); // Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.purchase.returnCreate', compact('vendors', 'companys', 'employees'));
    }

    public function returnStore(Request $request, PurchaseService $purchaseService)
    {
        try
        {
            $resultres = $purchaseService->returnStore($request->all());
            if($resultres->getData()->success)
            {
                return redirect()->route('purchase.return.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('purchase.return.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('purchase.return.create')->with('error',$e->getMessage());
        }
    }

    public function returnShow(PurchaseReturn $purchaseReturn)
    {
        $purchase = $purchaseReturn;
        $vendors = CustomerMaster::where('supplierstatus', true)->where('activestatus', true)->get(); // Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $employees = EmployeeMaster::where('activestatus', true)->get();
        return view('admin.purchase.returnShow', compact('purchase', 'vendors', 'companys', 'employees'));
    }

    public function returnEdit(PurchaseReturn $purchaseReturn)
    {
        $vendors = CustomerMaster::where('supplierstatus', true)->where('activestatus', true)->get(); // Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        $purchase = $purchaseReturn;
        return view('admin.purchase.returnEdit', compact('purchase', 'vendors', 'companys', 'employees'));
    }

    public function returnUpdate(Request $request, PurchaseReturn $purchaseReturn, PurchaseService $purchaseService)
    {
        try
        {
            $resultres = $purchaseService->returnUpdate($request->all(), $purchaseReturn);
            if($resultres->getData()->success)
            {
                return redirect()->route('purchase.return.index')->with('success','Purchase return updated successfully');
            }
            else
            {
                return redirect()->route('purchase.return.index')->with('error',$resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('purchase.return.index')->with('error',$e->getMessage());
        }
    }

    public function returnItemDelete(Request $request, PurchaseService $purchaseService)
    {
        try
        {
            $resultres = $purchaseService->purchaseReturnItemDelete($request->all());
            if($resultres->getData()->success)
            {
                return response()->json(['success' => true, 'message' => $resultres->getData()->message], 200);
            }
            else
            {
                return response()->json(['success' => false, 'message' => $resultres->getData()->message], 200);
            }
        }
        catch (\Exception $e)
        {
            return response()->json(['success' => false, 'message' => $e->getMessage()], 200);
        }
    }

    public function autoComplete(Request $request)
    {

        $draw = $request->get('draw');
        $start = $request->get("start");
        $rowperpage = $request->get("length"); // Rows display per page

        $columnIndex_arr = $request->get('order');
        $columnName_arr = $request->get('columns');
        $order_arr = $request->get('order');
        $search_arr = $request->get('search');

        $columnIndex = $columnIndex_arr[0]['column']; // Column index
        $columnName = $columnName_arr[$columnIndex]['data']; // Column name
        $columnSortOrder = $order_arr[0]['dir']; // asc or desc
        $searchValue = $search_arr['value']; // Search value

        // Total records
        $totalRecords = Purchase::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->select('count(*) as allcount')->count();
        $totalRecordswithFilter = Purchase::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                                        $query->where('branch_id', Auth::user()->employee->branch->id);
                                    })->with('vendor', 'branch')
                                    ->where(function ($query) use ($searchValue) {
                                        $query->WhereHas('vendor', function ($q) use ($searchValue) {
                                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                                        })
                                        ->orWhereHas('branch', function ($q) use ($searchValue) {
                                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                                        })
                                        ->orwhere('invoice_no', 'like', '%' .$searchValue . '%')
                                        ->orwhere('tax_type', 'like', '%' .$searchValue . '%')
                                        ->orWhereDate('purchase_date', $searchValue);
                                    })
                                    ->where('status', 1)
                                    ->select('count(*) as allcount')
                                    ->count();

        // Fetch records
        $records = Purchase::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->with('vendor', 'branch')
                    ->where(function ($query) use ($searchValue) {
                        $query->WhereHas('vendor', function ($q) use ($searchValue) {
                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                        })
                        ->orWhereHas('branch', function ($q) use ($searchValue) {
                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                        })
                        ->orwhere('purchases.invoice_no', 'like', '%' .$searchValue . '%')
                        ->orwhere('purchases.tax_type', 'like', '%' .$searchValue . '%')
                        ->orWhereDate('purchase_date', $searchValue);
                    })
                    ->where('status', 1)
                    ->orderBy($columnName,$columnSortOrder)
                    
                    ->select('purchases.*')
                    ->skip($start)
                    ->take($rowperpage)
                    ->latest()->get();

        $data_arr = array();

        $c=0;
        foreach($records as $record)
        {
            $c++;
            $id = $c;//$record->id;
            $invoice_no = $record->invoice_no;
            $purchase_date =date("d-m-Y", strtotime($record->purchase_date)) ;
            $payment_pode = $record->payment_pode;
            $tax_type = $record->tax_type;
            $vendor = $record->vendor->name;
            $branch = $record->branch->name;
            $grand_total = $record->grand_total;

            $showbtn = '';
            $badge = '';

            if(($record->approve_status) && ((isset(Auth()->user()->employee->branch) && Auth()->user()->employee->branch->company_type == 1) || Auth()->user()->hasRole('Super Admin')))
            {
                $showbtn = '<form action="'. route('approvepurchase') .'" method="POST" onsubmit="return confirm(\'Are you sure?\');" class="d-inline-block">'.csrf_field().'<input type="hidden" name="refval" value="'.base64_encode($record->id).'"><button class="btn btn-outline-primary btn-sm" type="submit" data-bs-toggle="tooltip" data-bs-original-title="Approve Purchase">Approve</button></form>';
            }
            else
            {
                $showbtn = '';
            }

            /*<form action='".route('purchase.destroy', $record->id)."' method='POST' onsubmit='return confirm(\"Are you sure?\");' class='d-inline-block'> ".csrf_field()." ".method_field('DELETE')." <button class='btn btn-sm text-danger' type='submit' data-bs-toggle='tooltip' data-bs-original-title='Delete'><span class='fe fe-trash-2 fs-14'></span></button></form>*/

            $buttons = "<div class='g-2'>".$showbtn."<a class='btn text-primary btn-sm' href='".route('purchase.edit', $record->id)."' onclick='return confirm(\"Are you sure?\");' data-bs-toggle='tooltip' data-bs-original-title='Edit' title='Edit'><span class='fe fe-edit fs-14'></span></a><a class='btn text-primary btn-sm viewbtn' href='".route('purchase.show', $record->id)."' data-bs-toggle='tooltip' data-bs-original-title='View' title='View'><span class='fe fe-eye fs-14'></span></a><a class='btn text-primary btn-sm barcodebtn' href='".route('purchase.barcode.print', $record->id)."' data-bs-toggle='tooltip' data-bs-original-title='View' title='Print Barcode'><span class='bi bi-upc-scan fs-14'></span></a></div>";

            $data_arr[] = array("id" => $id, "invoice_no" => $invoice_no, "purchase_date" => $purchase_date, "payment_pode" => $payment_pode, "tax_type" => $tax_type, "vendor" => $vendor, "branch" => $branch, "grand_total" => $grand_total, "buttons" => $buttons);
        }

        $response = array(
           "draw" => intval($draw),
           "iTotalRecords" => $totalRecords,
           "iTotalDisplayRecords" => $totalRecordswithFilter,
           "aaData" => $data_arr
        );

        return response()->json($response);
    }

    public function barcodePrint($id)
    {
        $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
        if(!empty($companys[0]['print_address']))
        {
            $companyTitle = $companys[0]['print_address'];
        }
        else
        {
            $companyTitle = $companys[0]['name'];
        }
        $purchase = Purchase::with('purchaseDetails')->find($id);
        return view('admin.purchase.barcodelist', compact('purchase', 'companyTitle'));
    }
}
