<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CompanyProfile;
use App\Models\Sale;
use App\Models\SaleItem;
use App\Models\SaleClient;
use App\Models\SaleClientItems;
use App\Models\Vendor;
use App\Models\Purchase;
use App\Models\SalesReturn;
use App\Models\SalesItemReturn;
use App\Models\PurchaseReturn;
use App\Models\CustomerMaster;
use App\Models\Transaction;
use App\Models\ProductMaster;
use App\Models\Ledger;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

class ReportController extends Controller
{
    public function saleReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales', compact('companys'));
    }

    public function saleReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $query = SaleClient::query();
        $query->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    });
        $query->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate);
        $sales = $query->get();
        $reports['saleCount'] = $sales->count();
        $reports['totalAmount'] = $sales->sum('grand_total');
        $reports['setteledCount'] = $sales->where('settled', true)->count();
        $reports['notSetteledCount'] = $sales->where('settled', false)->count();
        $reports['setteledAmount'] = $sales->where('settled', true)->sum('grand_total');
        $reports['notSetteledAmount'] = $sales->where('settled', false)->sum('grand_total');
        $reports['cashCount'] = $sales->where('payment_pode', 'Cash')->count();
        $reports['cardCount'] = $sales->where('payment_pode', 'Card')->count();
        $reports['transferCount'] = $sales->where('payment_pode', 'Transfer')->count();
        $reports['creditCount'] = $sales->where('payment_pode', 'Credit')->count();
        $reports['upiCount'] = $sales->where('payment_pode', 'UPI')->count();
        $reports['cashTotal'] = $sales->where('payment_pode', 'Cash')->sum('grand_total');
        $reports['cardTotal'] = $sales->where('payment_pode', 'Card')->sum('grand_total');
        $reports['transferTotal'] = $sales->where('payment_pode', 'Transfer')->sum('grand_total');
        $reports['creditTotal'] = $sales->where('payment_pode', 'Credit')->sum('grand_total');
        $reports['upiTotal'] = $sales->where('payment_pode', 'UPI')->sum('grand_total');
        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales', compact('companys', 'reports'));
    }

    public function saleDetailsReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        return view('admin.report.sales.salesDetails', compact('companys', 'customers'));
    }

    public function saleDetailsReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $customer = $request->customer;
        $sales = SaleItem::with('sale', 'product', 'sale.customer', 'sale.vehicle')->whereHas('sale', function ($query) use ($request) {
                    return $query->whereDate('sale_date', '>=', $request->fromdate)->whereDate('sale_date', '<=', $request->todate)
                    ->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    })
                    ->when($request->has('customer') && !empty($request->customer), function ($query) use ($request) {
                        $query->where('customer_id', $request->customer);
                    });
                })->get();
        
        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        if(CustomerMaster::where('activestatus', true)->where('id', $customer)->exists())
        {
            $customerName = CustomerMaster::where('activestatus', true)->find($customer)->name;
        }
        else
        {
            $customerName = 'All Customer';
        }
        
        return view('admin.report.sales.salesDetails', compact('companys', 'reports', 'sales', 'customers', 'customerName'));
    }

    public function saleTaxReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.tax.sales', compact('companys'));
    }

    public function salesTaxReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $type = $request->sales_type;

        $query = Sale::query();
        $query->with('saleDetails');
        $query->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    });
        $query->when($request->has('sales_type') && !empty($request->sales_type), function ($query) use ($request) {
                        $query->where('bill_type', $request->sales_type);
                    });
        $query->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate);
        $query->withCount([
            'saleDetails AS taxtwentyeight_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleDetails AS taxeighteen_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleDetails AS taxtwelve_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleDetails AS taxfive_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleDetails AS taxzero_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'saleDetails AS taxtwentyeight_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleDetails AS taxeighteen_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleDetails AS taxtwelve_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleDetails AS taxfive_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleDetails AS taxzero_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'saleDetails AS taxtwentyeight_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleDetails AS taxeighteen_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleDetails AS taxtwelve_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleDetails AS taxfive_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleDetails AS taxzero_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '0.00');
                },
            ]);
        $sales = $query->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.tax.sales', compact('companys', 'sales', 'reports'));
    }

    // R1 Start
    public function saleTaxReportR1()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.tax.salesR1', compact('companys'));
    }

    public function salesTaxReportListR1(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $type = $request->sales_type;
        $query = Sale::query();
        $query->with('saleDetails');
        // $query->with(['saleDetails' => function ($query) {
        //             $query->groupBy('cgst')->selectRaw('cgst, SUM(taxable_amount) as total_sum');
        //         }]);
        $query->leftJoin(DB::raw('(SELECT sales_id, cgst, SUM(taxable_amount) as taxable_amount_sum FROM sale_items WHERE deleted_at is null GROUP BY sales_id, cgst) AS sales_details'), function ($join) {
            $join->on('sales_details.sales_id', '=', 'sales.id');
        });
        $query->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    });
        $query->when($request->has('sales_type') && !empty($request->sales_type), function ($query) use ($request) {
                        $query->where('bill_type', $request->sales_type);
                    });
        $query->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate);
        $sales = $query->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.tax.salesR1', compact('companys', 'sales', 'reports'));
    }

    // R1 End

    public function purchaseTaxReport()
    {
        $vendors = Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.purchase.purchase', compact('vendors', 'companys'));
    }

    public function purchaseTaxReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $vendor = $request->vendor;
        $branch = $request->branch;

        $query = Purchase::query();
        $query->with('purchaseDetails');
        $query->when($request->has('vendor') && !empty($request->vendor), function ($query) use ($request) {
                        $query->where('vendor_id', $request->vendor);
                    });
        $query->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    });
        $query->whereDate('purchase_date', '>=', $fromdate)->whereDate('purchase_date', '<=', $todate);
        $query->withCount([
            'purchaseDetails AS taxtwentyeight_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '28.00');
                },
            'purchaseDetails AS taxeighteen_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '18.00');
                },
            'purchaseDetails AS taxtwelve_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '12.00');
                },
            'purchaseDetails AS taxfive_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '5.00');
                },
            'purchaseDetails AS taxzero_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '0.00');
                },

            'purchaseDetails AS taxtwentyeight_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'purchaseDetails AS taxeighteen_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'purchaseDetails AS taxtwelve_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'purchaseDetails AS taxfive_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'purchaseDetails AS taxzero_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'purchaseDetails AS taxtwentyeight_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'purchaseDetails AS taxeighteen_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'purchaseDetails AS taxtwelve_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'purchaseDetails AS taxfive_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'purchaseDetails AS taxzero_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '0.00');
                },
            ]);
        $purchases = $query->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $vendors = Vendor::where('status', 0)->get();
        return view('admin.report.purchase.purchase', compact('vendors', 'companys', 'purchases', 'reports'));
    }

    public function salesReturnReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.index', compact('companys'));
    }

    public function salesReturnReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;

        $sales = SalesReturn::where('status', 1)->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                    $query->where('branch_id', $request->branch);
                })->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate)->withCount([
            'saleDetails AS taxtwentyeight_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleDetails AS taxeighteen_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleDetails AS taxtwelve_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleDetails AS taxfive_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleDetails AS taxzero_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'saleDetails AS taxtwentyeight_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleDetails AS taxeighteen_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleDetails AS taxtwelve_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleDetails AS taxfive_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleDetails AS taxzero_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'saleDetails AS taxtwentyeight_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleDetails AS taxeighteen_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleDetails AS taxtwelve_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleDetails AS taxfive_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleDetails AS taxzero_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '0.00');
                },
            ])->get();
        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.index', compact('companys', 'sales', 'reports'));
    }

    public function purchaseReturnReport()
    {
        $vendors = Vendor::where('status', 0)->get();
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.purchase.purchaseReturn', compact('vendors', 'companys'));
    }

    public function purchaseReturnReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $vendor = $request->vendor;
        $branch = $request->branch;

        $query = PurchaseReturn::query();
        $query->with('purchaseReturnDetails');
        $query->when($request->has('vendor') && !empty($request->vendor), function ($query) use ($request) {
                        $query->where('vendor_id', $request->vendor);
                    });
        $query->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    });
        $query->whereDate('purchase_date', '>=', $fromdate)->whereDate('purchase_date', '<=', $todate);
        $query->withCount([
            'purchaseReturnDetails AS taxtwentyeight_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '28.00');
                },
            'purchaseReturnDetails AS taxeighteen_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '18.00');
                },
            'purchaseReturnDetails AS taxtwelve_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '12.00');
                },
            'purchaseReturnDetails AS taxfive_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '5.00');
                },
            'purchaseReturnDetails AS taxzero_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amt), 0) as amount"))->where('cgst', '0.00');
                },

            'purchaseReturnDetails AS taxtwentyeight_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'purchaseReturnDetails AS taxeighteen_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'purchaseReturnDetails AS taxtwelve_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'purchaseReturnDetails AS taxfive_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'purchaseReturnDetails AS taxzero_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'purchaseReturnDetails AS taxtwentyeight_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'purchaseReturnDetails AS taxeighteen_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'purchaseReturnDetails AS taxtwelve_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'purchaseReturnDetails AS taxfive_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'purchaseReturnDetails AS taxzero_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '0.00');
                },
            ]);
        $purchases = $query->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $vendors = Vendor::where('status', 0)->get();
        return view('admin.report.purchase.purchaseReturn', compact('vendors', 'companys', 'purchases', 'reports'));
    }

    public function salesItemWiseReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        return view('admin.report.sales.itemWise', compact('companys', 'customers'));
    }

    public function salesItemWiseReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $product = $request->product;

        $sales = Sale::with('saleDetails')->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                    $query->where('branch_id', $request->branch);
                })->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate)->whereHas('saleDetails', function ($query) use ($product) {
                    return $query->where('product_master_id', $product);
                })->when($request->has('customer') && !empty($request->customer), function ($query) use ($request) {
                    $query->where('customer_id', $request->customer);
                })->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }
        $productVal = ProductMaster::find($product);

        $reports['branch'] = $selcompany;
        $reports['product'] = $productVal->name;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        return view('admin.report.sales.itemWise', compact('companys', 'sales', 'reports', 'product', 'customers'));
    }

    /*public function salesItemWiseCustomerReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $product = $request->product;

        $sales = Sale::with('saleDetails')->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                    $query->where('branch_id', $request->branch);
                })->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate)->whereHas('saleDetails', function ($query) use ($product) {
                    return $query->where('product_master_id', $product);
                })->when($request->has('customer') && !empty($request->customer), function ($query) use ($request) {
                    $query->where('customer_id', $request->customer);
                })->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }
        $productVal = ProductMaster::find($product);

        $reports['branch'] = $selcompany;
        $reports['product'] = $productVal->name;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.itemWise', compact('companys', 'sales', 'reports', 'product'));
    }*/

    public function purchaseItemWiseReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.purchase.itemWise', compact('companys'));
    }

    public function purchaseItemWiseReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $product = $request->product;

        $sales = Purchase::with('purchaseDetails', 'vendor')->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                    $query->where('branch_id', $request->branch);
                })->whereDate('purchase_date', '>=', $fromdate)->whereDate('purchase_date', '<=', $todate)->whereHas('purchaseDetails', function ($query) use ($product) {
                    return $query->where('product_master_id', $product);
                })->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }
        $productVal = ProductMaster::find($product);

        $reports['branch'] = $selcompany;
        $reports['product'] = $productVal->name;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.purchase.itemWise', compact('companys', 'sales', 'reports', 'product'));
    }

    public function clientSaleTaxReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.tax.salesClient', compact('companys'));
    }

    public function clientSalesTaxReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $type = $request->sales_type;

        $query = SaleClient::query();
        $query->with('saleClientDetails');
        $query->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    });
        $query->when($request->has('sales_type') && !empty($request->sales_type), function ($query) use ($request) {
                        $query->where('bill_type', $request->sales_type);
                    });
        $query->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate);
        $query->withCount([
            'saleClientDetails AS taxtwentyeight_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleClientDetails AS taxeighteen_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleClientDetails AS taxtwelve_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleClientDetails AS taxfive_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleClientDetails AS taxzero_amount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(taxable_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'saleClientDetails AS taxtwentyeight_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleClientDetails AS taxeighteen_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleClientDetails AS taxtwelve_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleClientDetails AS taxfive_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleClientDetails AS taxzero_cgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(cgst_amount), 0) as amount"))->where('cgst', '0.00');
                },

            'saleClientDetails AS taxtwentyeight_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '28.00');
                },
            'saleClientDetails AS taxeighteen_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '18.00');
                },
            'saleClientDetails AS taxtwelve_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '12.00');
                },
            'saleClientDetails AS taxfive_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '5.00');
                },
            'saleClientDetails AS taxzero_sgstamount' => function ($query) {
                    $query->select(DB::raw("coalesce(SUM(sgst_amount), 0) as amount"))->where('cgst', '0.00');
                },
            ]);
        $sales = $query->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.tax.salesClient', compact('companys', 'sales', 'reports'));
    }

    public function transactionSearch()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $ledgers = Ledger::latest()->get();
        return view('admin.report.transaction.index', compact('companys', 'customers', 'ledgers'));
    }

    public function transactionSearchResult(Request $request)
    {
        try
        {
            $customer = $request->customer;
            $branch = $request->branch;
            $ledgers = $request->ledgers;
            $fromdate = $request->fromdate;
            $todate = $request->todate;
            $companys = CompanyProfile::where('status', 1)->where('id', $branch)->first();

            $amountBeforeFromDate = Transaction::when($request->has('customer') && !empty($request->customer), function ($query) use ($request) {
                $query->where('customer_id', $request->customer);
            })
            ->when($request->has('ledgers') && !empty($request->ledgers), function ($query) use ($request) {
                $query->where('ledger_id', $request->ledgers);
            })
            ->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                $query->where('branch_id', $request->branch);
            })
            ->whereDate('transaction_date', '<', $fromdate)
            ->select(
                DB::raw('SUM(credit_amount) as total_credit_amount'),
                DB::raw('SUM(debit_amount) as total_debit_amount')
            )
            ->first();

            // dd($amountBeforeFromDate->total_credit_amount);

            $transactionList = Transaction::select(
                'parent_table_id',
                'parent_table', 'reference_invoice_no',
                DB::raw('MIN(id) as id'),
                DB::raw('MIN(customer_id) as customer_id'),
                DB::raw('MIN(branch_id) as branch_id'),
                DB::raw('MIN(ledger_id) as ledger_id'),
                DB::raw('MIN(transaction_date) as transaction_date'),
                DB::raw('MIN(transaction_type) as transaction_type'),
                DB::raw('MIN(payment_type) as payment_type'),
                DB::raw('SUM(debit_amount) as debit_amount'),
                DB::raw('SUM(credit_amount) as credit_amount'),
                DB::raw('MIN(description) as description'),
                DB::raw('MIN(transaction_no) as transaction_no')
            )
            ->with('customer')->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                $query->where('branch_id', $request->branch);
            })
            ->when($request->has('customer') && !empty($request->customer), function ($query) use ($request) {
                $query->where('customer_id', $request->customer);
            })
            ->when($request->has('ledgers') && !empty($request->ledgers), function ($query) use ($request) {
                $query->where('ledger_id', $request->ledgers);
            })
            ->whereDate('transaction_date', '>=', $fromdate)
            ->whereDate('transaction_date', '<=', $todate)
            ->groupBy('parent_table_id', 'parent_table','reference_invoice_no')
            ->orderBy('transaction_date')->get()->toArray();




            if(!empty($transactionList))
            {
                $pagedata['companys'] = $companys;
                $pagedata['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
                $openBal[] = array("id" => '',
                    "transaction_no" => "",
                    "ledger_id" => (isset($ledgers) && !empty($ledgers)) ? $ledgers : '',
                    "transaction_date" => $fromdate,
                    "parent_table_id" => '',
                    "customer_id" => (isset($customer) && !empty($customer)) ? $customer : '',
                    "branch_id" => $request->branch,
                    "parent_table" => '',
                    "transaction_type" => '5',
                    "payment_type" => '',
                    "credit_amount" => $amountBeforeFromDate->total_credit_amount,
                    "debit_amount" => $amountBeforeFromDate->total_debit_amount,
                    "payment_details" => null,
                    "description" => "Balance before ".date("d-m-Y", strtotime($fromdate)),
                    "customer" => (isset($customer) && !empty($customer)) ? CustomerMaster::where('activestatus', true)->where('id', $customer)->get()->toArray()[0] : '',
                );
                $invoice = array_merge($openBal, $transactionList);
                //dd($invoice);
                return view('admin.report.transaction.transactionList', compact('pagedata', 'invoice'));
            }
            else
            {
                return redirect()->route('report.transaction.search')->with('error', 'No record found.');
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('report.transaction.search')->with('error', $e->getMessage());
        }
    }

    public function saleProfitReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.salesProfit', compact('companys'));
    }

    public function saleProfitReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        /*$sales = SaleClient::with('saleClientDetails', 'customer')->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    })->join('sale_client_items', 'sale_clients.id', '=', 'sale_client_items.sales_client_id')
             ->join('product_prices', 'product_prices.product_master_id', '=', 'sale_client_items.product_master_id')
             ->select('sale_clients.*', DB::raw('SUM(product_prices.cost) as productTotal'), DB::raw('SUM(sale_client_items.gross_amount) as grossTotal'))->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate)
             ->groupBy('sale_clients.id')
             ->get();*/
             
        $sales = SaleClient::with('saleClientDetails', 'saleClientDetails.product', 'saleClientDetails.product.price', 'customer')->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    })->whereDate('sale_date', '>=', $fromdate)->whereDate('sale_date', '<=', $todate)->get();

        // dd($sales);

        $reports['saleData'] = $sales;
        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.salesProfit', compact('companys', 'reports'));
    }

    public function saleHsnUpdate()
    {
        $productList = ProductMaster::with('unit')->get();
        foreach($productList as $key => $product)
        {
            if(SaleItem::where('product_master_id', $product->id)->exists())
            {
                SaleItem::where('product_master_id', $product->id)->update(['hsncode' => $product->hsncode, 'unit' => $product->unit->unit]);
            }

            if(SaleClientItems::where('product_master_id', $product->id)->exists())
            {
                SaleClientItems::where('product_master_id', $product->id)->update(['hsncode' => $product->hsncode, 'unit' => $product->unit->unit]);
            }

            if(SalesItemReturn::where('product_master_id', $product->id)->exists())
            {
                SalesItemReturn::where('product_master_id', $product->id)->update(['hsncode' => $product->hsncode, 'unit' => $product->unit->unit]);
            }
        }
        return redirect()->route('adminDashboard');
    }

    public function saleHsnReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.salesHsn', compact('companys'));
    }

    public function saleHsnReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $sales = SaleClientItems::with('sale', 'product')->whereHas('sale', function ($query) use ($request) {
                    return $query->whereDate('sale_date', '>=', $request->fromdate)->whereDate('sale_date', '<=', $request->todate)
                    ->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    });
                 
                })
                ->select('cgst', 'hsncode', 'unit',
                    DB::raw('sum(quantity) as quantity_sum'),
                    DB::raw('sum(taxable_amount) as taxable_amount_sum'),
                    DB::raw('sum(item_total) as item_total_sum'),
                    DB::raw('sum(cgst_amount) as cgst_amount_sum'),
                    DB::raw('sum(sgst_amount) as sgst_amount_sum')
                )->groupBy('cgst', 'hsncode', 'unit')->get();
        $reports['saleData'] = $sales;
        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                            $query->where('id', Auth::user()->employee->branch->id);
                        })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();

        return view('admin.report.sales.salesHsn', compact('companys', 'reports'));
    }

    public function saleTaxSplitReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.salesTaxSplitDetails', compact('companys'));
    }

    public function saleTaxSplitReportList(Request $request)
    {
        $fromdate = $request->fromdate;
        $todate = $request->todate;
        $branch = $request->branch;
        $sales = SaleItem::with('sale', 'product', 'sale.customer', 'sale.vehicle')->whereHas('sale', function ($query) use ($request) {
                    return $query->whereDate('sale_date', '>=', $request->fromdate)->whereDate('sale_date', '<=', $request->todate)
                    ->when($request->has('branch') && !empty($request->branch), function ($query) use ($request) {
                        $query->where('branch_id', $request->branch);
                    })
                    ->when($request->has('sales_type') && !empty($request->sales_type), function ($query) use ($request) {
                        $query->where('bill_type', $request->sales_type);
                    })
                    ->when($request->has('tax') && !empty($request->tax), function ($query) use ($request) {
                        $query->where('tax_type', $request->tax);
                    });
                })->get();
        
        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($fromdate)).' - '.date("d-m-Y", strtotime($todate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.sales.salesTaxSplitDetails', compact('companys', 'reports', 'sales'));
    }

    public function stockDetailsReport()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.stock.stockDetails', compact('companys'));
    }

    public function stockDetailsReportList(Request $request)
    {
        $fromDate = ''; // $request->fromdate;
        $toDate = $request->todate;
        $branchId = $request->branch;

        /* $productVal = ProductMaster::with([
          'productSales' => function ($query) use ($fromDate, $toDate, $branchId) {
              $query->whereHas('sale', function ($query) use ($fromDate, $toDate, $branchId) {
                  $query->whereBetween('sale_date', [$fromDate, $toDate])
                        ->where('branch_id', $branchId);
              });
          },
          'productPurchase' => function ($query) use ($fromDate, $toDate, $branchId) {
              $query->whereHas('purchase', function ($query) use ($fromDate, $toDate, $branchId) {
                  $query->whereBetween('purchase_date', [$fromDate, $toDate])->where('branch_id', $branchId);
              });
          }, 'stockqty'])->get(); */

        $productVal = ProductMaster::with([
          'productSales' => function ($query) use ($fromDate, $toDate, $branchId) {
              $query->whereHas('sale', function ($query) use ($fromDate, $toDate, $branchId) {
                  $query->whereDate('sale_date', '<=', $toDate)
                  ->when($branchId, function ($query, $branchId) {
                       return $query->where('branch_id', $branchId);
                   });
              });
          },
          'productPurchase' => function ($query) use ($fromDate, $toDate, $branchId) {
              $query->whereHas('purchase', function ($query) use ($fromDate, $toDate, $branchId) {
                  $query->whereDate('purchase_date', '<=', $toDate)
                  ->when($branchId, function ($query, $branchId) {
                       return $query->where('branch_id', $branchId);
                   });
              });
          },
          'productSaleReturn' => function ($query) use ($fromDate, $toDate, $branchId) {
              $query->whereHas('sale', function ($query) use ($fromDate, $toDate, $branchId) {
                  $query->whereDate('sale_date', '<=', $toDate)
                  ->when($branchId, function ($query, $branchId) {
                       return $query->where('branch_id', $branchId);
                   });
              });
          },
          'productPurchaseReturn' => function ($query) use ($fromDate, $toDate, $branchId) {
              $query->whereHas('purchaseReturn', function ($query) use ($fromDate, $toDate, $branchId) {
                  $query->whereDate('purchase_date', '<=', $toDate)
                  ->when($branchId, function ($query, $branchId) {
                       return $query->where('branch_id', $branchId);
                   });
              });
          },
          'stockqty', 'price'])->get();

        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($toDate)); // date("d-m-Y", strtotime($fromDate)).' - '.date("d-m-Y", strtotime($toDate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.stock.stockDetails', compact('companys', 'reports', 'productVal'));
    }
}
