<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;
use App\Http\Requests\StoreRoleRequest;
use Illuminate\Support\Facades\Auth;

class RoleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
        /*$this->middleware('permission:Manage-Roles|Create-Role|Edit-Role', ['only' => ['index','show']]);
        $this->middleware('permission:Create-Role', ['only' => ['create','store']]);
        $this->middleware('permission:Edit-Role', ['only' => ['edit','update']]);*/
    }

    public function index()
    {
        $permissionList = Auth::user()->getPermissionsViaRoles()->pluck('name');
        $roles = Role::whereNotIn('name', ['Super Admin'])->get();
        if(Auth::user()->hasRole('Super Admin'))
        {
            $permissions = Permission::get();
        }
        else
        {
            $permissions = Permission::whereIn('name', $permissionList)->get();
        }
        return view('admin.roles.index', compact('roles', 'permissions'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreRoleRequest $request)
    {
        $role = Role::create(['name' => ucwords($request->rolename)]);

        $permissions = $request->permission ? $request->permission : [];
        $role->syncPermissions($permissions);
        
        return redirect()->route('roles.index')->with('success','Role created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Role $role)
    {
        $permissionList = Auth::user()->getPermissionsViaRoles()->pluck('name');
        if(Auth::user()->hasRole('Super Admin'))
        {
            $permissions = Permission::get();
        }
        else
        {
            $permissions = Permission::whereIn('name', $permissionList)->get();
        }
        return view('admin.roles.edit',compact('role','permissions'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Role $role)
    {
        $permissions = $request->permission ? $request->permission : [];
        $role->syncPermissions($permissions);

        return redirect()->route('roles.index')->with('success','Role permission updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
