<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Sale;
use App\Models\SaleClient;
use App\Models\CompanyProfile;
use App\Models\CustomerMaster;
use App\Models\EmployeeMaster;
use App\Models\SaleSettlement;
use App\Models\PlaceOfSupply;
use App\Models\DriverMaster;
use App\Models\Vehicle;
use App\Services\SaleService;
use PDF;
use App\Traits\InvoicePrintTrait;
use Illuminate\Support\Facades\Auth;
use App\Models\SalesReturn;

class SaleController extends Controller
{
    use InvoicePrintTrait;
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $sales = Sale::when(Auth::check() && !Auth::user()->hasRole(['Super Admin','Admin']), function ($query) {
                        $query->where('created_by', Auth::id());
                    })->latest()->get();
        $pageTitle = 'Sale List';
        return view('admin.sales.index', compact('sales', 'pageTitle'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $places = PlaceOfSupply::get();
        $drivers = DriverMaster::get();
        $employees = EmployeeMaster::whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        $vehicles = Vehicle::get();
        return view('admin.sales.create', compact('companys', 'customers', 'employees', 'vehicles', 'places', 'drivers'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, SaleService $saleService)
    {
        try
        {
            $resultres = $saleService->store($request->all());
            if($resultres->getData()->success)
            {
                if(isset($request->customer_name) && !empty($request->customer_name))
                {
                    return redirect()->route('view.thermal.print.sale', $resultres->getData()->sale)->with('success', $resultres->getData()->message);
                    //return redirect()->route('counter.sale')->with('success', $resultres->getData()->message);
                }
                elseif(isset($request->billType) && !empty($request->billType))
                {
                    return redirect()->route('view.print.sale.estimate', $resultres->getData()->sale)->with('success', $resultres->getData()->message);
                }

                return redirect()->route('sales.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                if(isset($request->customer_name) && !empty($request->customer_name))
                {
                    return redirect()->route('counter.sale')->with('error', $resultres->getData()->message);
                }
                elseif(isset($request->billType) && !empty($request->billType))
                {
                    return redirect()->route('sale.estimate')->with('error', $resultres->getData()->message);
                }
                return redirect()->route('sales.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            if(isset($request->customer_name) && !empty($request->customer_name))
            {
                return redirect()->route('counter.sale')->with('error', $e->getMessage());
            }
            elseif(isset($request->billType) && !empty($request->billType))
            {
                return redirect()->route('sale.estimate')->with('error', $e->getMessage());
            }
            return redirect()->route('sales.create')->with('error', $e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Sale $sale)
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::where('activestatus', true)->get();
        return view('admin.sales.show', compact('companys', 'customers', 'employees', 'sale'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Sale $sale)
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $places = PlaceOfSupply::get();
        $drivers = DriverMaster::get();
        $driverName = $placeName = $print_diver = $print_site = $print_vehicle = '';
        if(!empty($sale->site_data))
        {
            $siteData = json_decode($sale->site_data);
            $driverName = $siteData->driver;
            $placeName = $siteData->site;
            $print_diver = $siteData->printdiver ?? '';
            $print_site = $siteData->printsite ?? '';
            $print_vehicle = $siteData->printvehicle ?? '';
        }
        $vehicles = Vehicle::get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.sales.edit', compact('companys', 'customers', 'employees', 'sale', 'places', 'drivers', 'driverName', 'placeName', 'vehicles','print_diver','print_site','print_vehicle'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Sale $sale, SaleService $saleService)
    {
        try
        {
            $resultres = $saleService->update($request->all(), $sale);
            if($resultres->getData()->success)
            {
                if(!$sale->sales_type)
                {
                    return redirect()->route('view.thermal.print.sale', $sale)->with('success', $resultres->getData()->message);
                }
                return redirect()->route('sales.index')->with('success', 'Sale updated successfully');
            }
            else
            {
                return redirect()->route('sales.index')->with('error', $resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('sales.index')->with('error', $e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function itemDelete(Request $request, SaleService $saleService)
    {
        try
        {
            $resultres = $saleService->saleItemDelete($request->all());
            if($resultres->getData()->success)
            {
                return response()->json(['success' => true, 'message' => $resultres->getData()->message], 200);
            }
            else
            {
                return response()->json(['success' => false, 'message' => $resultres->getData()->message], 200);
            }
        }
        catch (\Exception $e)
        {
            return response()->json(['success' => false, 'message' => $e->getMessage()], 200);
        }
    }

    public function listClientSale()
    {
        $sales = SaleClient::latest()->get();
        return view('admin.sales.indexClient', compact('sales'));
    }

    public function viewClientSale($id)
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::where('activestatus', true)->get();
        $sale = SaleClient::where('sales_id', $id)->first();
        return view('admin.sales.viewclient', compact('companys', 'customers', 'employees', 'sale'));
    }

    public function editClientSale($id)
    {
        $sale = SaleClient::find($id);
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.sales.editClient', compact('companys', 'customers', 'employees', 'sale'));
    }

    public function updateClientSale(Request $request, $id, SaleService $saleService)
    {
        try
        {
            $sale = SaleClient::find($id);
            $resultres = $saleService->updateClient($request->all(), $sale);
            if($resultres->getData()->success)
            {
                return redirect()->route('sale.client.list')->with('success', 'Sale updated successfully');
            }
            else
            {
                return redirect()->route('sale.client.list')->with('error', $resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('sale.client.list')->with('error', $e->getMessage());
        }
    }

    public function saleClientItemDelete(Request $request, SaleService $saleService)
    {
        try
        {
            $resultres = $saleService->saleClientItemDelete($request->all());
            if($resultres->getData()->success)
            {
                return response()->json(['success' => true, 'message' => $resultres->getData()->message], 200);
            }
            else
            {
                return response()->json(['success' => false, 'message' => $resultres->getData()->message], 200);
            }
        }
        catch (\Exception $e)
        {
            return response()->json(['success' => false, 'message' => $e->getMessage()], 200);
        }
    }

    public function counterSale()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.sales.counter', compact('companys', 'customers', 'employees'));
    }

    public function billSettled(Request $request, $id)
    {
        $sale = Sale::find($id);
        $sale->settled = true;
        $sale->save();

        $saleClient = SaleClient::where('sales_id', $id)->first();
        $saleClient->settled = true;
        $saleClient->save();

        $saleSettlements = new SaleSettlement;
        $saleSettlements->sales_id = $sale->id;
        $saleSettlements->payment_mode = $sale->payment_pode;
        $saleSettlements->total_amount = $sale->grand_total;
        $saleSettlements->received_amount = (isset($request->recamt) && !empty($request->recamt)) ? $request->recamt : '0';
        $saleSettlements->save();
        if(!$sale->sales_type)
        {
            return redirect()->route('view.thermal.print.sale', $sale)->with('success', 'Print View');
        }
        return redirect()->route('sales.index')->with('success', 'Sale updated successfully');
    }

    public function salePrint($id)
    {
        try
        {
            if(Auth::user()->hasRole(['Super Admin','Admin']))
            {
                $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
            }
            else
            {
                $companys[] = Auth::user()->employee->branch->toArray();
            }


            $saledata = $this->saleItems($id);
            if($saledata->getData()->success)
            {
                $invoice = $saledata->getData()->data;
                $pagedata = $companys;
                //$pdf = PDF::loadView('admin.report.invoice.saleList', compact('pagedata', 'invoice'))->setPaper('a4', 'portrait');
                //return $pdf->download('invoice.pdf');
                return view('admin.report.invoice.saleList', compact('pagedata', 'invoice'));
            }
            else
            {
                return redirect()->route('sales.index')->with('error', 'Data not exist.');
            }
        }
        catch (\Exception $e)
        {
            //dd($e->getMessage());
            return redirect()->route('sales.index')->with('error', $e->getMessage());
        }
    }

    public function saleThermalPrint($id)
    {
        try
        {
            if(Auth::user()->hasRole(['Super Admin','Admin']))
            {
                $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
            }
            else
            {
                $companys[] = Auth::user()->employee->branch->toArray();
            }


            $saledata = $this->saleItems($id);
            if($saledata->getData()->success)
            {
                $invoice = $saledata->getData()->data;
                $pagedata = $companys;
                return view('admin.report.invoice.thermalPrint', compact('pagedata', 'invoice'));
            }
            else
            {
                return redirect()->route('sales.index')->with('error', 'Data not exist.');
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('sales.index')->with('error', $e->getMessage());
        }
    }

    public function estimatePrint($id)
    {
        try
        {
            if(Auth::user()->hasRole(['Super Admin','Admin']))
            {
                $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
            }
            else
            {
                $companys[] = Auth::user()->employee->branch->toArray();
            }


            $saledata = $this->saleItemEstimate($id);
            if($saledata->getData()->success)
            {
                $invoice = $saledata->getData()->data;
                $pagedata = $companys;
                return view('admin.report.invoice.estimateList', compact('pagedata', 'invoice'));
            }
            else
            {
                return redirect()->route('admin.sales.estimate')->with('error', 'Data not exist.');
            }
        }
        catch (\Exception $e)
        {
            //dd($e->getMessage());
            return redirect()->route('admin.sales.estimate')->with('error', $e->getMessage());
        }
    }

        public function saleReturnPrint($id)
    {
        try
        {
            if(Auth::user()->hasRole(['Super Admin','Admin']))
            {
                $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
            }
            else
            {
                $companys[] = Auth::user()->employee->branch->toArray();
            }


            $saledata = $this->SalesReturn($id);
            if($saledata->getData()->success)
            {
                $invoice = $saledata->getData()->data;
                $pagedata = $companys;
                //$pdf = PDF::loadView('admin.report.invoice.saleList', compact('pagedata', 'invoice'))->setPaper('a4', 'portrait');
                //return $pdf->download('invoice.pdf');
                return view('admin.report.invoice.saleReturnList', compact('pagedata', 'invoice'));
            }
            else
            {
                return redirect()->route('sales.return.index')->with('error', 'Data not exist.');
            }
        }
        catch (\Exception $e)
        {
            //dd($e->getMessage());
            return redirect()->route('sales.return.index')->with('error', $e->getMessage());
        }
    }

    public function saleEstimate()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        $vehicles = Vehicle::get();
        return view('admin.sales.estimate', compact('companys', 'customers', 'employees', 'vehicles'));
    }


    public function estimateIndex()
    {
        $sales = Sale::when(Auth::check() && !Auth::user()->hasRole(['Super Admin','Admin']), function ($query) {
                        $query->where('created_by', Auth::id());
                    })->where('purpose', false)->latest()->get();
        $pageTitle = 'Estimate List';
        return view('admin.sales.estimateIndex', compact('sales', 'pageTitle'));
    }

    public function returnIndex()
    {
        $sales = SalesReturn::where('status', 1)->when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->get();
        return view('admin.sales.returnIndex', compact('sales'));
    }

    public function returnCreate()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.sales.returnCreate', compact('companys', 'customers', 'employees'));
    }

    public function returnStore(Request $request, SaleService $saleService)
    {
        try
        {
            $resultres = $saleService->returnStore($request->all());
            if($resultres->getData()->success)
            {
                return redirect()->route('sales.return.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('sales.return.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('sales.return.create')->with('error',$e->getMessage());
        }
    }

    public function returnShow(SalesReturn $salesReturn)
    {
        $sale = $salesReturn;
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::where('activestatus', true)->get();
        return view('admin.sales.returnShow', compact('companys', 'customers', 'employees', 'sale'));
    }

    public function returnEdit(SalesReturn $salesReturn)
    {
        $sale = $salesReturn;
        $companys = CompanyProfile::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole(['Super Admin','Admin']) && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.sales.returnEdit', compact('companys', 'customers', 'employees', 'sale'));
    }

    public function returnUpdate(Request $request, SalesReturn $salesReturn, SaleService $saleService)
    {
        try
        {
            $resultres = $saleService->returnUpdate($request->all(), $salesReturn);
            if($resultres->getData()->success)
            {
                return redirect()->route('sales.return.index')->with('success','Sales return updated successfully');
            }
            else
            {
                return redirect()->route('sales.return.index')->with('error',$resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('sales.return.index')->with('error',$e->getMessage());
        }
    }

    public function returnItemDelete(Request $request, SaleService $saleService)
    {
        try
        {
            $resultres = $saleService->saleReturnItemDelete($request->all());
            if($resultres->getData()->success)
            {
                return response()->json(['success' => true, 'message' => $resultres->getData()->message], 200);
            }
            else
            {
                return response()->json(['success' => false, 'message' => $resultres->getData()->message], 200);
            }
        }
        catch (\Exception $e)
        {
            return response()->json(['success' => false, 'message' => $e->getMessage()], 200);
        }
    }

    public function counterSaleStatus($status)
    {
        $sales = Sale::where('settled', $status)->when(Auth::check() && !Auth::user()->hasRole(['Super Admin','Admin']), function ($query) {
                        $query->where('created_by', Auth::id());
                    })->latest()->get();
        $pageTitle = ($status)?'Settled':'Unsettled';
        return view('admin.sales.index', compact('sales', 'pageTitle'));
    }

    public function autoComplete(Request $request)
    {
        $draw = $request->get('draw');
        $start = $request->get("start");
        $rowperpage = $request->get("length"); // Rows display per page

        $columnIndex_arr = $request->get('order');
        $columnName_arr = $request->get('columns');
        $order_arr = $request->get('order');
        $search_arr = $request->get('search');

        $columnIndex = $columnIndex_arr[0]['column']; // Column index
        $columnName = $columnName_arr[$columnIndex]['data']; // Column name
        $columnSortOrder = $order_arr[0]['dir']; // asc or desc
        $searchValue = $search_arr['value']; // Search value

        // Total records
        $totalRecords = Sale::when(Auth::check() && !Auth::user()->hasRole(['Super Admin','Admin']), function ($query) {
                            $query->where('created_by', Auth::id());
                        })->select('count(*) as allcount')->count();
        $totalRecordswithFilter = Sale::when(Auth::check() && !Auth::user()->hasRole(['Super Admin','Admin']), function ($query) {
                                        $query->where('created_by', Auth::id());
                                    })
                                    ->with('customer', 'branch')
                                    ->where(function ($query) use ($searchValue) {
                                        $query->WhereHas('customer', function ($q) use ($searchValue) {
                                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                                        })
                                        ->orWhereHas('branch', function ($q) use ($searchValue) {
                                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                                        })
                                        ->orwhere('invoice_no', 'like', '%' .$searchValue . '%')
                                        ->orwhere('bill_type', 'like', '%' .$searchValue . '%')
                                        ->orwhere('grand_total', 'like', '%' .$searchValue . '%')
                                        ->orWhereDate('sale_date', $searchValue);
                                    })
                                    ->select('count(*) as allcount')
                                    ->count();

        // Fetch records
        $records = Sale::when(Auth::check() && !Auth::user()->hasRole(['Super Admin','Admin']), function ($query) {
                        $query->where('created_by', Auth::id());
                    })
                    ->with('customer', 'branch')
                    ->where(function ($query) use ($searchValue) {
                        $query->WhereHas('customer', function ($q) use ($searchValue) {
                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                        })
                        ->orWhereHas('branch', function ($q) use ($searchValue) {
                            $q->where('name', 'LIKE', '%' . $searchValue . '%');
                        })
                        ->orwhere('sales.invoice_no', 'like', '%' .$searchValue . '%')
                        ->orwhere('sales.bill_type', 'like', '%' .$searchValue . '%')
                        ->orwhere('sales.grand_total', 'like', '%' .$searchValue . '%')
                        ->orWhereDate('sale_date', $searchValue);
                    })
                    ->orderBy($columnName,$columnSortOrder)
                    ->select('sales.*')
                    ->skip($start)
                    ->take($rowperpage)
                    ->latest()->get();

        $data_arr = array();

        $c=0;
        foreach($records as $record)
        {
            $c++;
            $id = $c;//$record->id;
            $invoice_no = $record->invoice_no;
            $sale_date = $record->sale_date;
            $bill_type = $record->bill_type;
            $payment_pode = $record->payment_pode;
            $tax_type = $record->tax_type;
            $customer = $record->customer->name;
            $branch = $record->branch->name;
            $grand_total = $record->grand_total;

            if($record->sales_type)
            {
                $showbtn = '<a class="btn text-primary btn-sm viewbtn" href="'. route('sales.show', $record->id) .'" data-bs-toggle="tooltip" data-bs-original-title="View"><span class="fe fe-eye fs-14"></span></a>';
            }
            else
            {
                $showbtn = '';
            }

            if($record->settled)
            {
                $badge = '<span class="badge bg-success badge-sm  me-1 mb-1 mt-1">Settled</span>';
            }
            else
            {
                $badge = '<span class="badge bg-danger badge-sm  me-1 mb-1 mt-1">Not Settled</span>';
            }

            $buttons = "<div class='g-2'><a class='btn text-primary btn-sm' href='".route('sales.edit', $record->id)."' data-bs-toggle='tooltip' data-bs-original-title='Edit'><span class='fe fe-edit fs-14'></span></a>".$showbtn.$badge."<a class='btn text-primary btn-sm printbtn' href='".route('view.print.sale', $record->id)."' target='_blank' data-bs-toggle='tooltip' data-bs-original-title='Print'><span class='fe fe-printer fs-14'></span></a><a class='btn text-primary btn-sm printbtn' href='".route('view.thermal.print.sale', $record->id)."' target='_blank' data-bs-toggle='tooltip' data-bs-original-title='Thermal Print'><span class='fe fe-clipboard fs-14'></span></a></div>";

            $data_arr[] = array("id" => $id, "invoice_no" => $invoice_no, "sale_date" => $sale_date, "bill_type" => $bill_type,"payment_pode" => $payment_pode, "tax_type" => $tax_type, "customer" => $customer, "branch" => $branch, "grand_total" => $grand_total, "buttons" => $buttons);
        }

        $response = array(
           "draw" => intval($draw),
           "iTotalRecords" => $totalRecords,
           "iTotalDisplayRecords" => $totalRecordswithFilter,
           "aaData" => $data_arr
        );

        return response()->json($response);
    }

    public function placeAutocompleteList(Request $request)
    {
        $searchvalue = $request->get('search');
        $data = PlaceOfSupply::where('name', 'LIKE', '%'. $searchvalue. '%')->get();
        return response()->json($data);
    }

    public function driverAutocompleteList(Request $request)
    {
        $searchvalue = $request->get('search');
        $data = DriverMaster::where('name', 'LIKE', '%'. $searchvalue. '%')->get();
        return response()->json($data);
    }
}
