<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\SaleQuotation;
use App\Models\CompanyProfile;
use App\Models\CustomerMaster;
use App\Models\EmployeeMaster;
use App\Models\Vehicle;
use App\Services\SaleQuotationService;
use Illuminate\Support\Facades\Auth;
use App\Traits\InvoicePrintTrait;

class SaleQuotationController extends Controller
{
    use InvoicePrintTrait;

    public function index()
    {
        $sales = SaleQuotation::when(Auth::check() && !Auth::user()->hasRole('Super Admin'), function ($query) {
                        $query->where('created_by', Auth::id());
                    })->latest()->get();
        $pageTitle = 'Quotation List';
        return view('admin.quotation.index', compact('sales', 'pageTitle'));
    }

    public function create()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        $vehicles = Vehicle::get();
        return view('admin.quotation.create', compact('companys', 'customers', 'employees', 'vehicles'));
    }

    public function store(Request $request, SaleQuotationService $saleQuotationService)
    {
        try
        {
            $resultres = $saleQuotationService->store($request->all());
            if($resultres->getData()->success)
            {
                return redirect()->route('quot.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('quot.create')->with('error', $resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('quot.create')->with('error', $e->getMessage());
        }
    }

    public function edit(SaleQuotation $saleQuotation)
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        $employees = EmployeeMaster::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('branch_id', Auth::user()->employee->branch->id);
                    })->whereHas('user.roles', function ($query){ $query->where('name','=', 'Sales Man'); })->where('activestatus', true)->get();
        return view('admin.quotation.edit', compact('companys', 'customers', 'employees', 'saleQuotation'));
    }

    public function update(Request $request, SaleQuotation $saleQuotation, SaleQuotationService $saleQuotationService)
    {
        try
        {
            $resultres = $saleQuotationService->update($request->all(), $saleQuotation);
            if($resultres->getData()->success)
            {
                return redirect()->route('quot.index')->with('success', 'Quotation updated successfully');
            }
            else
            {
                return redirect()->route('quot.index')->with('error', $resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('quot.index')->with('error', $e->getMessage());
        }
    }

    public function convertInvoice(SaleQuotation $saleQuotation, SaleQuotationService $saleQuotationService)
    {
        try
        {
            $resultres = $saleQuotationService->convertInvoice($saleQuotation);
            if($resultres->getData()->success)
            {
                return redirect()->route('quot.index')->with('success', 'Invoice created successfully.');
            }
            else
            {
                return redirect()->route('quot.index')->with('error', $resultres->getData()->message);
            }
        }
        catch (\Exception $e)
        {
            return redirect()->route('quot.index')->with('error', $e->getMessage());
        }
    }

    public function salePrint($id)
    {
        try
        {
            if(Auth::user()->hasRole('Super Admin'))
            {
                $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
            }
            else
            {
                $companys[] = Auth::user()->employee->branch->toArray();
            }


            $saledata = $this->saleItemQuotation($id);
            if($saledata->getData()->success)
            {
                $invoice = $saledata->getData()->data;
                $pagedata = $companys;
                return view('admin.report.invoice.quotationList', compact('pagedata', 'invoice'));
            }
            else
            {
                return redirect()->route('quot.index')->with('error', 'Data not exist.');
            }
        }
        catch (\Exception $e)
        {
            dd($e->getMessage());
            return redirect()->route('quot.index')->with('error', $e->getMessage());
        }
    }
}
