<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\AccountGroup;

class SearchController extends Controller
{
    public function accountSearchIndex()
    {
        $groups = AccountGroup::where('status', true)->get();
        return view('admin.report.search.index', compact('groups'));
    }

    public function accountSearchList(Request $request)
    {
        $group = $request->accountGroup;
        $fromDate = $request->fromdate;
        $toDate = $request->todate;
        $month = null;
        $year = null;
        /*$accountGroups = AccountGroup::whereHas('ledgers', function ($query) use ($fromDate, $toDate) {
            $query->whereHas('transactions', function ($transactionQuery) use ($fromDate, $toDate) {
                $transactionQuery->whereBetween('transaction_date', [$fromDate, $toDate]);
            });
        })->where('status', true)->where('id', $group)->get();*/

        $accountGroups = AccountGroup::whereHas('ledgers', function ($query) use ($fromDate, $toDate, $month, $year) {
            $query->whereHas('transactions', function ($transactionQuery) use ($fromDate, $toDate, $month, $year) {
                $transactionQuery->when($fromDate, function ($q) use ($fromDate) {
                    $q->whereDate('transaction_date', '>=', $fromDate);
                })
                ->when($toDate, function ($q) use ($toDate) {
                    $q->whereDate('transaction_date', '<=', $toDate);
                })
                ->when($month, function ($q) use ($month) {
                    $q->whereMonth('transaction_date', $month);
                })
                ->when($year, function ($q) use ($year) {
                    $q->whereYear('transaction_date', $year);
                });
            });
        })->where('status', true)->where('id', $group)->get();

        $results = [];

        foreach($accountGroups as $accountGroup)
        {
            $ledgersWithSums = $accountGroup->getTransactionSumsGroupedByLedger($fromDate, $toDate);
            $pagedata['group'] = $accountGroup->name;
            foreach($ledgersWithSums as $ledgerData)
            {
                $results[] = [
                    'account_group_id' => $accountGroup->id,
                    'account_group_name' => $accountGroup->name,
                    'ledger_id' => $ledgerData['ledger']->id,
                    'ledger_name' => $ledgerData['ledger']->name,
                    'total_credit_amount' => $ledgerData['total_credit_amount'],
                    'total_debit_amount' => $ledgerData['total_debit_amount'],
                    'total_credit_before_date' => $ledgerData['total_credit_before_date'],
                    'total_debit_before_date' => $ledgerData['total_debit_before_date'],
                ];
            }
        }
        $companys = []; // CompanyProfile::where('status', 1)->where('id', $branch)->first();
        $pagedata['companys'] = $companys;
        $pagedata['dates'] = date("d-m-Y", strtotime($fromDate)).' - '.date("d-m-Y", strtotime($toDate));
        return view('admin.report.search.transactionList', compact('pagedata', 'results'));
    }
}
