<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CompanyProfile;
use App\Models\Stock;
use App\Models\StockBranch;
use App\Models\StockTransfer;
use App\Models\StockTransferItems;
use App\Models\ProductMaster;
use App\Models\StockAdjust;
use Illuminate\Support\Facades\Auth;

class StockController extends Controller
{
    public function stockList()
    {
        $companys = CompanyProfile::where('status', 1)->get();
        return view('admin.stock.index', compact('companys'));
    }

    public function branchStockList($id)
    {
        if(CompanyProfile::where('id', $id)->exists())
        {
            $companyBranch = CompanyProfile::find($id);

            $companys = CompanyProfile::where('status', 1)->get();
            return view('admin.stock.index', compact('companys', 'companyBranch'));
        }

    }

    public function branchStockListTable(Request $request, $id)
    {
        if(CompanyProfile::where('id', $id)->exists())
        {
            $companyBranch = CompanyProfile::find($id);

            $draw = $request->get('draw');
            $start = $request->get("start");
            $rowperpage = $request->get("length"); // Rows display per page

            $columnIndex_arr = $request->get('order');
            $columnName_arr = $request->get('columns');
            $order_arr = $request->get('order');
            $search_arr = $request->get('search');

            $columnIndex = $columnIndex_arr[0]['column']; // Column index
            $columnName = $columnName_arr[$columnIndex]['data']; // Column name
            $columnSortOrder = $order_arr[0]['dir']; // asc or desc
            $searchValue = $search_arr['value']; // Search value

            if($companyBranch->company_type == 1)
            {
                // Total records
                $totalRecords = Stock::select('count(*) as allcount')->count();
                $totalRecordswithFilter = Stock::with('product')->select('count(*) as allcount')->whereHas('product', function ($q) use ($searchValue) {
                        $q->where('name', 'LIKE', '%' . $searchValue . '%');
                })->count();

                // Fetch records
                $records = Stock::with('product')->orderBy($columnName,$columnSortOrder)

                ->whereHas('product', function ($q) use ($searchValue, $start, $rowperpage) {
                        $q->where('name', 'LIKE', '%' . $searchValue . '%')->orwhere('code', 'like', '%' .$searchValue . '%')->select('product_masters.*');
                })->skip($start)->take($rowperpage)->get();
            }
            else
            {
                // Total records
                $totalRecords = StockBranch::select('count(*) as allcount')->where('branch_id', $id)->count();
                $totalRecordswithFilter = StockBranch::with('product')->select('count(*) as allcount')->whereHas('product', function ($q) use ($searchValue) {
                        $q->where('name', 'LIKE', '%' . $searchValue . '%');
                })->where('branch_id', $id)->count();

                // Fetch records
                $records = StockBranch::with('product')->orderBy($columnName,$columnSortOrder)

                ->whereHas('product', function ($q) use ($searchValue, $start, $rowperpage) {
                        $q->where('name', 'LIKE', '%' . $searchValue . '%')->orwhere('code', 'like', '%' .$searchValue . '%')->select('product_masters.*');
                })->where('branch_id', $id)->skip($start)->take($rowperpage)->get();
            }

            $data_arr = array();

            $c=0;
            foreach($records as $record)
            {
                $c++;
                $id = $c;//$record->id;
                $code = $record->product->code;
                $name = $record->product->name;
                $quantity = $record->primary_qty;

                if(Auth::user()->can('Manage-Stock-Adjustment'))
                {
                    $buttons = "<a class='btn text-primary btn-sm stockAdjust' href='#' data-idval='".$record->id."' data-prodname='".$record->product->name."' data-bs-toggle='tooltip' data-bs-original-title='Edit Stock'><span class='fe fe-edit fs-14'></span></a>";
                }
                else
                {
                    $buttons = '';
                }

                $data_arr[] = array("id" => $id, "code" => $code, "name" => $name, "quantity" => $quantity, "buttons" => $buttons);
            }

            $response = array(
               "draw" => intval($draw),
               "iTotalRecords" => $totalRecords,
               "iTotalDisplayRecords" => $totalRecordswithFilter,
               "aaData" => $data_arr
            );

            return response()->json($response);
        }
    }

    public function stockTransferList()
    {
        $transferlists = StockTransfer::get();
        return view('admin.stock.transferList', compact('transferlists'));
    }

    public function stockTransferShow($id)
    {
        $transferlist = StockTransfer::find($id);
        return view('admin.stock.transferShow', compact('transferlist'));
    }

    public function stockTransferCreate()
    {
        $query = CompanyProfile::query();
        $query->where('status', '1');
        if(Auth::user()->employee)
        {
            $query->where('id','!=', Auth::user()->employee->branch->id);
        }
        $companys = $query->get();

        $companysFrom = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.stock.transferCreate', compact('companys', 'companysFrom'));
    }

    public function stockTransferStore(Request $request)
    {
        $transfer = new StockTransfer;
        $transfer->transfer_no = time();
        $transfer->transfer_date = date("Y-m-d");
        $transfer->from_branch = $request->branchfrom;
        $transfer->to_branch = $request->branchto;
        $transfer->created_by = Auth::id();
        $transfer->save();

        foreach($request->prdid as $key => $productid)
        {
            if(ProductMaster::where('id', $productid)->exists())
            {
                $product = ProductMaster::find($productid);
                $transferDetails = new StockTransferItems;
                $transferDetails->transfer_id = $transfer->id;
                $transferDetails->product_master_id = $productid;
                $transferDetails->quantity = $request->quantity[$key];
                $transferDetails->save();

                $totalqty = ((int) $request->quantity[$key]);
                if($transfer->fromBranch->company_type == 2)
                {
                    if(StockBranch::where('branch_id', $request->branchfrom)->where('product_master_id', $productid)->exists())
                    {
                        $currentstock = StockBranch::where('branch_id', $request->branchfrom)->where('product_master_id', $productid)->first();
                        $currentstock->primary_qty = ($currentstock->primary_qty - $totalqty);
                        $currentstock->secondary_qty = ($currentstock->secondary_qty - 0);
                        $currentstock->measure_finder = $currentstock->measure_finder;
                        $currentstock->save();
                    }
                    else
                    {
                        $branchStock = new StockBranch;
                        $branchStock->branch_id = $request->branchfrom;
                        $branchStock->product_master_id = $productid;
                        $branchStock->primary_qty = (-1 * abs($totalqty));
                        $branchStock->secondary_qty = 0;
                        $branchStock->measure_finder = 0;
                        $branchStock->comments = 'Transfer ID: '.$transfer->id;
                        $branchStock->created_by = Auth::id();
                        $branchStock->save();
                    }
                }
                else
                {
                    if(Stock::where('product_master_id', $productid)->exists())
                    {
                        $mainstock = Stock::where('product_master_id', $productid)->first();
                        $mainstock->primary_qty = ($mainstock->primary_qty - $totalqty);
                        $mainstock->secondary_qty = ($mainstock->secondary_qty - 0);
                        $mainstock->measure_finder = $mainstock->measure_finder;
                        $mainstock->save();
                    }
                    else
                    {
                        $mainstock = new Stock;
                        $mainstock->product_master_id = $productid;
                        $mainstock->primary_qty = (-1 * abs($totalqty));
                        $mainstock->secondary_qty = 0;
                        $mainstock->measure_finder = 0;
                        $mainstock->save();
                    }
                }

                if($transfer->toBranch->company_type == 2)
                {
                    if(StockBranch::where('branch_id', $request->branchto)->where('product_master_id', $productid)->exists())
                    {
                        $currentstock = StockBranch::where('branch_id', $request->branchto)->where('product_master_id', $productid)->first();
                        $currentstock->primary_qty = ($currentstock->primary_qty + $totalqty);
                        $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                        $currentstock->measure_finder = $currentstock->measure_finder;
                        $currentstock->save();
                    }
                    else
                    {
                        $branchStock = new StockBranch;
                        $branchStock->branch_id = $request->branchto;
                        $branchStock->product_master_id = $productid;
                        $branchStock->primary_qty = $totalqty;
                        $branchStock->secondary_qty = 0;
                        $branchStock->measure_finder = 0;
                        $branchStock->comments = 'Transfer ID: '.$transfer->id;
                        $branchStock->created_by = Auth::id();
                        $branchStock->save();
                    }
                }
                else
                {
                    if(Stock::where('product_master_id', $productid)->exists())
                    {
                        $mainstock = Stock::where('product_master_id', $productid)->first();
                        $mainstock->primary_qty = ($mainstock->primary_qty + $totalqty);
                        $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                        $mainstock->measure_finder = $mainstock->measure_finder;
                        $mainstock->save();
                    }
                    else
                    {
                        $mainstock = new Stock;
                        $mainstock->product_master_id = $productid;
                        $mainstock->primary_qty = $totalqty;
                        $mainstock->secondary_qty = 0;
                        $mainstock->measure_finder = 0;
                        $mainstock->save();
                    }
                }
            }
        }

        $query = CompanyProfile::query();
        $query->where('status', '1');
        $companys = $query->get();
        $companysFrom = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.stock.transferCreate', compact('companys', 'companysFrom'));
    }

    public function stockQuantityUpdate(Request $request)
    {
        $company = CompanyProfile::where('id', $request->branchID)->where('status', 1)->first();
        if($company->company_type == 1)
        {
            if(Stock::where('id', $request->row_id)->exists())
            {
                $mainstock = Stock::where('id', $request->row_id)->first();
                $stockadjust = new StockAdjust;
                $stockadjust->product_master_id = $mainstock->product_master_id;
                $stockadjust->opening_qty = $mainstock->primary_qty;
                $stockadjust->adjusted_qty = abs($mainstock->primary_qty - $request->primary_qty);
                $stockadjust->closing_qty = $request->primary_qty;
                $stockadjust->created_by = Auth::id();
                $stockadjust->save();

                $mainstock->primary_qty = $request->primary_qty;
                $mainstock->secondary_qty = $request->secondary_qty;
                $mainstock->save();
                return response()->json(['success' => true, 'message' => 'Stock Updated.'], 200);
            }
            else
            {
                return response()->json(['success' => false, 'message' => 'Stock not exist.'], 400);
            }
        }
        else
        {
            if(StockBranch::where('id', $request->row_id)->where('branch_id', $request->branchID)->exists())
            {
                $mainstock = StockBranch::where('id', $request->row_id)->where('branch_id', $request->branchID)->first();
                $mainstock->primary_qty = $request->primary_qty;
                $mainstock->secondary_qty = $request->secondary_qty;
                $mainstock->save();
                return response()->json(['success' => true, 'message' => 'Stock Updated.'], 200);
            }
            else
            {
                return response()->json(['success' => false, 'message' => 'Stock not exist.'], 400);
            }
        }
    }

}
