<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CompanyProfile;
use App\Models\CustomerMaster;
use App\Models\Transaction;
use App\Models\Ledger;
use App\Models\Sale;
use App\Models\Purchase;
use Rmunate\Utilities\SpellNumber;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class TransactionController extends Controller
{
    public function index($type)
    {
        if($type == 3)
        {
            $pageTitle = 'Receipt';
        }
        elseif($type == 4)
        {
            $pageTitle = 'Payment';
        }
        elseif($type == 5)
        {
            $pageTitle = 'Opening Balance';
        }
        elseif($type == 9)
        {
            $pageTitle = 'Debit Note';
        }
        elseif($type == 10)
        {
            $pageTitle = 'Credit Note';
        }
        else
        {
            $pageTitle = 'Transaction';
        }

        $transactions = Transaction::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                            $query->where('branch_id', Auth::user()->employee->branch->id);
                        })->where('transaction_type', $type)->latest()->get();
        return view('admin.transaction.index', compact('type', 'pageTitle', 'transactions'));
    }

    public function transactionReceipt($type)
    {
        if($type == 3)
        {
            $pageTitle = 'Receipt';
        }
        elseif($type == 4)
        {
            $pageTitle = 'Payment';
        }
        elseif($type == 5)
        {
            $pageTitle = 'Opening Balance';
        }
        elseif($type == 9)
        {
            $pageTitle = 'Debit Note';
        }
        elseif($type == 10)
        {
            $pageTitle = 'Credit Note';
        }
        else
        {
            $pageTitle = 'Transaction';
        }
        $ledgers = Ledger::latest()->get();

        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.transaction.create', compact('type', 'pageTitle', 'companys', 'ledgers'));
    }

    public function transactionPayment($type)
    {
        if($type == 3)
        {
            $pageTitle = 'Receipt';
        }
        elseif($type == 4)
        {
            $pageTitle = 'Payment';
        }
        elseif($type == 5)
        {
            $pageTitle = 'Opening Balance';
        }
        elseif($type == 9)
        {
            $pageTitle = 'Debit Note';
        }
        elseif($type == 10)
        {
            $pageTitle = 'Credit Note';
        }
        else
        {
            $pageTitle = 'Transaction';
        }
        $ledgers = Ledger::latest()->get();

        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.transaction.create', compact('type', 'pageTitle', 'companys', 'ledgers'));
    }

    public function calculateDueAmount(Request $request)
    {
        try
        {
            if(empty($request->customer_id) || empty($request->branch_id))
            {
                return response()->json(['success' => true, 'amount' => 0.00, 'payableStatus' => 'DF'], 200);
            }

            $transaction = Transaction::where('customer_id', $request->customer_id)->where('branch_id', $request->branch_id)->selectRaw('sum(credit_amount) as credit_amount, sum(debit_amount) as debit_amount')->get();
            $dueAmount = ($transaction[0]->credit_amount - $transaction[0]->debit_amount);

            if($dueAmount > 0)
            {
                $amountPayableStatus = 'DT';
            }
            else
            {
                $amountPayableStatus = 'DF';
            }

            $dueAmount = abs($dueAmount);

            return response()->json(['success' => true, 'amount' => $dueAmount, 'payableStatus' => $amountPayableStatus], 200);
        } catch (Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()], 400);
        }
    }

    public function store(Request $request)
    {
        try
        {
            $refinvoice = null;
            $parentID = 0;
            $parentTable = 0;
            if($request->referenceType == 'Sale')
            {
                $parentID = Sale::where('invoice_no', $request->sale_invoice)->where('payment_pode', 'Credit')->first()->id;
                $refinvoice = $request->sale_invoice;
                $parentTable = 1;
            }
            elseif($request->referenceType == 'Purchase')
            {
                $parentID = Purchase::where('invoice_no', $request->purchase_invoice)->where('payment_pode', 'Credit')->first()->id;
                $refinvoice = $request->purchase_invoice;
                $parentTable = 2;
            }
            else
            {
                $refinvoice = null;
            }

            $transaction = new Transaction;
            $transaction->transaction_no = strtoupper(uniqid());
            $transaction->ledger_id = (isset($request->ledgers) && !empty($request->ledgers)) ? $request->ledgers : null;
            $transaction->transaction_date = $request->inputDate;
            $transaction->parent_table_id = $parentID;
            $transaction->parent_table = $parentTable;
            $transaction->customer_id = (isset($request->customer) && !empty($request->customer)) ? $request->customer : null;
            $transaction->branch_id = $request->branch;
            $transaction->transaction_type = $request->transType;
            $transaction->payment_type = $request->payMode;
            if($request->transType == 3)
            {
                $transaction->credit_amount = $request->transAmount;
                $transaction->debit_amount = 0;
            }
            elseif($request->transType == 4)
            {
                $transaction->credit_amount = 0;
                $transaction->debit_amount = $request->transAmount;
            }
            elseif($request->transType == 9)
            {
                 $transaction->credit_amount = $request->transAmount;
                 $transaction->debit_amount = 0;
                
            }
            elseif($request->transType == 10)
            {
                $transaction->credit_amount = 0;
                $transaction->debit_amount = $request->transAmount;
            }
            elseif($request->transType == 5)
            {
                if($request->transactionType == 1)
                {
                    $transaction->credit_amount = $request->transAmount;
                    $transaction->debit_amount = 0;
                }
                else
                {
                    $transaction->credit_amount = 0;
                    $transaction->debit_amount = $request->transAmount;
                }
            }
            $transaction->payment_details = ['modeno' => $request->chequeNo, 'modedate' => $request->chequeDate];
            $transaction->description = $request->transDescription;

            $transaction->reference_type = $request->referenceType;
            $transaction->reference_invoice_no = $refinvoice;

            $transaction->created_by = Auth::id();
            $transaction->save();
            if($request->transType == 3)
            {
                return redirect()->route('transactions.receipt.list', $request->transType)->with('success', 'Transaction Updated.');
            }
            else
            {
                return redirect()->route('transactions.payment.list', $request->transType)->with('success', 'Transaction Updated.');
            }
        } catch (Exception $e) {
            if($request->transType == 3)
            {
                return redirect()->route('transactions.receipt.list', $request->transType)->with('error', $e->getMessage());
            }
            else
            {
                return redirect()->route('transactions.payment.list', $request->transType)->with('error', $e->getMessage());
            }
        }
    }

    public function edit(Transaction $transaction)
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        $customers = CustomerMaster::where('activestatus', true)->get();
        //new \Illuminate\Http\Request
        $request = new Request(['customer_id' => $transaction->customer_id, 'branch_id' => $transaction->branch_id]);
        $dueAmountRequest = $this->calculateDueAmount($request);
        if($dueAmountRequest->getData()->success)
        {
            $dueAmount = $dueAmountRequest->getData()->amount;
        }
        else
        {
            $dueAmount = 0.00;
        }

        if($dueAmount > 0)
        {
            $amountPayableStatus = 'DT';
        }
        else
        {
            $amountPayableStatus = 'DF';
        }
        $dueAmount = abs($dueAmount);
        $ledgers = Ledger::latest()->get();

        return view('admin.transaction.edit', compact('transaction', 'companys', 'customers', 'dueAmount', 'amountPayableStatus', 'ledgers'));
    }

    public function update(Request $request, Transaction $transaction)
    {
        try
        {
            $parentID = 0;
            $parentTable = 0;
            if($request->referenceType == 'Sale')
            {
                $parentID = Sale::where('invoice_no', $request->sale_invoice)->where('payment_pode', 'Credit')->first()->id;
                $refinvoice = $request->sale_invoice;
                $parentTable = 1;
            }
            elseif($request->referenceType == 'Purchase')
            {
                $parentID = Purchase::where('invoice_no', $request->purchase_invoice)->where('payment_pode', 'Credit')->first()->id;
                $refinvoice = $request->purchase_invoice;
                $parentTable = 2;
            }
            else
            {
                $refinvoice = null;
            }

            $transaction->ledger_id = (isset($request->ledgers) && !empty($request->ledgers)) ? $request->ledgers : null;
            $transaction->transaction_date = $request->inputDate;
            $transaction->parent_table_id = $parentID;
            $transaction->parent_table = $parentTable;
            $transaction->customer_id = (isset($request->customer) && !empty($request->customer)) ? $request->customer : null;
            $transaction->branch_id = $request->branch;
            $transaction->transaction_type = $request->transType;
            $transaction->payment_type = $request->payMode;
            if($request->transType == 3)
            {
                $transaction->credit_amount = $request->transAmount;
                $transaction->debit_amount = 0;
            }
            elseif($request->transType == 4)
            {
                $transaction->credit_amount = 0;
                $transaction->debit_amount = $request->transAmount;
            }
            elseif($request->transType == 9)
            {
               
                $transaction->credit_amount = $request->transAmount;
                $transaction->debit_amount = 0;
            }
            elseif($request->transType == 10)
            {
                 $transaction->credit_amount = 0;
                $transaction->debit_amount = $request->transAmount;           
            }
            elseif($request->transType == 5)
            {
                if($request->transactionType == 1)
                {
                    $transaction->credit_amount = $request->transAmount;
                    $transaction->debit_amount = 0;
                }
                else
                {
                    $transaction->credit_amount = 0;
                    $transaction->debit_amount = $request->transAmount;
                }
            }
            $transaction->payment_details = ['modeno' => $request->chequeNo, 'modedate' => $request->chequeDate];
            $transaction->description = $request->transDescription;
            

            $transaction->reference_type = $request->referenceType;
            $transaction->reference_invoice_no = $refinvoice;
            $transaction->created_by = Auth::id();
            $transaction->save();

            return redirect()->route('transactions.index', $request->transType)->with('success', 'Transaction Updated.');
        }
        catch (\Exception $e)
        {
            return redirect()->route('transactions.index', $request->transType)->with('error', $e->getMessage());
        }
    }

    public function transactionPrint($id)
    {
        if(Auth::user()->hasRole('Super Admin'))
        {
            $companys = CompanyProfile::where('status', 1)->where('company_type', 1)->get()->toArray();
        }
        else
        {
            $companys[] = Auth::user()->employee->branch->toArray();
        }

        $transaction = Transaction::find($id);
        $pagedata = $companys;
        //$totalamt = ($transaction->transaction_type == 3)?$transaction->credit_amount:$transaction->debit_amount;
        if($transaction->transaction_type == 5)
        {
            if($transaction->credit_amount > 0)
            {
                $totalamt = $transaction->credit_amount;
            }
            elseif($transaction->debit_amount > 0)
            {
                $totalamt = $transaction->debit_amount;
            }
        }
        elseif($transaction->transaction_type == 3)
        {
            $totalamt = $transaction->credit_amount;
        }
        else
        {
            $totalamt = $transaction->debit_amount;
        }
        $transaction['amountInWords'] = SpellNumber::value($totalamt)->locale('en')->currency('Rupees')->fraction('Paise')->toMoney();
        $transaction['amountTotal'] = $totalamt;
        return view('admin.report.invoice.receiptList', compact('pagedata', 'transaction'));
    }

    public function sundryCreditor()
    {
        $transactions = Transaction::with('branch', 'customer')->has('customer')->selectRaw('sum(credit_amount) as credit_amount, sum(debit_amount) as debit_amount, customer_id, branch_id')->groupBy('customer_id', 'branch_id')->get();
        $dueAmount = ($transactions[0]->credit_amount - $transactions[0]->debit_amount);

        $dueAmount = abs($dueAmount);
        $pageTitle = 'Sundry Creditor';
        return view('admin.transaction.sundryCreditor', compact('pageTitle', 'transactions'));
    }

    public function sundryDebtor()
    {
        $transactions = Transaction::with('branch', 'customer')->has('customer')->selectRaw('sum(credit_amount) as credit_amount, sum(debit_amount) as debit_amount, customer_id, branch_id')->groupBy('customer_id', 'branch_id')->get();
        $dueAmount = ($transactions[0]->credit_amount - $transactions[0]->debit_amount);

        $dueAmount = abs($dueAmount);
        $pageTitle = 'Sundry Debtor';
        return view('admin.transaction.sundryDebtor', compact('pageTitle', 'transactions'));
    }

    public function sundryCreditorDueReport()
    {
        $transactions = Transaction::with('branch', 'customer')->has('customer')->selectRaw('sum(credit_amount) as credit_amount, sum(debit_amount) as debit_amount, customer_id, branch_id')->groupBy('customer_id', 'branch_id')->get();
        $pageTitle = 'Due Report';
        return view('admin.transaction.dueReport', compact('pageTitle', 'transactions'));
    }

    public function getSundryCreditor($id)
    {
        $customer = $id;
        $companys = CompanyProfile::where('status', 1)->where('id', 1)->first();
        $transactionList = Transaction::with('customer')->has('customer')->where('customer_id', $customer)->get()->toArray();
        if(!empty($transactionList))
        {
            $pagedata['companys'] = $companys;
            $pagedata['dates'] = 'From Begining';
            $invoice = $transactionList;
            return view('admin.report.transaction.transactionList', compact('pagedata', 'invoice'));
        }
        else
        {
            return redirect()->back()->with('error', 'No record found.');   
        }
    }

    public function dayBook()
    {
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.transaction.dayBook', compact('companys'));
    }

    public function purchaseAutocompleteInvoice(Request $request)
    {
        $searchvalue = $request->get('search');
        $data = Purchase::where('invoice_no', 'LIKE', '%'. $searchvalue. '%')->where('payment_pode', 'Credit')->get();
        return response()->json($data);
    }

    public function salesAutocompleteInvoice(Request $request)
    {
        $searchvalue = $request->get('search');
        $data = Sale::where('invoice_no', 'LIKE', '%'. $searchvalue. '%')->where('payment_pode', 'Credit')->get();
        return response()->json($data);
    }

    public function searchDayBook(Request $request)
    {
        $toDate = $request->todate;
        $branchId = $request->branch;

        $transactionLists = Transaction::query()
        ->whereDate('transaction_date', $toDate)
        ->where('branch_id', $branchId)
        ->leftJoin('ledgers', 'transactions.ledger_id', '=', 'ledgers.id')
        ->leftJoin('account_groups', 'ledgers.account_group_id', '=', 'account_groups.id')
        ->with(['branch', 'customer'])
        ->select(
            DB::raw("CASE 
                        WHEN transactions.ledger_id IS NULL THEN CONCAT(CAST(transactions.transaction_type AS CHAR), ' | ', CAST(transactions.parent_table AS CHAR))
                        ELSE account_groups.name 
                     END as group_key"),
            DB::raw('SUM(transactions.credit_amount) as total_credit_amount'),
            DB::raw('SUM(transactions.debit_amount) as total_debit_amount'),
            DB::raw('COUNT(transactions.id) as transaction_count'),
            DB::raw('SUM(CASE 
                        WHEN transactions.transaction_type IN (1, 2) THEN 
                            CASE WHEN transactions.credit_amount = transactions.debit_amount THEN transactions.credit_amount ELSE 0 END
                        WHEN transactions.transaction_type = 3 THEN 0
                        ELSE transactions.credit_amount + transactions.debit_amount 
                     END) as conditional_sum'),
            'transactions.transaction_type',
            'transactions.parent_table',
            'account_groups.name as account_group_name'
        )
        ->groupBy(
            DB::raw("CASE 
                        WHEN transactions.ledger_id IS NULL THEN CONCAT(CAST(transactions.transaction_type AS CHAR), ' | ', CAST(transactions.parent_table AS CHAR))
                        ELSE account_groups.name 
                     END"),
            'transactions.transaction_type',
            'transactions.parent_table',
            'account_groups.name'
        )
        ->get();

        $selcompany = array();
        if(isset($request->branch) && !empty($request->branch))
        {
            $selcompany = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->find($request->branch)->name;
        }
        else
        {
            $selcompany = 'All';
        }

        $reports['branch'] = $selcompany;
        $reports['dates'] = date("d-m-Y", strtotime($toDate)); // date("d-m-Y", strtotime($fromDate)).' - '.date("d-m-Y", strtotime($toDate));
        $companys = CompanyProfile::when((!Auth::user()->hasRole('Super Admin') && Auth::user()->employee->branch->company_type == 2), function ($query) {
                        $query->where('id', Auth::user()->employee->branch->id);
                    })->where('status', 1)->get();
        return view('admin.report.transaction.dayBook', compact('companys', 'reports', 'transactionLists'));
    }
}
