<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Vehicle;
use Illuminate\Support\Facades\Auth;

class VehicleController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $vehicles = Vehicle::get();
        return view('admin.vehicle.index', compact('vehicles'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try
        {
            //$unserializeData = [];
            //parse_str($request->formsdata, $unserializeData);

            $validatedData = $request->validate([
              'vehicle_no' => 'required|unique:vehicles,reg_no|max:255',
              'vehicle_type' => 'required'
            ]);

            $save = new Vehicle;
            $save->reg_no = $request->vehicle_no;
            $save->type = $request->vehicle_type;
            $save->status = (isset($request->active_status) && $request->active_status == 1)? true : false;
            $save->created_by = Auth::id();
            $save ->save();
            return redirect()->route('vehicle.index')->with('success','Vehicle Created successfully');
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return redirect()->route('vehicle.index')->with('success', $errormessage);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Vehicle $vehicle)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Vehicle $vehicle)
    {
        return view('admin.vehicle.edit', compact('vehicle'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Vehicle $vehicle)
    {
        try
        {
            $vehicle->reg_no = $request->vehicle_no;
            $vehicle->type = $request->vehicle_type;
            $vehicle->status = (isset($request->active_status) && $request->active_status == 1)? true : false;
            $vehicle->save();
            return redirect()->route('vehicle.index')->with('success','Vehicle updated successfully');
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return redirect()->route('admin.vehicle.edit', $vehicle)->with('error', $errormessage);
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Vehicle $vehicle)
    {
        $vehicle->delete();
        return redirect()->route('vehicle.index')->with('success','Vehicle deleted successfully');
    }
}
