<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Vendor;
use App\Models\CustomerMaster;
use App\Http\Requests\Vendor\StoreVendorRequest;
use App\Http\Requests\Vendor\UpdateVendorRequest;
use App\Services\VendorService;

class VendorController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $vendors = CustomerMaster::where('supplierstatus', true)->get();
        return view('admin.vendor.index', compact('vendors'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.vendor.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreVendorRequest $request, VendorService $vendorservice)
    {
        try
        {
            $resultres = $vendorservice->store($request->only(['code', 'regional', 'name', 'emailid', 'mobile_no', 'phone', 'address', 'remarks', 'state_pos', 'area', 'gst_no', 'active_status']));
            if($resultres->getData()->success)
            {
                return redirect()->route('vendor.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('vendor.create')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('vendor.create')->with('error',$e->getMessage());
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(CustomerMaster $vendor)
    {
        return view('admin.vendor.view', compact('vendor'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(CustomerMaster $vendor)
    {
        return view('admin.vendor.edit', compact('vendor'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateVendorRequest $request, CustomerMaster $vendor, VendorService $vendorservice)
    {
        try
        {
            $resultres = $vendorservice->update($request->only(['code', 'regional', 'name', 'emailid', 'mobile_no', 'phone', 'address', 'remarks', 'state_pos', 'area', 'gst_no', 'active_status']), $vendor);
            if($resultres->getData()->success)
            {
                return redirect()->route('vendor.index')->with('success', $resultres->getData()->message);
            }
            else
            {
                return redirect()->route('vendor.edit')->with('error', $resultres->getData()->message);
            }
            
        }
        catch (\Exception $e)
        {
            return redirect()->route('vendor.edit')->with('error',$e->getMessage());
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(CustomerMaster $vendor)
    {
        $vendor->delete();
        return redirect()->route('vendor.index')->with('success','Vendor deleted successfully');
    }

    public function vendorSearch(Request $request)
    {
        $vendor = [];
        if($request->has('q')){
            $search = $request->q;
            $vendor = CustomerMaster::select("id", "name")
            ->where(function($query_titles) use ($search){
                $query_titles->where('name', 'like', '%'.$search.'%');
            })->where('supplierstatus', true)->where('activestatus', true)->get();
        }
        return response()->json($vendor);
    }

    public function vendorDetails(Request $request)
    {
        $vendor = CustomerMaster::select(["name", "address", "mobile"])->where('supplierstatus', true)->where('activestatus', true)->find($request->vendor_id);
        return response()->json($vendor);
    }
}
