<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;

class AccountGroup extends Model
{
    use HasFactory, SoftDeletes;

    protected $table = 'account_groups';

    public function parent()
    {
        return $this->belongsTo(AccountGroup::class, 'parent_id', 'id');
    }

    public function ledgers()
    {
        return $this->hasMany(Ledger::class, 'account_group_id', 'id');
    }

    public function getTransactionSumsGroupedByLedger($fromDate = null, $toDate = null, $month = null, $year = null)
    {
        $fromDate = $fromDate ? Carbon::parse($fromDate) : null;
        $toDate = $toDate ? Carbon::parse($toDate) : null;

        $ledgersWithSums = $this->ledgers()
            ->whereHas('transactions', function ($query) use ($fromDate, $toDate, $month, $year) {
                $query->when($fromDate, function ($q) use ($fromDate) {
                    $q->whereDate('transaction_date', '>=', $fromDate);
                })
                ->when($toDate, function ($q) use ($toDate) {
                    $q->whereDate('transaction_date', '<=', $toDate);
                })
                ->when($month, function ($q) use ($month) {
                    $q->whereMonth('transaction_date', $month);
                })
                ->when($year, function ($q) use ($year) {
                    $q->whereYear('transaction_date', $year);
                });
            })
            ->with(['transactions' => function ($query) use ($fromDate, $toDate, $month, $year) {
                $query->when($fromDate, function ($q) use ($fromDate) {
                    $q->whereDate('transaction_date', '>=', $fromDate);
                })
                ->when($toDate, function ($q) use ($toDate) {
                    $q->whereDate('transaction_date', '<=', $toDate);
                })
                ->when($month, function ($q) use ($month) {
                    $q->whereMonth('transaction_date', $month);
                })
                ->when($year, function ($q) use ($year) {
                    $q->whereYear('transaction_date', $year);
                })
                ->select('ledger_id', 
                         DB::raw('SUM(credit_amount) as total_credit_amount'), 
                         DB::raw('SUM(debit_amount) as total_debit_amount'))
                ->groupBy('ledger_id');
            }])
            ->get();

        return $ledgersWithSums->map(function ($ledger) use ($fromDate) {
            $beforeFromDate = $ledger->transactions()
                ->when($fromDate, function ($q) use ($fromDate) {
                    $q->whereDate('transaction_date', '<', $fromDate);
                })
                ->select('ledger_id', 
                         DB::raw('SUM(credit_amount) as total_credit_before_date'), 
                         DB::raw('SUM(debit_amount) as total_debit_before_date'))
                ->groupBy('ledger_id')
                ->first();

            return [
                'ledger' => $ledger,
                'total_credit_amount' => $ledger->transactions->first()->total_credit_amount ?? 0,
                'total_debit_amount' => $ledger->transactions->first()->total_debit_amount ?? 0,
                'total_credit_before_date' => $beforeFromDate->total_credit_before_date ?? 0,
                'total_debit_before_date' => $beforeFromDate->total_debit_before_date ?? 0,
            ];
        });
    }
}
