<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\DB;

class CustomerMaster extends Model
{
    use HasFactory, SoftDeletes;

    protected $table = 'customer_masters';

    public function state()
    {
        return $this->belongsTo(State::class, 'state_pos', 'id')->withTrashed();
    }

    public function area()
    {
        return $this->belongsTo(Area::class, 'area_id', 'id')->withTrashed();
    }

    public function allTransactions()
    {
        return $this->hasMany(Transaction::class, 'customer_id', 'id');
    }

    public function filteredAllTransactions()
    {
        return $this->allTransactions()
            ->select(
                'parent_table_id',
                'parent_table', 
                'reference_invoice_no',
                DB::raw('MIN(id) as id'),
                DB::raw('MIN(customer_id) as customer_id'),
                DB::raw('MIN(branch_id) as branch_id'),
                DB::raw('MIN(ledger_id) as ledger_id'),
                DB::raw('MIN(transaction_date) as transaction_date'),
                DB::raw('MIN(transaction_type) as transaction_type'),
                DB::raw('MIN(payment_type) as payment_type'),
                DB::raw('SUM(debit_amount) as debit_amount'),
                DB::raw('SUM(credit_amount) as credit_amount'),
                DB::raw('MIN(description) as description'),
                DB::raw('MIN(transaction_no) as transaction_no')
            )
            ->groupBy('parent_table_id', 'parent_table', 'reference_invoice_no')
            ->orderBy('transaction_date');
    }
}
