<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class ProductMaster extends Model
{
    use HasFactory, SoftDeletes;

    protected $table = 'product_masters';

    public function category()
    {
        return $this->belongsTo(Category::class, 'catagory_id', 'id')->withTrashed();
    }

    public function manufacturer()
    {
        return $this->belongsTo(Manufacturer::class, 'manufacturer_id', 'id')->withTrashed();
    }

    public function tax()
    {
        return $this->hasOne(ProductTax::class, 'product_master_id', 'id');
    }

    public function price()
    {
        return $this->hasOne(ProductPrice::class, 'product_master_id', 'id');
    }

    public function unit()
    {
        return $this->hasOne(ProductUnit::class, 'product_master_id', 'id');
    }

    public function billMaterial()
    {
        return $this->hasOne(BillOfMaterial::class, 'product_master_id', 'id');
    }

    public function stockqty()
    {
        return $this->hasOne(Stock::class, 'product_master_id', 'id');
    }

    public function productSales()
    {
        return $this->hasMany(SaleItem::class, 'product_master_id', 'id');
    }

    public function productPurchase()
    {
        return $this->hasMany(PurchaseDetails::class, 'product_master_id', 'id');
    }

    public function productSaleReturn()
    {
        return $this->hasMany(SalesItemReturn::class, 'product_master_id', 'id');
    }

    public function productPurchaseReturn()
    {
        return $this->hasMany(PurchaseReturnDetails::class, 'product_master_id', 'id');
    }
}
