<?php

namespace App\Services;
use App\Models\ProductMaster;
use App\Models\ProductPrice;
use App\Models\ProductTax;
use App\Models\ProductUnit;
use App\Models\Stock;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class ProductService {

    public function store(array $inputData)
    {
        try
        {
            $product = new ProductMaster;
            $product->code = strtoupper(preg_replace('/\s+/', '', $inputData['code']));
            $product->barcode = $inputData['barcode'];
            $product->name = $inputData['name'];
            $product->regionalname = $inputData['regionalname'];
            $product->catagory_id = $inputData['category'];
            $product->manufacturer_id = $inputData['manufacturer'];
            $product->hsncode = $inputData['hsn_code'];
            $product->rol = $inputData['rol'];
            $product->rack = $inputData['rack'];
            $product->expiry_status = (isset($inputData['expiry_item']) && $inputData['expiry_item'] == 1)? true : false;
            if(isset($inputData['expiry_date']) && !empty($inputData['expiry_date']))
            {
                $product->expiry = '';
            }
            $product->item_class = $inputData['item_class'];
            $product->sp_com = $inputData['spcom'];
            $product->remarks = $inputData['remarks'];
            $product->remarks_one = $inputData['remarks_one'];
            $product->remarks_two = $inputData['remarks_two'];
            $product->status = (isset($inputData['active_status']) && $inputData['active_status'] == 1)? true : false;
            $product->created_by = Auth::id();
            $product->save();

            //Tax
            $productTax = new ProductTax;
            $productTax->product_master_id = $product->id;
            $productTax->gst = $inputData['gstval'];
            $productTax->igst = $inputData['igstval'];
            $productTax->cess = $inputData['cessval'];
            $productTax->adcess = $inputData['addcessval'];
            $productTax->inclusive_sale = (isset($inputData['sale_incl']) && $inputData['sale_incl'] == 1)? true : false;
            $productTax->inclusive_purchase = (isset($inputData['purchase_incl']) && $inputData['purchase_incl'] == 1)? true : false;
            $productTax->save();

            //Price
            $productPrice = new ProductPrice;
            $productPrice->product_master_id = $product->id;
            $productPrice->purchase_rate = $inputData['purchase_rate'];
            $productPrice->sales_rate = $inputData['sale_rate'];
            $productPrice->mrp = $inputData['mrpval'];
            $productPrice->save();

            //Unit
            $productUnit = new ProductUnit;
            $productUnit->product_master_id = $product->id;
            $productUnit->unit = $inputData['unitval'];
            $productUnit->altr_unit = $inputData['alter_unit'];
            $productUnit->uc_factor = $inputData['ucfactor'];
            $productUnit->save();

            //Stock
            $productStock = new Stock;
            $productStock->product_master_id = $product->id;
            $productStock->primary_qty = $inputData['openstock'];
            $productStock->opening_stock = $inputData['openstock'];
            $productStock->save();
            
            return response()->json(['success' => true, 'message' => 'Product Created Successfully!', 'product' => $product], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    public function update(array $inputData, ProductMaster $product)
    {
        try
        {
            $product->code = strtoupper(preg_replace('/\s+/', '', $inputData['code']));
            $product->barcode = $inputData['barcode'];
            $product->name = $inputData['name'];
            $product->regionalname = $inputData['regionalname'];
            $product->catagory_id = $inputData['category'];
            $product->manufacturer_id = $inputData['manufacturer'];
            $product->hsncode = $inputData['hsn_code'];
            $product->rol = $inputData['rol'];
            $product->rack = $inputData['rack'];
            $product->expiry_status = (isset($inputData['expiry_item']) && $inputData['expiry_item'] == 1)? true : false;
            if(isset($inputData['expiry_date']) && !empty($inputData['expiry_date']))
            {
                $product->expiry = '';
            }
            $product->item_class = $inputData['item_class'];
            $product->sp_com = $inputData['spcom'];
            $product->remarks = $inputData['remarks'];
            $product->remarks_one = $inputData['remarks_one'];
            $product->remarks_two = $inputData['remarks_two'];
            $product->status = (isset($inputData['active_status']) && $inputData['active_status'] == 1)? true : false;
            //Tax
            $product->tax->product_master_id = $product->id;
            $product->tax->gst = $inputData['gstval'];
            $product->tax->igst = $inputData['igstval'];
            $product->tax->cess = $inputData['cessval'];
            $product->tax->adcess = $inputData['addcessval'];
            $product->tax->inclusive_sale = (isset($inputData['sale_incl']) && $inputData['sale_incl'] == 1)? true : false;
            $product->tax->inclusive_purchase = (isset($inputData['purchase_incl']) && $inputData['purchase_incl'] == 1)? true : false;
            //Price
            $product->price->product_master_id = $product->id;
            $product->price->purchase_rate = $inputData['purchase_rate'];
            $product->price->sales_rate = $inputData['sale_rate'];
            $product->price->mrp = $inputData['mrpval'];
            $product->price->cost = $inputData['costval'];
            //Unit
            $product->unit->product_master_id = $product->id;
            $product->unit->unit = $inputData['unitval'];
            $product->unit->altr_unit = $inputData['alter_unit'];
            $product->unit->uc_factor = $inputData['ucfactor'];
            $product->push();

            return response()->json(['success' => true, 'message' => 'Product Updated'], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    public function productSearch($request)
    {
        $name = $request->get('name');
        $fieldName =  $request->get('fieldName');
        $name = strtolower(trim($name));
        if(empty($fieldName))
        {
            $fieldName = 'name';
        }

        $filterResult = ProductMaster::with('price', 'tax', 'stockqty')->where(`LOWER(`.$fieldName.`)`, 'LIKE', "$name%")->limit(5)->get();
        //$filterResult = DB::table('product_masters')->join('product_prices', 'product_masters.id', '=', 'product_prices.product_master_id')->join('product_taxes', 'product_masters.id', '=', 'product_taxes.product_master_id')->join('stocks', 'product_masters.id', '=', 'stocks.product_master_id')->select('product_masters.*', 'product_prices.* as price', 'product_taxes.*', 'stocks.*')->where(`LOWER(`.$fieldName.`)`, 'LIKE', "$name%")->limit(5)->get();
        return response()->json($filterResult);
    }

    public function productSearchBOM($request)
    {
        $name = $request->get('name');
        $fieldName =  $request->get('fieldName');
        $name = strtolower(trim($name));
        if(empty($fieldName))
        {
            $fieldName = 'name';
        }

        $filterResult = ProductMaster::whereIn('item_class', ['2', '3'])->where(`LOWER(`.$fieldName.`)`, 'LIKE', "$name%")->limit(5)->get();
        return response()->json($filterResult);
    }
}