<?php

namespace App\Services;
use App\Models\ProductMaster;
use App\Models\ProductPrice;
use App\Models\ProductTax;
use App\Models\ProductUnit;
use App\Models\Stock;
use App\Models\Purchase;
use App\Models\PurchaseDetails;
use App\Models\StockBranch;
use App\Models\StockBranchPurchase;
use App\Models\PurchaseLog;
use App\Models\PurchaseReturn;
use App\Models\PurchaseReturnDetails;
use App\Models\StockBranchPurchaseReturn;
use App\Models\Transaction;

use Illuminate\Support\Facades\Auth;


class PurchaseService {

    public function store(array $inputData)
    {
        try
        {
            $purchase = new Purchase;
            $purchase->invoice_no = $inputData['invno'];
            $purchase->purchase_date = $inputData['billdate'];
            $purchase->payment_pode = $inputData['mop'];
            $purchase->tax_type = $inputData['tax'];
            $purchase->vendor_id = $inputData['vendor'];
            $purchase->branch_id = $inputData['branch'];
            $purchase->salesman_id = $inputData['sales_man'];
            $purchase->total_amount = (isset($inputData['grosstotal']) && !empty($inputData['grosstotal'])) ? $inputData['grosstotal'] : '0';
            $purchase->total_cgst_amount = (isset($inputData['cgstamt']) && !empty($inputData['cgstamt'])) ? $inputData['cgstamt'] : '0';
            $purchase->total_sgst_amount = (isset($inputData['sgstamt']) && !empty($inputData['sgstamt'])) ? $inputData['sgstamt'] : '0';
            $purchase->total_igst_amount = (isset($inputData['igstamt']) && !empty($inputData['igstamt'])) ? $inputData['igstamt'] : '0';
            $purchase->total_tax_amount = (isset($inputData['totaltax']) && !empty($inputData['totaltax'])) ? $inputData['totaltax'] : '0';
            $purchase->total_taxable_amt = (isset($inputData['taxable']) && !empty($inputData['taxable'])) ? $inputData['taxable'] : '0';
            $purchase->total_discount_percentage = (isset($inputData['discountfinal']) && !empty($inputData['discountfinal'])) ? $inputData['discountfinal'] : '0';
            $purchase->total_discount_amount = (isset($inputData['discountfinalamt']) && !empty($inputData['discountfinalamt'])) ? $inputData['discountfinalamt'] : '0';
            $purchase->exempted = (isset($inputData['exempted']) && !empty($inputData['exempted'])) ? $inputData['exempted'] : '0';
            $purchase->total_item_discount = (isset($inputData['itemdiscount']) && !empty($inputData['itemdiscount'])) ? $inputData['itemdiscount'] : '0';
            $purchase->purchase_total = (isset($inputData['purchasevalue']) && !empty($inputData['purchasevalue'])) ? $inputData['purchasevalue'] : '0';
            $purchase->netvalue = (isset($inputData['netvalue']) && !empty($inputData['netvalue'])) ? $inputData['netvalue'] : '0';
            $purchase->cess = (isset($inputData['cessamt']) && !empty($inputData['cessamt'])) ? $inputData['cessamt'] : '0';
            $purchase->add_cess = (isset($inputData['addcess']) && !empty($inputData['addcess'])) ? $inputData['addcess'] : '0';
            $purchase->freight_coolie = (isset($inputData['freightcoolie']) && !empty($inputData['freightcoolie'])) ? $inputData['freightcoolie'] : '0';
            $purchase->otherexp = (isset($inputData['otherexp']) && !empty($inputData['otherexp'])) ? $inputData['otherexp'] : '0';
            $purchase->cost_factor = (isset($inputData['costfactor']) && !empty($inputData['costfactor'])) ? $inputData['costfactor'] : '0';
            $purchase->cash_discount = (isset($inputData['cashdisc']) && !empty($inputData['cashdisc'])) ? $inputData['cashdisc'] : '0';
            $purchase->round_off = (isset($inputData['roundval']) && !empty($inputData['roundval'])) ? $inputData['roundval'] : '0';
            $purchase->tcs_amount = (isset($inputData['tcsvalue']) && !empty($inputData['tcsvalue'])) ? $inputData['tcsvalue'] : '0';
            $purchase->grand_total = (isset($inputData['finalamount']) && !empty($inputData['finalamount'])) ? $inputData['finalamount'] : '0';

            $purchase->status = true;
            $purchase->created_by = Auth::id();
            $purchase->save();

            
            if($purchase->branch->company_type == 2)
            {
                $purchase->approve_status = true;
                $purchase->save();
            }

            $transaction = new Transaction;
            $transaction->transaction_no = strtoupper(uniqid());
            $transaction->transaction_date = $purchase->purchase_date;
            $transaction->parent_table_id = $purchase->id;
            $transaction->customer_id = $purchase->vendor_id;
            $transaction->branch_id = $purchase->branch_id;
            $transaction->parent_table = 2;
            $transaction->transaction_type = 2;
            $transaction->payment_type = 1;
            if($purchase->payment_pode == 'Credit')
            {
                $transaction->credit_amount = $purchase->grand_total;
                $transaction->debit_amount = 0;
            }
            else
            {
                $transaction->credit_amount = $purchase->grand_total;
                $transaction->debit_amount = $purchase->grand_total;
            }
            
            $transaction->description = 'Purchase';
            $transaction->reference_invoice_no = $purchase->invoice_no;
            $transaction->reference_type = 'Purchase';
            $transaction->created_by = Auth::id();
            $transaction->save();

            foreach($inputData['prdid'] as $key => $productid)
            {
                if(ProductMaster::where('id', $productid)->exists())
                {
                    $product = ProductMaster::find($productid);
                    $purchaseDetails = new PurchaseDetails;
                    $purchaseDetails->purchase_id = $purchase->id;
                    $purchaseDetails->product_master_id = $productid;
                    $purchaseDetails->quantity = $inputData['quantity'][$key];
                    $purchaseDetails->free_quantity = $inputData['freequantity'][$key];
                    $purchaseDetails->rate = $inputData['purchase_rate'][$key];
                    $purchaseDetails->cost = $inputData['cost'][$key];
                    $purchaseDetails->sale_rate = $inputData['salerate'][$key];
                    $purchaseDetails->mrp = $inputData['mrp'][$key];
                    $purchaseDetails->gross_amt = $inputData['taxableamt'][$key];
                    $purchaseDetails->discount_percentage = $inputData['disc_per'][$key];
                    $purchaseDetails->discount_amount = $inputData['disc_amt'][$key];
                    $purchaseDetails->taxable_amt = $inputData['taxablerow'][$key];
                    $purchaseDetails->cgst = $inputData['cgst'][$key];
                    $purchaseDetails->cgst_amount = $inputData['cgst_amt'][$key];
                    $purchaseDetails->sgst = $inputData['sgst'][$key];
                    $purchaseDetails->sgst_amount = $inputData['sgst_amt'][$key];
                    $purchaseDetails->item_total = $inputData['total'][$key];
                    $purchaseDetails->save();

                    if($product->price->purchase_rate < $inputData['purchase_rate'][$key])
                    {
                        $product->price->cost = $inputData['cost'][$key];
                        $product->price->mrp = $inputData['mrp'][$key];
                        $product->price->sales_rate = $inputData['salerate'][$key];
                        $product->price->purchase_rate = $inputData['purchase_rate'][$key];
                        $product->price->save();
                        $product->save();

                        ProductPrice::where('product_master_id', $productid)->update(['purchase_rate' => $inputData['purchase_rate'][$key], 'cost' => $inputData['cost'][$key], 'mrp' => $inputData['mrp'][$key], 'sales_rate' => $inputData['salerate'][$key], 'price1' => $inputData['salerate'][$key], 'price2' => $inputData['salerate'][$key], 'price3' => $inputData['salerate'][$key]]);
                    }

                    $totalqty = ((float) $inputData['quantity'][$key] + (float) $inputData['freequantity'][$key]);
                    if($purchase->branch->company_type == 2)
                    {
                        if($this->checkUseris())
                        {
                            if(StockBranch::where('branch_id', $inputData['branch'])->where('product_master_id', $productid)->exists())
                            {
                                $currentstock = StockBranch::where('branch_id', $inputData['branch'])->where('product_master_id', $productid)->first();
                                $currentstock->primary_qty = ($currentstock->primary_qty + $totalqty);
                                $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                                $currentstock->measure_finder = $currentstock->measure_finder;
                                $currentstock->save();
                            }
                            else
                            {
                                $branchStock = new StockBranch;
                                $branchStock->branch_id = $inputData['branch'];
                                $branchStock->product_master_id = $productid;
                                $branchStock->primary_qty = $totalqty;
                                $branchStock->secondary_qty = 0;
                                $branchStock->measure_finder = 0;
                                $branchStock->comments = $inputData['invno'];
                                $branchStock->created_by = Auth::id();
                                $branchStock->save();
                            }
                        }

                        $branchpurchase = StockBranchPurchase::create([
                            'branch_id' => $inputData['branch'],
                            'product_master_id' => $productid,
                            'quantity' => $totalqty,
                            'purchase_id' => $purchase->id,
                            'created_by' => Auth::id(),
                        ]);
                    }
                    else
                    {
                        if(Stock::where('product_master_id', $productid)->exists())
                        {
                            $mainstock = Stock::where('product_master_id', $productid)->first();
                            $mainstock->primary_qty = ($mainstock->primary_qty + $totalqty);
                            $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                            $mainstock->measure_finder = $mainstock->measure_finder;
                            $mainstock->save();
                        }
                        else
                        {
                            $mainstock = new Stock;
                            $mainstock->product_master_id = $productid;
                            $mainstock->primary_qty = $totalqty;
                            $mainstock->secondary_qty = 0;
                            $mainstock->measure_finder = 0;
                            $mainstock->save();
                        }
                    }

                    $log = PurchaseLog::create(['purchase_id' => $purchase->id, 'created_by' =>  Auth::id(), 'product_master_id' => $productid, 'comment' => 'Made new purchase.']);
                }
                else
                {
                    return response()->json(['success' => false, 'message' => 'Product not exist'], 400);
                }
            }
            
            return response()->json(['success' => true, 'message' => 'Purchase Created Successfully!', 'product' => $product], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    public function checkUseris()
    {
        if(Auth::user()->hasRole('Super Admin'))
        {
            return true;
        }
        elseif(Auth::user()->employee->branch->company_type == 1)
        {
            return true;
        }
        else
        {
            return false;
        }
    }

    public function approveData(array $inputData)
    {
        try
        {
            $purchaseid = base64_decode($inputData['refval']);
            if(Purchase::where('id', $purchaseid)->exists())
            {
                $purchase = Purchase::find($purchaseid);
                if($purchase->approve_status)
                {
                    $purchaseDetails = PurchaseDetails::where('purchase_id', $purchaseid)->get();
                    if($purchase->branch->company_type == 2)
                    {
                        foreach($purchaseDetails as $key => $purchaseDetail)
                        {
                            $totalqty = ((float) $purchaseDetail->quantity + (float) $purchaseDetail->freequantity);
                            if(StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $purchaseDetail->product_master_id)->exists())
                            {
                                $currentstock = StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $purchaseDetail->product_master_id)->first();
                                $currentstock->primary_qty = ($currentstock->primary_qty + $totalqty);
                                $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                                $currentstock->measure_finder = $currentstock->measure_finder;
                                $currentstock->save();
                            }
                            else
                            {
                                $branchStock = new StockBranch;
                                $branchStock->branch_id = $purchase->branch_id;
                                $branchStock->product_master_id = $purchaseDetail->product_master_id;
                                $branchStock->primary_qty = $totalqty;
                                $branchStock->secondary_qty = 0;
                                $branchStock->measure_finder = 0;
                                $branchStock->comments = $purchase->invoice_no;
                                $branchStock->created_by = Auth::id();
                                $branchStock->save();
                            }

                            $log = PurchaseLog::create(['purchase_id' => $purchaseid, 'created_by' =>  Auth::id(), 'product_master_id' => $purchaseDetail->product_master_id, 'comment' => 'Approved a purchase.']);
                        }
                        $purchase->approve_status = false;
                        $purchase->save();

                    }
                    return response()->json(['success' => true, 'message' => 'Purchase Approved Successfully!'], 200);
                }
                else
                {
                    return response()->json(['success' => false, 'message' => 'Invalid Status.'], 400);
                }
            }
            else
            {
                return response()->json(['success' => false, 'message' => 'Invalid Purchase.'], 400);
            }
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    public function update(array $inputData, Purchase $purchase)
    {
        try
        {
            $purchase->invoice_no = $inputData['invno'];
            $purchase->purchase_date = $inputData['billdate'];
            $purchase->payment_pode = $inputData['mop'];
            $purchase->tax_type = $inputData['tax'];
            $purchase->vendor_id = $inputData['vendor'];
            $purchase->branch_id = $inputData['branch'];
            $purchase->salesman_id = $inputData['sales_man'];
            $purchase->total_amount = (isset($inputData['grosstotal']) && !empty($inputData['grosstotal'])) ? $inputData['grosstotal'] : '0';
            $purchase->total_cgst_amount = (isset($inputData['cgstamt']) && !empty($inputData['cgstamt'])) ? $inputData['cgstamt'] : '0';
            $purchase->total_sgst_amount = (isset($inputData['sgstamt']) && !empty($inputData['sgstamt'])) ? $inputData['sgstamt'] : '0';
            $purchase->total_igst_amount = (isset($inputData['igstamt']) && !empty($inputData['igstamt'])) ? $inputData['igstamt'] : '0';
            $purchase->total_tax_amount = (isset($inputData['totaltax']) && !empty($inputData['totaltax'])) ? $inputData['totaltax'] : '0';
            $purchase->total_taxable_amt = (isset($inputData['taxable']) && !empty($inputData['taxable'])) ? $inputData['taxable'] : '0';
            $purchase->total_discount_percentage = (isset($inputData['discountfinal']) && !empty($inputData['discountfinal'])) ? $inputData['discountfinal'] : '0';
            $purchase->total_discount_amount = (isset($inputData['discountfinalamt']) && !empty($inputData['discountfinalamt'])) ? $inputData['discountfinalamt'] : '0';
            $purchase->exempted = (isset($inputData['exempted']) && !empty($inputData['exempted'])) ? $inputData['exempted'] : '0';
            $purchase->total_item_discount = (isset($inputData['itemdiscount']) && !empty($inputData['itemdiscount'])) ? $inputData['itemdiscount'] : '0';
            $purchase->purchase_total = (isset($inputData['purchasevalue']) && !empty($inputData['purchasevalue'])) ? $inputData['purchasevalue'] : '0';
            $purchase->netvalue = (isset($inputData['netvalue']) && !empty($inputData['netvalue'])) ? $inputData['netvalue'] : '0';
            $purchase->cess = (isset($inputData['cessamt']) && !empty($inputData['cessamt'])) ? $inputData['cessamt'] : '0';
            $purchase->add_cess = (isset($inputData['addcess']) && !empty($inputData['addcess'])) ? $inputData['addcess'] : '0';
            $purchase->freight_coolie = (isset($inputData['freightcoolie']) && !empty($inputData['freightcoolie'])) ? $inputData['freightcoolie'] : '0';
            $purchase->otherexp = (isset($inputData['otherexp']) && !empty($inputData['otherexp'])) ? $inputData['otherexp'] : '0';
            $purchase->cost_factor = (isset($inputData['costfactor']) && !empty($inputData['costfactor'])) ? $inputData['costfactor'] : '0';
            $purchase->cash_discount = (isset($inputData['cashdisc']) && !empty($inputData['cashdisc'])) ? $inputData['cashdisc'] : '0';
            $purchase->round_off = (isset($inputData['roundval']) && !empty($inputData['roundval'])) ? $inputData['roundval'] : '0';
            $purchase->tcs_amount = (isset($inputData['tcsvalue']) && !empty($inputData['tcsvalue'])) ? $inputData['tcsvalue'] : '0';
            $purchase->grand_total = (isset($inputData['finalamount']) && !empty($inputData['finalamount'])) ? $inputData['finalamount'] : '0';
            $purchase->save();

            if(Transaction::where('branch_id', $purchase->branch_id)->where('parent_table', 2)->where('parent_table_id', $purchase->id)->exists())
            {
                $transaction = Transaction::where('branch_id', $purchase->branch_id)->where('parent_table', 2)->where('parent_table_id', $purchase->id)->first();
                $transaction->customer_id = $purchase->vendor_id;
                $transaction->transaction_date = $purchase->purchase_date;
                if($purchase->payment_pode == 'Credit')
                {
                    $transaction->credit_amount = $purchase->grand_total;
                    $transaction->debit_amount = 0;
                }
                else
                {
                    $transaction->credit_amount = $purchase->grand_total;
                    $transaction->debit_amount = $purchase->grand_total;
                }
                $transaction->save();
            }

            $removedItems = PurchaseDetails::where('purchase_id', $purchase->id)->whereNotIn('id', $inputData['tblid'])->get();
            if($removedItems)
            {
                foreach($removedItems as $removedItem)
                {
                    $totalqty = ((float) $removedItem->quantity + (float) $removedItem->free_quantity);
                    if($purchase->branch->company_type == 2)
                    {
                        if(StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $currentstock = StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $removedItem->product_master_id)->first();
                            $currentstock->primary_qty = ($currentstock->primary_qty - $totalqty);
                            $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                            $currentstock->measure_finder = $currentstock->measure_finder;
                            $currentstock->save();
                        }
                    }
                    else
                    {
                        if(Stock::where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $mainstock = Stock::where('product_master_id', $removedItem->product_master_id)->first();
                            $mainstock->primary_qty = ($mainstock->primary_qty - $totalqty);
                            $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                            $mainstock->measure_finder = $mainstock->measure_finder;
                            $mainstock->save();
                        }
                    }
                    $log = PurchaseLog::create(['purchase_id' => $purchase->id, 'created_by' =>  Auth::id(), 'product_master_id' => $removedItem->product_master_id, 'comment' => 'Removed item.']);
                    $removedItem->delete();
                }
            }

            foreach($inputData['tblid'] as $key => $tableid)
            {
                if(PurchaseDetails::where('id', $tableid)->exists())
                {
                    $purchaseItems = PurchaseDetails::with('product','product.price')->where('purchase_id', $purchase->id)->find($tableid);
                    if(ProductMaster::where('id', $purchaseItems->product_master_id)->exists())
                    {
                        $totalqty = ((float) $inputData['quantity'][$key] + (float) $inputData['freequantity'][$key]);
                        $totalqtyexist = ((float) $purchaseItems->quantity + (float) $purchaseItems->free_quantity);
                        if($purchase->branch->company_type == 2)
                        {
                            $currentstock = StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $purchaseItems->product_master_id)->first();
                            if($totalqtyexist >= $totalqty)
                            {
                                $quantitys = abs($totalqtyexist - $totalqty);
                                $quantitys = ($currentstock->primary_qty - $quantitys);
                            }
                            else
                            {
                                $quantitys = abs($totalqty - $totalqtyexist);
                                $quantitys = ($currentstock->primary_qty + $quantitys);
                            }
                            $currentstock->primary_qty = $quantitys;
                            $currentstock->save();
                        }
                        else
                        {
                            $mainstock = Stock::where('product_master_id', $purchaseItems->product_master_id)->first();
                            if($totalqtyexist >= $totalqty)
                            {
                                $quantitys = abs($totalqty - $totalqtyexist);
                                $quantitys = ($mainstock->primary_qty - $quantitys);
                            }
                            else
                            {
                                $quantitys = abs($totalqtyexist - $totalqty);
                                $quantitys = ($mainstock->primary_qty + $quantitys);
                            }
                            $mainstock->primary_qty = $quantitys;
                            $mainstock->save();
                        }

                        $purchaseItems->quantity = $inputData['quantity'][$key];
                        $purchaseItems->free_quantity = $inputData['freequantity'][$key];
                        $purchaseItems->rate = $inputData['purchase_rate'][$key];
                        $purchaseItems->cost = $inputData['cost'][$key];
                        $purchaseItems->sale_rate = $inputData['salerate'][$key];
                        $purchaseItems->mrp = $inputData['mrp'][$key];
                        $purchaseItems->gross_amt = $inputData['taxableamt'][$key];
                        $purchaseItems->discount_percentage = $inputData['disc_per'][$key];
                        $purchaseItems->discount_amount = $inputData['disc_amt'][$key];
                        $purchaseItems->taxable_amt = $inputData['taxablerow'][$key];
                        $purchaseItems->cgst = $inputData['cgst'][$key];
                        $purchaseItems->cgst_amount = $inputData['cgst_amt'][$key];
                        $purchaseItems->sgst = $inputData['sgst'][$key];
                        $purchaseItems->sgst_amount = $inputData['sgst_amt'][$key];
                        $purchaseItems->item_total = $inputData['total'][$key];
                        $purchaseItems->save();

                        if($purchaseItems->product->price->purchase_rate < $inputData['purchase_rate'][$key])
                        {
                            $product = ProductMaster::find($purchaseItems->product_master_id);
                            $product->price->cost = $inputData['cost'][$key];
                            $product->price->mrp = $inputData['mrp'][$key];
                            $product->price->sales_rate = $inputData['salerate'][$key];
                            $product->price->purchase_rate = $inputData['purchase_rate'][$key];
                            $product->price->save();
                            $product->save();
                            // ProductPrice::where('product_master_id', $purchaseItems->product_master_id)->where('purchase_id', $purchase->id)->update(['purchase_rate' => $inputData['purchase_rate'][$key], 'cost' => $inputData['cost'][$key], 'mrp' => $inputData['mrp'][$key], 'sales_rate' => $inputData['salerate'][$key]]);
                        }

                        $log = PurchaseLog::create(['purchase_id' => $purchase->id, 'created_by' =>  Auth::id(), 'product_master_id' => $purchaseItems->product_master_id, 'comment' => 'Updated item.']);
                    }
                }
            }

            if(isset($inputData['editprdid']) && count($inputData['editprdid']) > 0)
            {
                foreach($inputData['editprdid'] as $key => $productid)
                {
                    if(ProductMaster::where('id', $productid)->exists())
                    {
                        $product = ProductMaster::find($productid);
                        $purchaseDetails = new PurchaseDetails;
                        $purchaseDetails->purchase_id = $purchase->id;
                        $purchaseDetails->product_master_id = $productid;
                        $purchaseDetails->quantity = $inputData['editquantity'][$key];
                        $purchaseDetails->free_quantity = $inputData['editfreequantity'][$key];
                        $purchaseDetails->rate = $inputData['editpurchase_rate'][$key];
                        $purchaseDetails->cost = $inputData['editcost'][$key];
                        $purchaseDetails->sale_rate = $inputData['editsalerate'][$key];
                        $purchaseDetails->mrp = $inputData['editmrp'][$key];
                        $purchaseDetails->gross_amt = $inputData['edittaxableamt'][$key];
                        $purchaseDetails->discount_percentage = $inputData['editdisc_per'][$key];
                        $purchaseDetails->discount_amount = $inputData['editdisc_amt'][$key];
                        $purchaseDetails->taxable_amt = $inputData['edittaxablerow'][$key];
                        $purchaseDetails->cgst = $inputData['editcgst'][$key];
                        $purchaseDetails->cgst_amount = $inputData['editcgst_amt'][$key];
                        $purchaseDetails->sgst = $inputData['editsgst'][$key];
                        $purchaseDetails->sgst_amount = $inputData['editsgst_amt'][$key];
                        $purchaseDetails->item_total = $inputData['edittotal'][$key];
                        $purchaseDetails->save();

                        if($product->price->purchase_rate < $inputData['editpurchase_rate'][$key])
                        {
                            $product->price->cost = $inputData['editcost'][$key];
                            $product->price->mrp = $inputData['editmrp'][$key];
                            $product->price->sales_rate = $inputData['editsalerate'][$key];
                            $product->price->purchase_rate = $inputData['editpurchase_rate'][$key];
                            $product->price->save();
                            $product->save();
                            // ProductPrice::where('product_master_id', $productid)->where('purchase_id', $purchase->id)->update(['purchase_rate' => $inputData['editpurchase_rate'][$key], 'cost' => $inputData['editcost'][$key], 'mrp' => $inputData['editmrp'][$key], 'sales_rate' => $inputData['editsalerate'][$key]]);
                        }

                        $totalqty = ((float) $inputData['editquantity'][$key] + (float) $inputData['editfreequantity'][$key]);
                        if($purchase->branch->company_type == 2)
                        {
                            if($this->checkUseris())
                            {
                                if(StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $productid)->exists())
                                {
                                    $currentstock = StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $productid)->first();
                                    $currentstock->primary_qty = ($currentstock->primary_qty + $totalqty);
                                    $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                                    $currentstock->measure_finder = $currentstock->measure_finder;
                                    $currentstock->save();
                                }
                                else
                                {
                                    $branchStock = new StockBranch;
                                    $branchStock->branch_id = $purchase->branch_id;
                                    $branchStock->product_master_id = $productid;
                                    $branchStock->primary_qty = $totalqty;
                                    $branchStock->secondary_qty = 0;
                                    $branchStock->measure_finder = 0;
                                    $branchStock->comments = $purchase->invoice_no;
                                    $branchStock->created_by = Auth::id();
                                    $branchStock->save();
                                }
                            }

                            $branchpurchase = StockBranchPurchase::create([
                                'branch_id' => $purchase->branch_id,
                                'product_master_id' => $productid,
                                'quantity' => $totalqty,
                                'purchase_id' => $purchase->id,
                                'created_by' => Auth::id(),
                            ]);
                        }
                        else
                        {
                            if(Stock::where('product_master_id', $productid)->exists())
                            {
                                $mainstock = Stock::where('product_master_id', $productid)->first();
                                $mainstock->primary_qty = ($mainstock->primary_qty + $totalqty);
                                $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                                $mainstock->measure_finder = $mainstock->measure_finder;
                                $mainstock->save();
                            }
                            else
                            {
                                $mainstock = new Stock;
                                $mainstock->product_master_id = $productid;
                                $mainstock->primary_qty = $totalqty;
                                $mainstock->secondary_qty = 0;
                                $mainstock->measure_finder = 0;
                                $mainstock->save();
                            }
                        }
                        $log = PurchaseLog::create(['purchase_id' => $purchase->id, 'created_by' =>  Auth::id(), 'product_master_id' => $productid, 'comment' => 'Added new item.']);
                    }
                    else
                    {
                        return response()->json(['success' => false, 'message' => 'Product not exist'], 400);
                    }
                }
            }
            
            return response()->json(['success' => true, 'message' => 'Purchase Updated'], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    public function purchaseItemDelete(array $inputData)
    {
        $rowid = $inputData['rowid'];
        if(PurchaseDetails::where('id', $rowid)->exists())
        {
            $removedItems = PurchaseDetails::with('purchase', 'purchase.branch')->where('id', $rowid)->get();
            if($removedItems)
            {
                foreach($removedItems as $removedItem)
                {
                    $totalqty = ((float) $removedItem->quantity + (float) $removedItem->free_quantity);
                    if($removedItem->purchase->branch->company_type == 2)
                    {
                        if(StockBranch::where('branch_id', $removedItem->purchase->branch_id)->where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $currentstock = StockBranch::where('branch_id', $removedItem->purchase->branch_id)->where('product_master_id', $removedItem->product_master_id)->first();
                            $currentstock->primary_qty = ($currentstock->primary_qty - $totalqty);
                            $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                            $currentstock->measure_finder = $currentstock->measure_finder;
                            $currentstock->save();
                        }
                    }
                    else
                    {
                        if(Stock::where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $mainstock = Stock::where('product_master_id', $removedItem->product_master_id)->first();
                            $mainstock->primary_qty = ($mainstock->primary_qty - $totalqty);
                            $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                            $mainstock->measure_finder = $mainstock->measure_finder;
                            $mainstock->save();
                        }
                    }
                    $log = PurchaseLog::create(['purchase_id' => $removedItem->purchase->id, 'created_by' =>  Auth::id(), 'product_master_id' => $removedItem->product_master_id, 'comment' => 'Removed item.']);
                    $removedItem->delete();
                }
            }
            return response()->json(['success' => true, 'message' => 'Item Deleted'], 200);
        }
        else
        {
            return response()->json(['success' => false, 'message' => 'Item not exist.'], 400);
        }
    }

    public function returnStore(array $inputData)
    {
        try
        {
            $purchase = new PurchaseReturn;
            $purchase->invoice_no = $inputData['invno'];
            $purchase->purchase_date = $inputData['billdate'];
            $purchase->payment_pode = $inputData['mop'];
            $purchase->tax_type = $inputData['tax'];
            $purchase->vendor_id = $inputData['vendor'];
            $purchase->branch_id = $inputData['branch'];
            $purchase->salesman_id = $inputData['sales_man'];
            $purchase->total_amount = (isset($inputData['grosstotal']) && !empty($inputData['grosstotal'])) ? $inputData['grosstotal'] : '0';
            $purchase->total_cgst_amount = (isset($inputData['cgstamt']) && !empty($inputData['cgstamt'])) ? $inputData['cgstamt'] : '0';
            $purchase->total_sgst_amount = (isset($inputData['sgstamt']) && !empty($inputData['sgstamt'])) ? $inputData['sgstamt'] : '0';
            $purchase->total_igst_amount = (isset($inputData['igstamt']) && !empty($inputData['igstamt'])) ? $inputData['igstamt'] : '0';
            $purchase->total_tax_amount = (isset($inputData['totaltax']) && !empty($inputData['totaltax'])) ? $inputData['totaltax'] : '0';
            $purchase->total_taxable_amt = (isset($inputData['taxable']) && !empty($inputData['taxable'])) ? $inputData['taxable'] : '0';
            $purchase->total_discount_percentage = (isset($inputData['discountfinal']) && !empty($inputData['discountfinal'])) ? $inputData['discountfinal'] : '0';
            $purchase->total_discount_amount = (isset($inputData['discountfinalamt']) && !empty($inputData['discountfinalamt'])) ? $inputData['discountfinalamt'] : '0';
            $purchase->exempted = (isset($inputData['exempted']) && !empty($inputData['exempted'])) ? $inputData['exempted'] : '0';
            $purchase->total_item_discount = (isset($inputData['itemdiscount']) && !empty($inputData['itemdiscount'])) ? $inputData['itemdiscount'] : '0';
            $purchase->purchase_total = (isset($inputData['purchasevalue']) && !empty($inputData['purchasevalue'])) ? $inputData['purchasevalue'] : '0';
            $purchase->netvalue = (isset($inputData['netvalue']) && !empty($inputData['netvalue'])) ? $inputData['netvalue'] : '0';
            $purchase->cess = (isset($inputData['cessamt']) && !empty($inputData['cessamt'])) ? $inputData['cessamt'] : '0';
            $purchase->add_cess = (isset($inputData['addcess']) && !empty($inputData['addcess'])) ? $inputData['addcess'] : '0';
            $purchase->freight_coolie = (isset($inputData['freightcoolie']) && !empty($inputData['freightcoolie'])) ? $inputData['freightcoolie'] : '0';
            $purchase->otherexp = (isset($inputData['otherexp']) && !empty($inputData['otherexp'])) ? $inputData['otherexp'] : '0';
            $purchase->cost_factor = (isset($inputData['costfactor']) && !empty($inputData['costfactor'])) ? $inputData['costfactor'] : '0';
            $purchase->cash_discount = (isset($inputData['cashdisc']) && !empty($inputData['cashdisc'])) ? $inputData['cashdisc'] : '0';
            $purchase->round_off = (isset($inputData['roundval']) && !empty($inputData['roundval'])) ? $inputData['roundval'] : '0';
            $purchase->grand_total = (isset($inputData['finalamount']) && !empty($inputData['finalamount'])) ? $inputData['finalamount'] : '0';

            $purchase->status = true;
            $purchase->created_by = Auth::id();
            $purchase->save();

            $transaction = new Transaction;
            $transaction->transaction_no = strtoupper(uniqid());
            $transaction->transaction_date = $purchase->purchase_date;
            $transaction->parent_table_id = $purchase->id;
            $transaction->customer_id = $purchase->vendor_id;
            $transaction->branch_id = $purchase->branch_id;
            $transaction->parent_table = 4;
            $transaction->transaction_type = 8;
            $transaction->payment_type = 1;
            $transaction->credit_amount = 0;
            $transaction->debit_amount = $purchase->grand_total;
            
            $transaction->description = 'Purchase Return';
            $transaction->created_by = Auth::id();
            $transaction->save();

            
            if($purchase->branch->company_type == 2)
            {
                $purchase->approve_status = true;
                $purchase->save();
            }

            foreach($inputData['prdid'] as $key => $productid)
            {
                if(ProductMaster::where('id', $productid)->exists())
                {
                    $product = ProductMaster::find($productid);
                    $purchaseDetails = new PurchaseReturnDetails;
                    $purchaseDetails->purchase_return_id = $purchase->id;
                    $purchaseDetails->product_master_id = $productid;
                    $purchaseDetails->quantity = $inputData['quantity'][$key];
                    $purchaseDetails->free_quantity = $inputData['freequantity'][$key];
                    $purchaseDetails->rate = $inputData['purchase_rate'][$key];
                    $purchaseDetails->cost = $inputData['cost'][$key];
                    $purchaseDetails->sale_rate = $inputData['salerate'][$key];
                    $purchaseDetails->mrp = $inputData['mrp'][$key];
                    $purchaseDetails->gross_amt = $inputData['taxableamt'][$key];
                    $purchaseDetails->discount_percentage = $inputData['disc_per'][$key];
                    $purchaseDetails->discount_amount = $inputData['disc_amt'][$key];
                    $purchaseDetails->taxable_amt = $inputData['taxablerow'][$key];
                    $purchaseDetails->cgst = $inputData['cgst'][$key];
                    $purchaseDetails->cgst_amount = $inputData['cgst_amt'][$key];
                    $purchaseDetails->sgst = $inputData['sgst'][$key];
                    $purchaseDetails->sgst_amount = $inputData['sgst_amt'][$key];
                    $purchaseDetails->item_total = $inputData['total'][$key];
                    $purchaseDetails->save();

                    $totalqty = ((float) $inputData['quantity'][$key] + (float) $inputData['freequantity'][$key]);
                    if($purchase->branch->company_type == 2)
                    {
                        if($this->checkUseris())
                        {
                            if(StockBranch::where('branch_id', $inputData['branch'])->where('product_master_id', $productid)->exists())
                            {
                                $currentstock = StockBranch::where('branch_id', $inputData['branch'])->where('product_master_id', $productid)->first();
                                $currentstock->primary_qty = ($currentstock->primary_qty - $totalqty);
                                $currentstock->secondary_qty = ($currentstock->secondary_qty - 0);
                                $currentstock->measure_finder = $currentstock->measure_finder;
                                $currentstock->save();
                            }
                            else
                            {
                                $branchStock = new StockBranch;
                                $branchStock->branch_id = $inputData['branch'];
                                $branchStock->product_master_id = $productid;
                                $branchStock->primary_qty = (-1 * abs($totalqty));
                                $branchStock->secondary_qty = 0;
                                $branchStock->measure_finder = 0;
                                $branchStock->comments = $inputData['invno'];
                                $branchStock->created_by = Auth::id();
                                $branchStock->save();
                            }
                        }

                        $branchpurchase = StockBranchPurchaseReturn::create([
                            'branch_id' => $inputData['branch'],
                            'product_master_id' => $productid,
                            'quantity' => $totalqty,
                            'purchase_return_id' => $purchase->id,
                            'created_by' => Auth::id(),
                        ]);
                    }
                    else
                    {
                        if(Stock::where('product_master_id', $productid)->exists())
                        {
                            $mainstock = Stock::where('product_master_id', $productid)->first();
                            $mainstock->primary_qty = ($mainstock->primary_qty - $totalqty);
                            $mainstock->secondary_qty = ($mainstock->secondary_qty - 0);
                            $mainstock->measure_finder = $mainstock->measure_finder;
                            $mainstock->save();
                        }
                        else
                        {
                            $mainstock = new Stock;
                            $mainstock->product_master_id = $productid;
                            $mainstock->primary_qty = (-1 * abs($totalqty));
                            $mainstock->secondary_qty = 0;
                            $mainstock->measure_finder = 0;
                            $mainstock->save();
                        }
                    }
                }
                else
                {
                    return response()->json(['success' => false, 'message' => 'Product not exist'], 400);
                }
            }
            
            return response()->json(['success' => true, 'message' => 'Return Created Successfully!', 'product' => $product], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    // Return Update

    public function returnUpdate(array $inputData, PurchaseReturn $purchaseReturn)
    {
        $purchase = $purchaseReturn;
        try
        {
            $purchase->invoice_no = $inputData['invno'];
            $purchase->purchase_date = $inputData['billdate'];
            $purchase->payment_pode = $inputData['mop'];
            $purchase->tax_type = $inputData['tax'];
            $purchase->vendor_id = $inputData['vendor'];
            $purchase->branch_id = $inputData['branch'];
            $purchase->salesman_id = $inputData['sales_man'];
            $purchase->total_amount = (isset($inputData['grosstotal']) && !empty($inputData['grosstotal'])) ? $inputData['grosstotal'] : '0';
            $purchase->total_cgst_amount = (isset($inputData['cgstamt']) && !empty($inputData['cgstamt'])) ? $inputData['cgstamt'] : '0';
            $purchase->total_sgst_amount = (isset($inputData['sgstamt']) && !empty($inputData['sgstamt'])) ? $inputData['sgstamt'] : '0';
            $purchase->total_igst_amount = (isset($inputData['igstamt']) && !empty($inputData['igstamt'])) ? $inputData['igstamt'] : '0';
            $purchase->total_tax_amount = (isset($inputData['totaltax']) && !empty($inputData['totaltax'])) ? $inputData['totaltax'] : '0';
            $purchase->total_taxable_amt = (isset($inputData['taxable']) && !empty($inputData['taxable'])) ? $inputData['taxable'] : '0';
            $purchase->total_discount_percentage = (isset($inputData['discountfinal']) && !empty($inputData['discountfinal'])) ? $inputData['discountfinal'] : '0';
            $purchase->total_discount_amount = (isset($inputData['discountfinalamt']) && !empty($inputData['discountfinalamt'])) ? $inputData['discountfinalamt'] : '0';
            $purchase->exempted = (isset($inputData['exempted']) && !empty($inputData['exempted'])) ? $inputData['exempted'] : '0';
            $purchase->total_item_discount = (isset($inputData['itemdiscount']) && !empty($inputData['itemdiscount'])) ? $inputData['itemdiscount'] : '0';
            $purchase->purchase_total = (isset($inputData['purchasevalue']) && !empty($inputData['purchasevalue'])) ? $inputData['purchasevalue'] : '0';
            $purchase->netvalue = (isset($inputData['netvalue']) && !empty($inputData['netvalue'])) ? $inputData['netvalue'] : '0';
            $purchase->cess = (isset($inputData['cessamt']) && !empty($inputData['cessamt'])) ? $inputData['cessamt'] : '0';
            $purchase->add_cess = (isset($inputData['addcess']) && !empty($inputData['addcess'])) ? $inputData['addcess'] : '0';
            $purchase->freight_coolie = (isset($inputData['freightcoolie']) && !empty($inputData['freightcoolie'])) ? $inputData['freightcoolie'] : '0';
            $purchase->otherexp = (isset($inputData['otherexp']) && !empty($inputData['otherexp'])) ? $inputData['otherexp'] : '0';
            $purchase->cost_factor = (isset($inputData['costfactor']) && !empty($inputData['costfactor'])) ? $inputData['costfactor'] : '0';
            $purchase->cash_discount = (isset($inputData['cashdisc']) && !empty($inputData['cashdisc'])) ? $inputData['cashdisc'] : '0';
            $purchase->round_off = (isset($inputData['roundval']) && !empty($inputData['roundval'])) ? $inputData['roundval'] : '0';
            $purchase->grand_total = (isset($inputData['finalamount']) && !empty($inputData['finalamount'])) ? $inputData['finalamount'] : '0';
            $purchase->save();

            if(Transaction::where('branch_id', $purchase->branch_id)->where('parent_table', 4)->where('parent_table_id', $purchase->id)->exists())
            {
                $transaction = Transaction::where('branch_id', $purchase->branch_id)->where('parent_table', 4)->where('parent_table_id', $purchase->id)->first();
                $transaction->transaction_date = $purchase->purchase_date;
                $transaction->customer_id = $purchase->vendor_id;
                $transaction->credit_amount = 0;
                $transaction->debit_amount = $purchase->grand_total ;
                $transaction->save();
            }

            $removedItems = PurchaseReturnDetails::where('purchase_return_id', $purchase->id)->whereNotIn('id', $inputData['tblid'])->get();
            if($removedItems)
            {
                foreach($removedItems as $removedItem)
                {
                    $totalqty = ((float) $removedItem->quantity + (float) $removedItem->free_quantity);
                    if($purchase->branch->company_type == 2)
                    {
                        if(StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $currentstock = StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $removedItem->product_master_id)->first();
                            $currentstock->primary_qty = ($currentstock->primary_qty + $totalqty);
                            $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                            $currentstock->measure_finder = $currentstock->measure_finder;
                            $currentstock->save();
                        }
                    }
                    else
                    {
                        if(Stock::where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $mainstock = Stock::where('product_master_id', $removedItem->product_master_id)->first();
                            $mainstock->primary_qty = ($mainstock->primary_qty + $totalqty);
                            $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                            $mainstock->measure_finder = $mainstock->measure_finder;
                            $mainstock->save();
                        }
                    }
                    $removedItem->delete();
                }
            }

            foreach($inputData['tblid'] as $key => $tableid)
            {
                if(PurchaseReturnDetails::where('id', $tableid)->exists())
                {
                    $purchaseItems = PurchaseReturnDetails::where('purchase_return_id', $purchase->id)->find($tableid);
                    if(ProductMaster::where('id', $purchaseItems->product_master_id)->exists())
                    {
                        $totalqty = ((float) $inputData['quantity'][$key] + (float) $inputData['freequantity'][$key]);
                        $totalqtyexist = ((float) $purchaseItems->quantity + (float) $purchaseItems->free_quantity);
                        if($purchase->branch->company_type == 2)
                        {
                            $currentstock = StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $purchaseItems->product_master_id)->first();
                            if($totalqtyexist >= $totalqty)
                            {
                                $quantitys = abs($totalqtyexist - $totalqty);
                                $quantitys = ($currentstock->primary_qty + $quantitys);
                            }
                            else
                            {
                                $quantitys = abs($totalqty - $totalqtyexist);
                                $quantitys = ($currentstock->primary_qty - $quantitys);
                            }
                            $currentstock->primary_qty = $quantitys;
                            $currentstock->save();
                        }
                        else
                        {
                            $mainstock = Stock::where('product_master_id', $purchaseItems->product_master_id)->first();
                            if($totalqtyexist >= $totalqty)
                            {
                                $quantitys = abs($totalqty - $totalqtyexist);
                                $quantitys = ($mainstock->primary_qty + $quantitys);
                            }
                            else
                            {
                                $quantitys = abs($totalqtyexist - $totalqty);
                                $quantitys = ($mainstock->primary_qty - $quantitys);
                            }
                            $mainstock->primary_qty = $quantitys;
                            $mainstock->save();
                        }

                        $purchaseItems->quantity = $inputData['quantity'][$key];
                        $purchaseItems->free_quantity = $inputData['freequantity'][$key];
                        $purchaseItems->rate = $inputData['purchase_rate'][$key];
                        $purchaseItems->cost = $inputData['cost'][$key];
                        $purchaseItems->sale_rate = $inputData['salerate'][$key];
                        $purchaseItems->mrp = $inputData['mrp'][$key];
                        $purchaseItems->gross_amt = $inputData['taxableamt'][$key];
                        $purchaseItems->discount_percentage = $inputData['disc_per'][$key];
                        $purchaseItems->discount_amount = $inputData['disc_amt'][$key];
                        $purchaseItems->taxable_amt = $inputData['taxablerow'][$key];
                        $purchaseItems->cgst = $inputData['cgst'][$key];
                        $purchaseItems->cgst_amount = $inputData['cgst_amt'][$key];
                        $purchaseItems->sgst = $inputData['sgst'][$key];
                        $purchaseItems->sgst_amount = $inputData['sgst_amt'][$key];
                        $purchaseItems->item_total = $inputData['total'][$key];
                        $purchaseItems->save();
                    }
                }
            }

            if(isset($inputData['editprdid']) && count($inputData['editprdid']) > 0)
            {
                foreach($inputData['editprdid'] as $key => $productid)
                {
                    if(ProductMaster::where('id', $productid)->exists())
                    {
                        $product = ProductMaster::find($productid);
                        $purchaseDetails = new PurchaseReturnDetails;
                        $purchaseDetails->purchase_return_id = $purchase->id;
                        $purchaseDetails->product_master_id = $productid;
                        $purchaseDetails->quantity = $inputData['editquantity'][$key];
                        $purchaseDetails->free_quantity = $inputData['editfreequantity'][$key];
                        $purchaseDetails->rate = $inputData['editpurchase_rate'][$key];
                        $purchaseDetails->cost = $inputData['editcost'][$key];
                        $purchaseDetails->sale_rate = $inputData['editsalerate'][$key];
                        $purchaseDetails->mrp = $inputData['editmrp'][$key];
                        $purchaseDetails->gross_amt = $inputData['edittaxableamt'][$key];
                        $purchaseDetails->discount_percentage = $inputData['editdisc_per'][$key];
                        $purchaseDetails->discount_amount = $inputData['editdisc_amt'][$key];
                        $purchaseDetails->taxable_amt = $inputData['edittaxablerow'][$key];
                        $purchaseDetails->cgst = $inputData['editcgst'][$key];
                        $purchaseDetails->cgst_amount = $inputData['editcgst_amt'][$key];
                        $purchaseDetails->sgst = $inputData['editsgst'][$key];
                        $purchaseDetails->sgst_amount = $inputData['editsgst_amt'][$key];
                        $purchaseDetails->item_total = $inputData['edittotal'][$key];
                        $purchaseDetails->save();

                        $totalqty = ((float) $inputData['editquantity'][$key] + (float) $inputData['editfreequantity'][$key]);
                        if($purchase->branch->company_type == 2)
                        {
                            if($this->checkUseris())
                            {
                                if(StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $productid)->exists())
                                {
                                    $currentstock = StockBranch::where('branch_id', $purchase->branch_id)->where('product_master_id', $productid)->first();
                                    $currentstock->primary_qty = ($currentstock->primary_qty - $totalqty);
                                    $currentstock->secondary_qty = ($currentstock->secondary_qty - 0);
                                    $currentstock->measure_finder = $currentstock->measure_finder;
                                    $currentstock->save();
                                }
                                else
                                {
                                    $branchStock = new StockBranch;
                                    $branchStock->branch_id = $purchase->branch_id;
                                    $branchStock->product_master_id = $productid;
                                    $branchStock->primary_qty = $totalqty;
                                    $branchStock->secondary_qty = 0;
                                    $branchStock->measure_finder = 0;
                                    $branchStock->comments = $purchase->invoice_no;
                                    $branchStock->created_by = Auth::id();
                                    $branchStock->save();
                                }
                            }

                            $branchpurchase = StockBranchPurchaseReturn::create([
                                'branch_id' => $purchase->branch_id,
                                'product_master_id' => $productid,
                                'quantity' => $totalqty,
                                'purchase_return_id' => $purchase->id,
                                'created_by' => Auth::id(),
                            ]);
                        }
                        else
                        {
                            if(Stock::where('product_master_id', $productid)->exists())
                            {
                                $mainstock = Stock::where('product_master_id', $productid)->first();
                                $mainstock->primary_qty = ($mainstock->primary_qty - $totalqty);
                                $mainstock->secondary_qty = ($mainstock->secondary_qty - 0);
                                $mainstock->measure_finder = $mainstock->measure_finder;
                                $mainstock->save();
                            }
                            else
                            {
                                $mainstock = new Stock;
                                $mainstock->product_master_id = $productid;
                                $mainstock->primary_qty = $totalqty;
                                $mainstock->secondary_qty = 0;
                                $mainstock->measure_finder = 0;
                                $mainstock->save();
                            }
                        }
                    }
                    else
                    {
                        return response()->json(['success' => false, 'message' => 'Product not exist'], 400);
                    }
                }
            }
            
            return response()->json(['success' => true, 'message' => 'Purchase Return Updated'], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }

    public function purchaseReturnItemDelete(array $inputData)
    {
        $rowid = $inputData['rowid'];
        if(PurchaseReturnDetails::where('id', $rowid)->exists())
        {
            $removedItems = PurchaseReturnDetails::with('purchaseReturn', 'purchaseReturn.branch')->where('id', $rowid)->get();
            if($removedItems)
            {
                foreach($removedItems as $removedItem)
                {
                    $totalqty = ((float) $removedItem->quantity + (float) $removedItem->free_quantity);
                    if($removedItem->purchaseReturn->branch->company_type == 2)
                    {
                        if(StockBranch::where('branch_id', $removedItem->purchaseReturn->branch_id)->where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $currentstock = StockBranch::where('branch_id', $removedItem->purchaseReturn->branch_id)->where('product_master_id', $removedItem->product_master_id)->first();
                            $currentstock->primary_qty = ($currentstock->primary_qty + $totalqty);
                            $currentstock->secondary_qty = ($currentstock->secondary_qty + 0);
                            $currentstock->measure_finder = $currentstock->measure_finder;
                            $currentstock->save();
                        }
                    }
                    else
                    {
                        if(Stock::where('product_master_id', $removedItem->product_master_id)->exists())
                        {
                            $mainstock = Stock::where('product_master_id', $removedItem->product_master_id)->first();
                            $mainstock->primary_qty = ($mainstock->primary_qty + $totalqty);
                            $mainstock->secondary_qty = ($mainstock->secondary_qty + 0);
                            $mainstock->measure_finder = $mainstock->measure_finder;
                            $mainstock->save();
                        }
                    }
                    $removedItem->delete();
                }
            }
            return response()->json(['success' => true, 'message' => 'Item Deleted'], 200);
        }
        else
        {
            return response()->json(['success' => false, 'message' => 'Item not exist.'], 400);
        }
    }
    
}