<?php

namespace App\Services;
use App\Models\AccountGroup;

class TransactionService {

    public function getTransactionAmount($fromDate, $toDate, $month, $year, $group)
    {
        try
        {
            $accountGroups = AccountGroup::whereHas('ledgers', function ($query) use ($fromDate, $toDate, $month, $year) {
                $query->whereHas('transactions', function ($transactionQuery) use ($fromDate, $toDate, $month, $year) {
                    $transactionQuery->when($fromDate, function ($q) use ($fromDate) {
                        $q->whereDate('transaction_date', '>=', $fromDate);
                    })
                    ->when($toDate, function ($q) use ($toDate) {
                        $q->whereDate('transaction_date', '<=', $toDate);
                    })
                    ->when($month, function ($q) use ($month) {
                        $q->whereMonth('transaction_date', $month);
                    })
                    ->when($year, function ($q) use ($year) {
                        $q->whereYear('transaction_date', $year);
                    });
                });
            })->where('status', true)->where('id', $group)->get();

            $results = [];

            foreach($accountGroups as $accountGroup)
            {
                $ledgersWithSums = $accountGroup->getTransactionSumsGroupedByLedger($fromDate, $toDate, $month, $year);
                $pagedata['group'] = $accountGroup->name;
                foreach($ledgersWithSums as $ledgerData)
                {
                    $results[] = [
                        'account_group_id' => $accountGroup->id,
                        'account_group_name' => $accountGroup->name,
                        'ledger_id' => $ledgerData['ledger']->id,
                        'ledger_name' => $ledgerData['ledger']->name,
                        'total_credit_amount' => $ledgerData['total_credit_amount'],
                        'total_debit_amount' => $ledgerData['total_debit_amount'],
                        'total_credit_before_date' => $ledgerData['total_credit_before_date'],
                        'total_debit_before_date' => $ledgerData['total_debit_before_date'],
                    ];
                }
            }

            $totalCreditAmount = 0;
            $totalDebitAmount = 0;
            $totalCreditBeforeAmount = 0;
            $totalDebitBeforeAmount = 0;
            foreach ($results as $result)
            {
                $totalCreditAmount = $totalCreditAmount + $result['total_credit_amount'];
                $totalDebitAmount = $totalDebitAmount + $result['total_debit_amount'];
                $totalCreditBeforeAmount = $totalCreditBeforeAmount + $result['total_credit_before_date'];
                $totalDebitBeforeAmount = $totalDebitBeforeAmount + $result['total_debit_before_date'];
            }

            $arrayData = array('totalCredit' => $totalCreditAmount, 'totalDebit' => $totalDebitAmount, 'totalCreditBefore' => $totalCreditBeforeAmount, 'totalDebitBefore' => $totalDebitBeforeAmount);

            return response()->json(['success' => true, 'message' => 'Data Get Successfully!', 'data' => $arrayData], 200);
        }
        catch (\Exception $th)
        {
            $errormessage = $th->getMessage();
            return response()->json(['success' => false, 'message' => $errormessage], 400);
        }
    }
}