<?php
namespace App\Traits;

use Illuminate\Http\Request;
use Carbon\Carbon;
use App\Models\Sale;
use App\Models\SaleClient;
use App\Models\SaleQuotation;
use Rmunate\Utilities\SpellNumber;

trait InvoicePrintTrait
{

    public function saleItems($id)
    {
        if(Sale::where('id', $id)->exists())
        {
            $sale = Sale::with('saleDetails', 'saleDetails.product', 'saleDetails.product.unit', 'customer', 'customer.state', 'branch', 'vehicle')
            ->withSum([ 'saleDetails as tax_0_cgst' => function($query) { $query->where( 'cgst', 0); }], 'item_total')
            ->withSum([ 'saleDetails as tax_5_cgst' => function($query) { $query->where( 'cgst', 5); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_5_sgst' => function($query) { $query->where( 'cgst', 5); }], 'sgst_amount')
            ->withSum([ 'saleDetails as tax_12_cgst' => function($query) { $query->where( 'cgst', 12); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_12_sgst' => function($query) { $query->where( 'cgst', 12); }], 'sgst_amount')
            ->withSum([ 'saleDetails as tax_18_cgst' => function($query) { $query->where( 'cgst', 18); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_18_sgst' => function($query) { $query->where( 'cgst', 18); }], 'sgst_amount')
            ->withSum([ 'saleDetails as tax_28_cgst' => function($query) { $query->where( 'cgst', 28); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_28_sgst' => function($query) { $query->where( 'cgst', 28); }], 'sgst_amount')
            
            ->find($id)->makeHidden(['created_at', 'updated_at', 'deleted_at', 'created_by', 'return_status', 'status', 'settled', 'correction_status'])->toArray();
            
            $grandTotal = number_format(round($sale['grand_total']), 2, '.', '');

            $sale['amountInWords'] = SpellNumber::value($grandTotal)->locale('en')->currency('Rupees')->fraction('Paise')->toMoney();
            return response()->json(['success' => true, 'data'=> $sale], 200);
        }
        else
        {
            return response()->json(['success' => false, 'message'=> 'Data not exist.'], 401);
        }
        return response()->json(['success' => false, 'message'=> 'Data not exist.'], 401);
    }

    public function saleItemEstimate($id)
    {
        if(SaleClient::where('sales_id', $id)->exists())
        {
            $sale = SaleClient::with('saleClientDetails', 'saleClientDetails.product', 'saleClientDetails.product.unit', 'customer', 'customer.state', 'branch')
            ->withSum([ 'saleClientDetails as tax_0_cgst' => function($query) { $query->where( 'cgst', 0); }], 'item_total')
            ->withSum([ 'saleClientDetails as tax_5_cgst' => function($query) { $query->where( 'cgst', 5); }], 'cgst_amount')
            ->withSum([ 'saleClientDetails as tax_5_sgst' => function($query) { $query->where( 'cgst', 5); }], 'sgst_amount')
            ->withSum([ 'saleClientDetails as tax_12_cgst' => function($query) { $query->where( 'cgst', 12); }], 'cgst_amount')
            ->withSum([ 'saleClientDetails as tax_12_sgst' => function($query) { $query->where( 'cgst', 12); }], 'sgst_amount')
            ->withSum([ 'saleClientDetails as tax_18_cgst' => function($query) { $query->where( 'cgst', 18); }], 'cgst_amount')
            ->withSum([ 'saleClientDetails as tax_18_sgst' => function($query) { $query->where( 'cgst', 18); }], 'sgst_amount')
            ->withSum([ 'saleClientDetails as tax_28_cgst' => function($query) { $query->where( 'cgst', 28); }], 'cgst_amount')
            ->withSum([ 'saleClientDetails as tax_28_sgst' => function($query) { $query->where( 'cgst', 28); }], 'sgst_amount')
            
            ->where('sales_id', $id)->first()->makeHidden(['created_at', 'updated_at', 'deleted_at', 'created_by', 'return_status', 'status', 'settled', 'correction_status'])->toArray(); // find($id)
            
            $grandTotal = number_format(round($sale['grand_total']), 2, '.', '');

            $sale['amountInWords'] = SpellNumber::value($grandTotal)->locale('en')->currency('Rupees')->fraction('Paise')->toMoney();
            return response()->json(['success' => true, 'data'=> $sale], 200);
        }
        else
        {
            return response()->json(['success' => false, 'message'=> 'Data not exist.'], 401);
        }
        return response()->json(['success' => false, 'message'=> 'Data not exist.'], 401);
    }

    public function saleItemQuotation($id)
    {
        if(SaleQuotation::where('id', $id)->exists())
        {
            $sale = SaleQuotation::with('saleDetails', 'saleDetails.product', 'saleDetails.product.unit', 'customer', 'customer.state', 'branch')
            ->withSum([ 'saleDetails as tax_0_cgst' => function($query) { $query->where( 'cgst', 0); }], 'item_total')
            ->withSum([ 'saleDetails as tax_5_cgst' => function($query) { $query->where( 'cgst', 5); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_5_sgst' => function($query) { $query->where( 'cgst', 5); }], 'sgst_amount')
            ->withSum([ 'saleDetails as tax_12_cgst' => function($query) { $query->where( 'cgst', 12); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_12_sgst' => function($query) { $query->where( 'cgst', 12); }], 'sgst_amount')
            ->withSum([ 'saleDetails as tax_18_cgst' => function($query) { $query->where( 'cgst', 18); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_18_sgst' => function($query) { $query->where( 'cgst', 18); }], 'sgst_amount')
            ->withSum([ 'saleDetails as tax_28_cgst' => function($query) { $query->where( 'cgst', 28); }], 'cgst_amount')
            ->withSum([ 'saleDetails as tax_28_sgst' => function($query) { $query->where( 'cgst', 28); }], 'sgst_amount')
            
            ->find($id)->makeHidden(['created_at', 'updated_at', 'deleted_at', 'created_by', 'return_status', 'status', 'settled', 'correction_status'])->toArray(); // find($id)
            
            $grandTotal = number_format(round($sale['grand_total']), 2, '.', '');

            $sale['amountInWords'] = SpellNumber::value($grandTotal)->locale('en')->currency('Rupees')->fraction('Paise')->toMoney();
            return response()->json(['success' => true, 'data'=> $sale], 200);
        }
        else
        {
            return response()->json(['success' => false, 'message'=> 'Data not exist.'], 401);
        }
        return response()->json(['success' => false, 'message'=> 'Data not exist.'], 401);
    }
}