<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

class CreateTransactionsTable extends Migration
{
    /**
     * Run the migrations.
     *
     * @return void
     */
    public function up()
    {
        Schema::create('transactions', function (Blueprint $table) {
            $table->id();
            $table->string('transaction_no', 255);
            $table->unsignedBigInteger('parent_table_id')->nullable()->comment('Sales/Purchase');
            $table->unsignedBigInteger('customer_id')->nullable();
            $table->unsignedBigInteger('branch_id')->nullable();
            $table->integer('parent_table')->nullable()->comment('1: Sale, 2: Purchase, 3: Sales Return, 4: Purchase Return');
            $table->integer('transaction_type')->nullable()->comment('1: Sale, 2: Purchase, 3: Receipt, 4: Payment, 5: Opening Balance, 6: Ledger, 7: Sales Return, 8: Purchase Return');
            $table->integer('payment_type')->nullable()->comment('1: Cash, 2: Cheque, 3: DD, 4: RTGS, 5: NEFT');
            $table->decimal('credit_amount', 15, 2)->default(0)->nullable();
            $table->decimal('debit_amount', 15, 2)->default(0)->nullable();
            $table->json('payment_details')->nullable();
            $table->longText('description')->nullable();
            $table->unsignedBigInteger('created_by')->nullable();
            $table->timestamps();
            $table->softDeletes();
            $table->foreign('created_by')->references('id')->on('users');
            $table->foreign('customer_id')->references('id')->on('customer_masters');
            $table->foreign('branch_id')->references('id')->on('company_profiles');
        });
    }

    /**
     * Reverse the migrations.
     *
     * @return void
     */
    public function down()
    {
        Schema::dropIfExists('transactions');
    }
}
