@extends('layouts.admin.master')
@section('title', 'Adjust')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')

<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $('#commonCutting').on('keyup change',function(){
        var cuttingVal = $(this).val();
        $('.cutperVal').each(function() {
            if(cuttingVal > 0)
            {
                $(this).val(cuttingVal);
            }
            else
            {
                $(this).val(0);
            }
        });
    });
</script>

@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Adjust List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Adjust List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->

<!-- Permission Table -->
<div class="card">
    <div class="p-2">
        @if(count($errors) > 0)
            <div class="row mb-2">
                <div class="col-lg-12">
                    <div class="alert alert-danger alert-dismissible" role="alert">
                        <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                        @foreach ($errors->all() as $error)
                            <p class="mb-0">{{ $error }}</p>
                        @endforeach
                        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"> </button>
                    </div>
                </div>
            </div>
        @endif
        @if($message = Session::get('error'))
            <div class="row mb-2">
                <div class="col-lg-12">
                    <div class="alert alert-danger alert-dismissible" role="alert">
                        <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
                        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"> </button>
                    </div>
                </div>
            </div>
        @endif
        @if($message = Session::get('success'))
            <div class="row mb-2">
                <div class="col-lg-12">
                    <div class="alert alert-success alert-dismissible" role="alert">
                        <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
                        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"> </button>
                    </div>
                </div>
            </div>
        @endif
    </div>
    <div class="card-body">
        
            <div class="row mt-4">
                <div class="col-md-4">
                    <div class="card mb-4">
                        <div class="card-header d-flex justify-content-between align-items-center">
                            <h5 class="mb-0">Bill Details:</h5> <small class="text-muted float-end">Search</small>
                        </div>
                        <div class="card-body">
                            <form id="addForm" action="{{ route('bill.details') }}" method="post">
                                @csrf

                                <div class="row">
                                    <div class="col-6">
                                        <label class="form-label" for="branch">Branch</label>
                                        <select id="branch" name="branch" class="form-control branch" required>
                                            <option value="">--Select--</option>
                                            @foreach($companys as $company)
                                                <option value="{{$company->id}}">{{$company->name}}</option>
                                            @endforeach
                                        </select>
                                    </div>
                                    <div class="col-6 mb-3">
                                        <label class="form-label" for="fromdate">Date</label>
                                        <input type="date" id="fromdate" name="fromdate" class="form-control" value="{{ date('Y-m-d') }}" autofocus />
                                    </div>
                                    <?php /*
                                    <div class="col-6 mb-3">
                                        <label class="form-label" for="todate">To Date</label>
                                        <input type="date" id="todate" name="todate" class="form-control" value="{{ date('Y-m-d') }}" />
                                    </div>
                                    */ ?>
                                    <div class="col-12 text-center demo-vertical-spacing">
                                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Find</button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>

                <div class="col-md-8">
                    @if(isset($sales))
                        <form id="addForm" action="{{ route('bill.adjust') }}" method="post">
                            @csrf
                            <input type="hidden" name="frmdte" value="{{ base64_encode($from_date) }}">
                            <input type="hidden" name="branch" value="{{ base64_encode($branch) }}">
                            <div class="card mb-4">
                                <div class="card-header d-flex justify-content-between align-items-center">
                                    <h5 class="mb-0">Bill List:</h5> <small class="text-muted float-end"><input type="text" class="form-control" name="commonCutting" id="commonCutting" placeholder="Common Cutting %"></small>
                                </div>
                                <div class="card-body">
                                    <table class="table table-bordered">
                                        <thead>
                                            <tr><th>Item</th><th>Qty</th><th width="200px">Cutting %</th></tr>
                                        </thead>
                                        <tbody>
                                            @forelse($sales as $sale)
                                                <tr>
                                                    <td>{{ $sale->product->name }}</td>
                                                    <td>{{ $sale->totalqty }}</td>
                                                    <td>
                                                        <input type="number" class="form-control cutperVal" name="cutper[{{$loop->index}}]" id="cutper" value="0">
                                                        <input type="hidden" name="totitem[{{$loop->index}}]" value="{{ base64_encode($sale->totalqty) }}">
                                                        <input type="hidden" name="product[{{$loop->index}}]" value="{{ base64_encode($sale->product_master_id) }}">
                                                    </td>
                                                </tr>
                                            @empty
                                            <tr><th>No Product</th></tr>
                                            @endforelse
                                        </tbody>
                                    </table>
                                    <div class="col-12 text-center demo-vertical-spacing">
                                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Adjust</button>
                                    </div>
                                </div>
                            </div>
                        </form>
                    @endif
                </div>
            </div>
        
    </div>
</div>
<!--/ Permission Table -->

@endsection
