@extends('layouts.admin.master')
@section('title', 'Area')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')

<script type="text/javascript">
    var table = $('.datatables-permissions').DataTable({
       // ... skipped ...
       dom: '<"row mx-1"<"col-sm-12 col-md-3" l><"col-sm-12 col-md-9"<"dt-action-buttons text-xl-end text-lg-start text-md-end text-start d-flex align-items-center justify-content-md-end justify-content-center flex-wrap me-1"<"me-3"f>B>>>t<"row mx-2"<"col-sm-12 col-md-6"i><"col-sm-12 col-md-6"p>>',
        language: {
            sLengthMenu: "_MENU_",
            search: "Search",
            searchPlaceholder: "Search.."
        },
        buttons: [{
            text: "Add Area",
            className: "add-new btn btn-primary mb-3 mb-md-0",
            attr: {
                "data-bs-toggle": "modal",
                "data-bs-target": "#addModal"
            },
            init: function(e, a, t) {
                $(a).removeClass("btn-secondary")
            }
        }],
        responsive: {
            details: {
                display: $.fn.dataTable.Responsive.display.modal({
                    header: function(e) {
                        return "Details of " + e.data().name
                    }
                }),
            }
        },
    });

</script>

@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Area List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Area List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->

<!-- Permission Table -->
<div class="card">
    <div class="p-2">
        @if(count($errors) > 0)
            <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
                <div class="d-flex flex-column ps-1">
                    <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                    @foreach ($errors->all() as $error)
                        <span>{{ $error }}</span>
                    @endforeach
                </div>
            </div>
        @endif
        
        @if($message = Session::get('success'))
            <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
                <div class="d-flex flex-column ps-1">
                    <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
                </div>
            </div>
        @endif
    </div>
    <div class="card-body">
        <div class="card-datatable">
            <table class="datatables-permissions table table-bordered text-nowrap border-bottom" id="file-datatable">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>Code</th>
                        <th>Name</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse ($areas as $area)
                    <tr>
                        <td>{{$loop->iteration}}</td>
                        <td class="text-left">{{ $area->code }}</td>
                        <td class="text-left">{{ $area->name }}</td>
                        <td>
                            <div class="g-2">
                                <a class="btn text-primary btn-sm" href="{{ route('areaEdit', $area->id) }}" data-bs-toggle="tooltip" data-bs-original-title="Edit"><span class="fe fe-edit fs-14"></span></a>
                                <form action="{{ route('area.destroy', $area->id) }}" method="POST" onsubmit="return confirm('Are you sure?');" class="d-inline-block">
                                    @csrf
                                    @method('DELETE')
                                    <button class="btn btn-sm text-danger" type="submit" data-bs-toggle="tooltip" data-bs-original-title="Delete"><span class="fe fe-trash-2 fs-14"></span></button>
                                </form>
                            </div>
                        </td>
                    </tr>
                    @empty
                        <!--<tr>
                            <td colspan="2" class="text-center">No permissions</td>
                        </tr>-->
                    @endforelse
                </tbody>
            </table>
        </div>
    </div>
</div>
<!--/ Permission Table -->
<!-- Add Permission Modal -->
<div class="modal fade" id="addModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header"><h5 class="modal-title">Add Area</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="addPermissionForm" class="row" action="{{ route('area.store') }}" method="post">
                    @csrf
                    <div class="col-12 mb-3">
                        <label class="form-label" for="areacode">Area Code</label>
                        <input type="text" id="areacode" name="areacode" class="form-control" placeholder="Area Code" autofocus />
                    </div>

                    <div class="col-12 mb-3">
                        <label class="form-label" for="areaname">Area Name</label>
                        <input type="text" id="areaname" name="areaname" class="form-control" placeholder="Area Name" autofocus />
                    </div>
                    <div class="col-12 text-center demo-vertical-spacing">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Create</button>
                        <button type="reset" class="btn btn-secondary" data-bs-dismiss="modal" aria-label="Close">Discard</button>
                    </div>
                </form>
                
            </div>
        </div>
    </div>
</div>
<!--/ Add Permission Modal -->
@endsection
