@extends('layouts.admin.master')
@section('title', 'Company')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')

<script type="text/javascript">
    var table = $('.datatables-permissions').DataTable({
       // ... skipped ...
       dom: '<"row mx-1"<"col-sm-12 col-md-3" l><"col-sm-12 col-md-9"<"dt-action-buttons text-xl-end text-lg-start text-md-end text-start d-flex align-items-center justify-content-md-end justify-content-center flex-wrap me-1"<"me-3"f>B>>>t<"row mx-2"<"col-sm-12 col-md-6"i><"col-sm-12 col-md-6"p>>',
        language: {
            sLengthMenu: "_MENU_",
            search: "Search",
            searchPlaceholder: "Search.."
        },
        buttons: [{
            text: "Add Company",
            className: "add-new btn btn-primary mb-3 mb-md-0",
            attr: {
                "data-bs-toggle": "modal",
                "data-bs-target": "#addModal"
            },
            init: function(e, a, t) {
                $(a).removeClass("btn-secondary")
            }
        }],
        responsive: {
            details: {
                display: $.fn.dataTable.Responsive.display.modal({
                    header: function(e) {
                        return "Details of " + e.data().name
                    }
                }),
            }
        },
    });

    $('body').on('click', '.viewbtn', function () {
 
        var userURL = $(this).data('url');
        $.ajax({
            url: userURL,
            type: 'GET',
            dataType: 'json',
            success: function(data) {
                $('#showModal').modal('show');
                $('#vcode').text(data.code);
                $('#vname').text(data.name);
                $('#vaddress').text(data.address);
                $('#vcity').text(data.city);
                $('#vcountry').text(data.country);
                $('#vstate').text(data.state);
                $('#vphoneno').text(data.phone);
                $('#vemailid').text(data.email);
                $('#vpincode').text(data.pincode);
                $('#vfinancialyearstart').text(data.financial_year_start);
                $('#vfinancialyearend').text(data.financial_year_end);
                $('#vgstuin').text(data.gst);
            }
        });
    });

</script>

@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Company List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Company List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->

<!-- Permission Table -->
<div class="card">
    <div class="p-2">
        @if(count($errors) > 0)
            <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
                <div class="d-flex flex-column ps-1">
                    <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                    @foreach ($errors->all() as $error)
                        <span>{{ $error }}</span>
                    @endforeach
                </div>
            </div>
        @endif
        
        @if($message = Session::get('success'))
            <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
                <div class="d-flex flex-column ps-1">
                    <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
                </div>
            </div>
        @endif

        @if($message = Session::get('error'))
            <div class="alert alert-danger d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
                <div class="d-flex flex-column ps-1">
                    <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
                </div>
            </div>
        @endif
    </div>
    <div class="card-body">
        <div class="card-datatable">
            <table class="datatables-permissions table table-bordered text-nowrap border-bottom" id="file-datatable">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>Code</th>
                        <th>Company Type</th>
                        <th>Name</th>
                        <th>Phone</th>
                        <th>Email</th>
                        <th>Pincode</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse ($companys as $company)
                    <tr>
                        <td>{{$loop->iteration}}</td>
                        <td class="text-left">{{ $company->code }}</td>
                        <td class="text-left">{{ ($company->company_type == 1)?'Main':'Branch' }}</td>
                        <td class="text-left">{{ $company->name }}</td>
                        <td class="text-left">{{ $company->phone }}</td>
                        <td class="text-left">{{ $company->email }}</td>
                        <td class="text-left">{{ $company->pincode }}</td>
                        <td>
                            <div class="g-2">
                                <a class="btn text-primary btn-sm" href="{{ route('company.edit', $company->id) }}" data-bs-toggle="tooltip" data-bs-original-title="Edit"><span class="fe fe-edit fs-14"></span></a>
                                <a class="btn text-primary btn-sm viewbtn" href="javascript:void(0)" data-url="{{ route('company.show', $company->id) }}" data-bs-toggle="tooltip" data-bs-original-title="View"><span class="fe fe-eye fs-14"></span></a>
                                <form action="{{ route('company.destroy', $company->id) }}" method="POST" onsubmit="return confirm('Are you sure?');" class="d-inline-block">
                                    @csrf
                                    @method('DELETE')
                                    <button class="btn btn-sm text-danger" type="submit" data-bs-toggle="tooltip" data-bs-original-title="Delete"><span class="fe fe-trash-2 fs-14"></span></button>
                                </form>
                            </div>
                        </td>
                    </tr>
                    @empty
                        <!--<tr>
                            <td colspan="2" class="text-center">No permissions</td>
                        </tr>-->
                    @endforelse
                </tbody>
            </table>
        </div>
    </div>
</div>
<!--/ Permission Table -->
<!-- Add Permission Modal -->
<div class="modal fade" id="addModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header"><h5 class="modal-title">Add Company</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close">x</button>
            </div>
            <div class="modal-body">
                <div class="container-fluid">
                    <x-company.create-form type="modal"/>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="modal fade" id="showModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header"><h5 class="modal-title">Add Company</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close">x</button>
            </div>
            <div class="modal-body">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-6">
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vcode">Code</label><div class="form-control col-9" id="vcode"></div>
                            </div>
                        </div>
                        <div class="col-6">
                            <div class="row mb-3">
                                <label class="form-label col-5" for="vname">Name</label>
                                <div class="form-control col-7" id="vname"></div>
                            </div>
                        </div>
                    </div>
                    <hr>
                    <div class="row">
                        <div class="col-6">
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vaddress">Address</label>
                                <div class="form-control col-9" id="vaddress"></div>
                            </div>
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vcity">City</label>
                                <div class="form-control col-9" id="vcity"></div>
                            </div>
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vcountry">Country</label>
                                <div class="form-control col-9" id="vcountry"></div>
                            </div>
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vstate">State</label>
                                <div class="form-control col-9" id="vstate"></div>
                            </div>
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vphoneno">Phone No</label>
                                <div class="form-control col-9" id="vphoneno"></div>
                            </div>
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vemailid">Email</label>
                                <div class="form-control col-9" id="vemailid"></div>
                            </div>
                            <div class="row mb-3">
                                <label class="form-label col-3" for="vpincode">Pincode</label>
                                <div class="form-control col-9" id="vpincode"></div>
                            </div>
                        </div>
                        <div class="col-6">
                            <div class="row mb-3">
                                <label class="form-label col-5" for="vfinancialyearstart">Financial Year Start</label>
                                <div class="form-control col-7" id="vfinancialyearstart"></div>
                            </div>
                            <div class="row mb-3">
                                <label class="form-label col-5" for="vfinancialyearend">Financial End Year</label>
                                <div class="form-control col-7" id="vfinancialyearend"></div>
                            </div>
                            <hr>
                            <div class="row mb-3">
                                <label class="form-label col-5" for="vgstuin">GSTIN/UIN</label>
                                <div class="form-control col-7" id="vgstuin"></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--/ Add Permission Modal -->
@endsection
