@extends('layouts.admin.master')
@section('title', 'Purchase Item Wise Report')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')
<script type="text/javascript" src="https://unpkg.com/xlsx@0.15.1/dist/xlsx.full.min.js"></script>
<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $('#product').select2({
        placeholder: 'Select Product',
        ajax: {
            url: "{{route('productSearch')}}",
            dataType: 'json',
            delay: 250,
            processResults: function (data) {
                return {
                    results: $.map(data, function (item) {
                            return {
                                text: item.name,
                                id: item.id
                            }
                      })
                };
            },
            cache: true
        }
    });

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });

    function ExportToExcel(type, fn, dl)
    {
        var branch = "{{ (isset($reports['branch']))?$reports['branch']:'' }}";
        var dateval = "{{ (isset($reports['dates']))?$reports['dates']:'' }}";
        var elt = document.getElementById('tbl_exporttable_to_xls');
        var wb = XLSX.utils.table_to_book(elt, { sheet: "sheet1" });
        return dl ?
        XLSX.write(wb, { bookType: type, bookSST: true, type: 'base64' }):
        XLSX.writeFile(wb, fn || (branch+'-'+dateval+'-Sales-Return.' + (type || 'xlsx')));
    }
</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Purchase Item Wise List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Report</a></li>
            <li class="breadcrumb-item active" aria-current="page">Purchase Item Wise List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-12 col-md-12">
        <div class="card">
            <div class="card-body">
                <form method="post" action="{{ route('report.purchase.item.wise.list') }}">
                    @csrf
                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="todate">To Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="branch">Branch</label>
                            <select id="branch" name="branch" class="form-control branch">
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                    <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="col">
                            <label class="form-label" for="product">Product</label>
                            <select id="product" name="product" class="form-control select2" required>
                                <option value="">--Select--</option>
                            </select>
                        </div>
                    </div>

                    <div class="col-12 text-center">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-lg-12 col-md-12">
        @if(isset($sales) && count($sales) > 0)
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    @if(isset($reports['branch']) && !empty($reports['branch']))
                        Branch: {{ $reports['branch'] }}
                    @endif
                </h5>
                <h5 class="mb-0">
                    @if(isset($reports['product']) && !empty($reports['product']))
                        Product: {{ $reports['product'] }}
                    @endif
                </h5>
                <small class="text-muted float-end">Date: {{ $reports['dates'] }} <a href="javascript:void(0);" id="toexl" onclick="ExportToExcel('xlsx')" class="btn btn-primary">Export To Excell</a></small>
            </div>
            <div class="card-body">
                

                <table class="table" id="tbl_exporttable_to_xls">
                    <thead>
                        <tr>
                            <th>#</th>
                            <th>Date</th>
                            <th>Invoice No</th>
                            <th>Customer</th>
                            <th>GSTIN</th>
                            <th>Product</th>
                            <th>Qty</th>
                            <th>Total</th>
                        </tr>
                    </thead>
                    <tbody>

                        @foreach($sales as $sale)
                        <tr>
                            <td>{{ $loop->iteration }}</td>
                            <td>{{ $sale->purchase_date }}</td>
                            <td>{{ $sale->invoice_no }}</td>
                            <td>{{ $sale->vendor->name }}</td>
                            <td>{{ $sale->vendor->gstin }}</td>
                            <td>{{ $reports['product'] }}</td>
                            <td>{{ $sale->purchaseDetails()->where('product_master_id', $product)->first()->quantity }}</td>
                            <td>{{ $sale->grand_total }}</td>
                        </tr>
                        @endforeach

                        <tr>
                            <th colspan="7" class="text-end">Total: </th>
                            <th>{{ $sales->sum('grand_total') }}</th>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
        @endif
    </div>
</div>
<!--/ Permission Table -->
@endsection
