@extends('layouts.admin.master')
@section('title', 'Sale Report')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')
<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });

</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Sales List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Sales List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-5 col-md-12">
        <div class="card">
            <div class="card-body">
                <form method="post" action="{{ route('report.sales.list') }}">
                    @csrf
                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="todate">To Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" required>
                        </div>
                    </div>

                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="branch">Branch</label>
                            <select id="branch" name="branch" class="form-control branch">
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>

                    <div class="col-12 text-center">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-lg-7 col-md-12">
        @if(isset($reports) && count($reports) > 0)
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    @if(isset($reports['branch']) && !empty($reports['branch']))
                        Branch: {{ $reports['branch'] }}
                    @endif
                </h5>
                <small class="text-muted float-end">Date: {{ $reports['dates'] }}</small>
            </div>
            <div class="card-body">
                
                <table class="table" id="datatable">
                    <tbody>
                        <tr>
                            <th>Total Sales</th>
                            <td>{{$reports['saleCount']}}</td>
                        </tr>
                        <tr>
                            <th>Total Amount</th>
                            <td>{{$reports['totalAmount']}}</td>
                        </tr>
                        <tr>
                            <th>Total Setteled</th>
                            <td>{{$reports['setteledCount']}}</td>
                        </tr>
                        <tr>
                            <th>Pending Setteled</th>
                            <td>{{$reports['notSetteledCount']}}</td>
                        </tr>
                        <tr>
                            <th>Setteled Amount</th>
                            <td>{{$reports['setteledAmount']}}</td>
                        </tr>
                        <tr>
                            <th>Pending Setteled Amount</th>
                            <td>{{$reports['notSetteledAmount']}}</td>
                        </tr>
                        <tr>
                            <th>Total Cash</th>
                            <td>{{$reports['cashCount']}}</td>
                            <th>Cash Total</th>
                            <td>{{$reports['cashTotal']}}</td>
                        </tr>
                        <tr>
                            <th>Total Card</th>
                            <td>{{$reports['cardCount']}}</td>
                            <th>Card Total</th>
                            <td>{{$reports['cardTotal']}}</td>
                        </tr>
                        <tr>
                            <th>Total Transfer</th>
                            <td>{{$reports['transferCount']}}</td>
                            <th>Transfer Total</th>
                            <td>{{$reports['transferTotal']}}</td>
                        </tr>
                        <tr>
                            <th>Total Credit</th>
                            <td>{{$reports['creditCount']}}</td>
                            <th>Credit Total</th>
                            <td>{{$reports['creditTotal']}}</td>
                        </tr>
                        <tr>
                            <th>Total UPI</th>
                            <td>{{$reports['upiCount']}}</td>
                            <th>UPI Total</th>
                            <td>{{$reports['upiTotal']}}</td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
        @endif
    </div>
</div>
<!--/ Permission Table -->
@endsection
