@extends('layouts.admin.master')
@section('title', 'Sales Return Report')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')
<script type="text/javascript" src="https://unpkg.com/xlsx@0.15.1/dist/xlsx.full.min.js"></script>
<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });

    function ExportToExcel(type, fn, dl)
    {
        var branch = "{{ (isset($reports['branch']))?$reports['branch']:'' }}";
        var dateval = "{{ (isset($reports['dates']))?$reports['dates']:'' }}";
        var elt = document.getElementById('tbl_exporttable_to_xls');
        var wb = XLSX.utils.table_to_book(elt, { sheet: "sheet1" });
        return dl ?
        XLSX.write(wb, { bookType: type, bookSST: true, type: 'base64' }):
        XLSX.writeFile(wb, fn || (branch+'-'+dateval+'-Sales-Return.' + (type || 'xlsx')));
    }
</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Sales Return List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Report</a></li>
            <li class="breadcrumb-item active" aria-current="page">Sales Return List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-12 col-md-12">
        <div class="card">
            <div class="card-body">
                <form method="post" action="{{ route('report.sales.return.list') }}">
                    @csrf
                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="todate">To Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="branch">Branch</label>
                            <select id="branch" name="branch" class="form-control branch">
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                    <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>

                    <div class="col-12 text-center">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-lg-12 col-md-12">
        @if(isset($sales) && count($sales) > 0)
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    @if(isset($reports['branch']) && !empty($reports['branch']))
                        Branch: {{ $reports['branch'] }}
                    @endif
                </h5>
                <small class="text-muted float-end">Date: {{ $reports['dates'] }} <a href="javascript:void(0);" id="toexl" onclick="ExportToExcel('xlsx')" class="btn btn-primary">Export To Excell</a></small>
            </div>
            <div class="card-body">
                
                <table class="table" id="tbl_exporttable_to_xls">
                    <thead>
                        <tr>
                            <th>#</th>
                            <th>Date</th>
                            <th>Invoice No</th>
                            <th>Customer</th>
                            <th>GSTIN</th>
                            <th>Item 28%</th>
                            <th>CGST 14%</th>
                            <th>CGST 14%</th>
                            <th>Item 18%</th>
                            <th>CGST 9%</th>
                            <th>SGST 9%</th>
                            <th>Item 12%</th>
                            <th>CGST 6%</th>
                            <th>SGST 6%</th>
                            <th>Item 5%</th>
                            <th>CGST 2.5%</th>
                            <th>SGST 2.5%</th>
                            <th>Item 0%</th>
                            <th>CGST 0%</th>
                            <th>SGST 0%</th>
                            <th>Total</th>
                            <th>Freight</th>
                            <th>Other Expence</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($sales as $sale)
                        <tr>
                            <td>{{ $loop->iteration }}</td>
                            <td>{{ $sale->sale_date }}</td>
                            <td>{{ $sale->invoice_no }}</td>
                            <td>{{ $sale->customer->name }}</td>
                            <td>{{ $sale->customer->gstin }}</td>
                            <td>{{ $sale->taxtwentyeight_amount }}</td>
                            <td>{{ $sale->taxtwentyeight_cgstamount }}</td>
                            <td>{{ $sale->taxtwentyeight_sgstamount }}</td>
                            <td>{{ $sale->taxeighteen_amount }}</td>
                            <td>{{ $sale->taxeighteen_cgstamount }}</td>
                            <td>{{ $sale->taxeighteen_sgstamount }}</td>
                            <td>{{ $sale->taxtwelve_amount }}</td>
                            <td>{{ $sale->taxtwelve_cgstamount }}</td>
                            <td>{{ $sale->taxtwelve_sgstamount }}</td>
                            <td>{{ $sale->taxfive_amount }}</td>
                            <td>{{ $sale->taxfive_cgstamount }}</td>
                            <td>{{ $sale->taxfive_sgstamount }}</td>
                            <td>{{ $sale->taxzero_amount }}</td>
                            <td>{{ $sale->taxzero_cgstamount }}</td>
                            <td>{{ $sale->taxzero_sgstamount }}</td>
                            <td>{{ $sale->grand_total }}</td>
                            <td>{{ $sale->freight_coolie }}</td>
                            <td>{{ $sale->otherexp }}</td>
                        </tr>
                        @endforeach

                        <tr>
                            <th colspan="5" class="text-end">Total</th>
                            <th>{{ $sales->sum('taxtwentyeight_amount') }}</th>
                            <th>{{ $sales->sum('taxtwentyeight_cgstamount') }}</th>
                            <th>{{ $sales->sum('taxtwentyeight_sgstamount') }}</th>
                            <th>{{ $sales->sum('taxeighteen_amount') }}</th>
                            <th>{{ $sales->sum('taxeighteen_cgstamount') }}</th>
                            <th>{{ $sales->sum('taxeighteen_sgstamount') }}</th>
                            <th>{{ $sales->sum('taxtwelve_amount') }}</th>
                            <th>{{ $sales->sum('taxtwelve_cgstamount') }}</th>
                            <th>{{ $sales->sum('taxtwelve_sgstamount') }}</th>
                            <th>{{ $sales->sum('taxfive_amount') }}</th>
                            <th>{{ $sales->sum('taxfive_cgstamount') }}</th>
                            <th>{{ $sales->sum('taxfive_sgstamount') }}</th>
                            <th>{{ $sales->sum('taxzero_amount') }}</th>
                            <th>{{ $sales->sum('taxzero_cgstamount') }}</th>
                            <th>{{ $sales->sum('taxzero_sgstamount') }}</th>
                            <th>{{ $sales->sum('grand_total') }}</th>
                            <th>{{ $sales->sum('freight_coolie') }}</th>
                            <th>{{ $sales->sum('otherexp') }}</th>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
        @endif
    </div>
</div>
<!--/ Permission Table -->
@endsection
