@extends('layouts.admin.master')
@section('title', 'Sale Report')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')
<script type="text/javascript" src="https://unpkg.com/xlsx@0.15.1/dist/xlsx.full.min.js"></script>
<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $('.customer').select2({
        placeholder: "--Select--",
        width: '100%'
    });

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });

    function ExportToExcel(type, fn, dl)
    {
        var branch = "{{ (isset($reports['branch']))?$reports['branch']:'' }}";
        var dateval = "{{ (isset($reports['dates']))?$reports['dates']:'' }}";
        var elt = document.getElementById('tbl_exporttable_to_xls');
        var wb = XLSX.utils.table_to_book(elt, { sheet: "sheet1" });
        return dl ?
        XLSX.write(wb, { bookType: type, bookSST: true, type: 'base64' }):
        XLSX.writeFile(wb, fn || (branch+'-'+dateval+'-Sales-Details.' + (type || 'xlsx')));
    }
</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Sales List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Sales List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-5 col-md-12">
        <div class="card">
            <div class="card-body">
                <form method="post" action="{{ route('report.sales.list.details') }}">
                    @csrf
                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="todate">To Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" required>
                        </div>
                    </div>

                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="customer">Customer</label>
                            <select id="customer" name="customer" class="form-control customer">
                                <option value="">--Select--</option>
                                @foreach($customers as $customer)
                                    <option value="{{$customer->id}}">{{$customer->name}}</option>
                                @endforeach
                            </select>
                        </div>

                        <div class="col">
                            <label class="form-label" for="branch">Branch</label>
                            <select id="branch" name="branch" class="form-control branch">
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>

                    <div class="col-12 text-center">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-lg-7 col-md-12">
        @if(isset($sales) && count($sales) > 0)
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    @if(isset($reports['branch']) && !empty($reports['branch']))
                        Branch: {{ $reports['branch'] }}
                    @endif
                </h5>
                <small class="text-muted float-end">Date: {{ $reports['dates'] }} <a href="javascript:void(0);" id="toexl" onclick="ExportToExcel('xlsx')" class="btn btn-primary">Export To Excell</a></small>
            </div>
            <div class="card-body">
                
                <table class="table" id="tbl_exporttable_to_xls">
                    <thead>
                        <tr>
                            <th colspan="10" class="text-center" align="center" valign="middle">{{ $reports['branch'] }} <br> {{ $reports['dates'] }}</th>
                        </tr>
                        <tr><th colspan="10" class="text-center" align="center" valign="middle">{{ $customerName }}</th></tr>
                        <tr>
                            <th>Inv Date</th>
                            <th>Inv No</th>
                            <th>Customer</th>
                            <th>Place of Supply</th>
                            <th>Driver</th>
                            <th>Vehicle No</th>
                            <th>Item Name</th>
                            <th>Price</th>
                            <th>Quantity</th>
                            <th>Total Amount</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach($sales as $sale)
                            @php
                                $regno = '';
                                $driverName = $placeName = '' ;
                                if(!empty($sale->sale->site_data))
                                {
                                    $siteData = json_decode($sale->sale->site_data);
                                    $driverName = (isset($siteData->driver)) ? $siteData->driver : '';
                                    $placeName = (isset($siteData->site)) ? $siteData->site : '';
                                }
                                if(!empty($sale->sale->vehicle->reg_no))
                                {
                                    $regno = $sale->sale->vehicle->reg_no;
                                }
                                $total_tax = ($sale->cgst_amount + $sale->sgst_amount);
                            @endphp
                            <tr>
                                <td>{{ date('d-m-Y', strtotime($sale->sale->sale_date)) }}</td>
                                <td>{{ $sale->sale->invoice_no }}</td>
                                <td>{{ $sale->sale->customer->name }}</td>
                                <td>{{ (!is_null($placeName))?$placeName:'' }}</td>
                                <td>{{ (!is_null($driverName))?$driverName:'' }}</td>
                                <td>{{ (!is_null($regno))?$regno:'' }}</td>
                                <td>{{ $sale->product->name }}</td>
                                <td>{{ round((($sale->taxable_amount + $total_tax) / $sale->quantity), 2) }}</td>
                                <td>{{ round($sale->quantity, 2) }}</td>
                                <td>{{ round($sale->item_total, 2) }}</td>
                            </tr>
                        @endforeach
                        
                    </tbody>
                </table>
            </div>
        </div>
        @endif
    </div>
</div>
<!--/ Permission Table -->
@endsection
