@extends('layouts.admin.master')
@section('title', 'Sale Report')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')
<script src="https://cdn.jsdelivr.net/gh/linways/table-to-excel@v1.0.4/dist/tableToExcel.js"></script>
<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });
</script>
<script>
    $(document).ready(function () {
        var maxW = 0;
        $('#datatable td').each(function () {
            var x = this.innerText.length;
            if (x > maxW) {
                maxW = x;
            }
        });
        $('#datatable th').attr("width", maxW + 'px');
        $('#datatable td').css('min-width', maxW + 'px');


        $("#btnExport").click(function () {
            let table = document.getElementsByTagName("table");
            TableToExcel.convert(table[0], {
                name: `profitList.xlsx`,
                sheet: {
                    name: 'profitList'
                }
            });
        });
    });
</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Sales List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Sales List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-5 col-md-12">
        <div class="card">
            <div class="card-body">
                <form method="post" action="{{ route('report.profit.sales.list') }}">
                    @csrf
                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="todate">To Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" required>
                        </div>
                    </div>

                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="branch">Branch</label>
                            <select id="branch" name="branch" class="form-control branch">
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>

                    <div class="col-12 text-center">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-lg-7 col-md-12">
        @if(isset($reports) && count($reports) > 0)
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    @if(isset($reports['branch']) && !empty($reports['branch']))
                        Branch: {{ $reports['branch'] }}
                    @endif
                </h5>
                <small class="text-muted float-end">Date: {{ $reports['dates'] }}</small>
            </div>
            <div class="card-body">
                <table class="table" id="datatable">
                    <thead>
                        <tr>
                            <th>#</th>
                            <th>Date</th>
                            <th>Invoice No</th>
                            <th>Bill Amount</th>
                            <th>Profit</th>
                            <th>Customer</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $profitsum = 0;
                            $billamtsum =0;
                        @endphp
                        @foreach($reports['saleData'] as $sale)
                            @php
                                $grossTotal = 0;
                                $productCostTotal = 0;
                                foreach($sale->saleClientDetails as $saleItems)
                                {
                                    $grossTotal = $grossTotal + $saleItems->gross_amount;
                                    $productCostTotal = $productCostTotal + ($saleItems->quantity * $saleItems->product->price->cost);
                                }

                                $profitsum = $profitsum + ($sale->netvalue - $productCostTotal);
                                $billamtsum = $billamtsum + $sale->grand_total;
                                $profit = round(($sale->netvalue - $productCostTotal),2);
                            @endphp
                        <tr>
                            <td>{{ $loop->iteration }}</td>
                            <td>{{ $sale->sale_date }}</td>
                            <td>{{ $sale->invoice_no }}</td>
                            <td>{{ $sale->grand_total }}</td>
                            <td>{{ $profit }}</td>
                            <td>{{ $sale->customer->name }}</td>
                        </tr>
                        @endforeach
                        <tr>
                            <td colspan="3">TOTAL</td>
                            <td>{{ $billamtsum }}</td>
                            <td colspan="2">{{ round($profitsum,2) }}</td>
                            
                        </tr>
                    </tbody>
                </table>
                <div class="text-center mt-4">
                    <a href="#" class="btn btn-primary" id="btnExport">Export</a>
                </div>
            </div>
        </div>
        @endif
    </div>
</div>
<!--/ Permission Table -->
@endsection
