@extends('layouts.admin.master')
@section('title', 'Sale Tax Split Detail Report')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')
<script type="text/javascript" src="https://unpkg.com/xlsx@0.15.1/dist/xlsx.full.min.js"></script>
<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });

    function ExportToExcel(type, fn, dl)
    {
        var branch = "{{ (isset($reports['branch']))?$reports['branch']:'' }}";
        var dateval = "{{ (isset($reports['dates']))?$reports['dates']:'' }}";
        var elt = document.getElementById('tbl_exporttable_to_xls');
        var wb = XLSX.utils.table_to_book(elt, { sheet: "sheet1" });
        return dl ?
        XLSX.write(wb, { bookType: type, bookSST: true, type: 'base64' }):
        XLSX.writeFile(wb, fn || (branch+'-'+dateval+'-Sales-Details.' + (type || 'xlsx')));
    }
</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Tax Split Detail</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Tax Split Detail</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-12 col-md-12">
        <div class="card">
            <div class="card-body">
                <form method="post" action="{{ route('report.sales.tax.split.list.details') }}">
                    @csrf
                    <div class="row mb-3">
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" value="{{ old('fromdate')?old('fromdate'):date('Y-m-d') }}" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="todate">To Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" value="{{ old('todate')?old('todate'):date('Y-m-d') }}" required>
                        </div>
                        <div class="col">
                            <label class="form-label" for="branch">Branch</label>
                            <select id="branch" name="branch" class="form-control branch">
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                    <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="col">
                            <label class="form-label" for="tax">Tax</label>
                            <select id="tax" name="tax" class="form-control">
                                <option value="">All</option>
                                <option value="GST">GST</option>
                                <option value="IGST">IGST</option>
                                <option value="No Tax">No Tax</option>
                            </select>
                        </div>

                        <div class="col">
                            <label class="form-label" for="sales_type">Type</label>
                            <select id="sales_type" name="sales_type" class="form-control">
                                <option value="">All</option>
                                <option value="B2B">B2B</option>
                                <option value="B2CS">B2CS</option>
                                <option value="B2CL">B2CL</option>
                            </select>
                        </div>
                    </div>

                    <div class="col-12 text-center">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-lg-12 col-md-12">
        @if(isset($sales) && count($sales) > 0)
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    @if(isset($reports['branch']) && !empty($reports['branch']))
                        Branch: {{ $reports['branch'] }}
                    @endif
                </h5>
                <small class="text-muted float-end">Date: {{ $reports['dates'] }} <a href="javascript:void(0);" id="toexl" onclick="ExportToExcel('xlsx')" class="btn btn-primary">Export To Excell</a></small>
            </div>
            <div class="card-body">
                
                <table class="table" id="tbl_exporttable_to_xls">
                    <thead>
                        <tr>
                            <th>Invoice Date</th>
                            <th>Invoice No</th>
                            <th>Type</th>
                            <th>Customer</th>
                            <th>GSTIN/UIN</th>
                            <th>Bill Amount</th>
                            <th>Quantity</th>
                            <th>HSN/SAC</th>
                            <th>Taxable</th>
                            <th>CGST Rate</th>
                            <th>CGST Amount</th>
                            <th>SGST Rate</th>
                            <th>SGST Amount</th>
                            <th>IGST Rate</th>
                            <th>IGST Amount</th>
                            <th>Freight Coolie</th>
                            <th>Other Expense</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $grandtotal = 0;
                            $totalQuantity = $totalTaxable = $cgstamountTotal = $sgstamountTotal = $igstamountTotal = $freightCoolie = $otherexp = 0;
                            $valExist = array();
                        @endphp
                        @foreach($sales as $sale)
                            @php
                                $total_tax = ($sale->cgst_amount + $sale->sgst_amount);
                                
                                $totalQuantity = $totalQuantity + $sale->quantity;
                                $totalTaxable = $totalTaxable + $sale->taxable_amount;
                                $cgstamountTotal = $cgstamountTotal + (($sale->sale->tax_type != 'IGST') ? $sale->cgst_amount : '0.00');
                                $sgstamountTotal = $sgstamountTotal + (($sale->sale->tax_type != 'IGST') ? $sale->sgst_amount : '0.00');
                                $igstamountTotal = $igstamountTotal + (($sale->sale->tax_type == 'IGST') ? $total_tax : '0.00');
                                $freightCoolie = $freightCoolie + $sale->sale->freight_coolie;
                                $otherexp = $otherexp + $sale->sale->otherexp;
                                if(!in_array($sale->sale->invoice_no, $valExist))
                                {
                                    $grandtotal = $grandtotal + $sale->sale->grand_total;
                                }
                            @endphp
                            <tr>
                                <td>{{ date('d-m-Y', strtotime($sale->sale->sale_date)) }}</td>
                                <td>{{ $sale->sale->invoice_no }}</td>
                                <td>{{ $sale->sale->bill_type }}</td>
                                <td>{{ $sale->sale->customer->name }}</td>
                                <td>{{ $sale->sale->customer->gstin }}</td>
                                <td>{{ (!in_array($sale->sale->invoice_no, $valExist))?$sale->sale->grand_total:'' }}</td>
                                <td>{{ $sale->quantity }}</td>
                                <td>{{ $sale->product->hsncode }}</td>
                                <td>{{ $sale->taxable_amount }}</td>
                                <td>{{ ($sale->sale->tax_type != 'IGST') ? ($sale->cgst / 2) : '0.00' }}</td>
                                <td>{{ ($sale->sale->tax_type != 'IGST') ? $sale->cgst_amount : '0.00' }}</td>
                                <td>{{ ($sale->sale->tax_type != 'IGST') ? $sale->sgst : '0.00' }}</td>
                                <td>{{ ($sale->sale->tax_type != 'IGST') ? $sale->sgst_amount : '0.00' }}</td>
                                <td>{{ ($sale->sale->tax_type == 'IGST') ? $sale->cgst : '0.00' }}</td>
                                <td>{{ ($sale->sale->tax_type == 'IGST') ? $total_tax : '0.00' }}</td>
                                <td>{{ $sale->sale->freight_coolie }}</td>
                                <td>{{ $sale->sale->otherexp }}</td>
                            </tr>
                            @php
                                $valExist[] = $sale->sale->invoice_no;
                            @endphp
                        @endforeach
                            <tr>
                                <th></th>
                                <th></th>
                                <th></th>
                                <th></th>
                                <th></th>
                                <th>{{ $grandtotal }}</th>
                                <th>{{ $totalQuantity }}</th>
                                <th></th>
                                <th>{{ $totalTaxable }}</th>
                                <th></th>
                                <th>{{ $cgstamountTotal }}</th>
                                <th></th>
                                <th>{{ $sgstamountTotal }}</th>
                                <th></th>
                                <th>{{ $igstamountTotal }}</th>
                                <th>{{ $freightCoolie }}</th>
                                <th>{{ $otherexp }}</th>
                            </tr>
                    </tbody>
                </table>
            </div>
        </div>
        @endif
    </div>
</div>
<!--/ Permission Table -->
@endsection
