@extends('layouts.admin.master')
@section('title', 'Transaction Report')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
        .select2-selection.select2-selection--single{ padding-right: 10px !important; }
    </style>
@endsection

@section('vendor-script')
<script type="text/javascript" src="https://unpkg.com/xlsx@0.15.1/dist/xlsx.full.min.js"></script>
<script type="text/javascript">
    $('#accountGroup').select2({
        placeholder: "--Select--",
        width: 'resolve',
        allowClear: true,
        closeOnSelect: true,
    });
    

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });

</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Transaction List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Report</a></li>
            <li class="breadcrumb-item active" aria-current="page">Transaction List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex mb-3" role="alert">
            <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center mb-3" role="alert">
            <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif

    @if($message = Session::get('error'))
        <div class="alert alert-danger d-flex align-items-center mb-3" role="alert">
            <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-4 col-md-4 mx-auto">
        <div class="card">
            <div class="card-body">
                <form id="searchTransaction" method="post" action="{{ route('search.accounts.list') }}" target="_blank">
                    @csrf
                    <div class="row mb-2">
                        <div class="col-12 mb-3">
                            <label class="form-label" for="accountGroup">Account Group</label>
                            <select id="accountGroup" name="accountGroup" class="form-control select2" required>
                                <option value="">--Select--</option>
                                @foreach($groups as $baseGroup)
                                <option value="{{$baseGroup->id}}">{{$baseGroup->name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>

                    <div class="row mb-2">
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" value="{{ date('Y-m-d') }}" required>
                        </div>
                        
                        <div class="col">
                            <label class="form-label" for="todate">To Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" value="{{ date('Y-m-d') }}" required>
                        </div>
                    </div>

                    <div class="col-12 text-center mt-2">
                        <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
<!--/ Permission Table -->
@endsection
