@extends('layouts.admin.master')
@section('title', 'Day Book')

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')
<script type="text/javascript" src="https://unpkg.com/xlsx@0.15.1/dist/xlsx.full.min.js"></script>
<script type="text/javascript">
    $('.branch').select2({
        minimumResultsForSearch: '',
        width: '100%'
    });

    $(document).on('select2:open', function(e) {
        window.setTimeout(function () {
            document.querySelector('input.select2-search__field').focus();
        }, 0);
    });

    function ExportToExcel(type, fn, dl)
    {
        var branch = "{{ (isset($reports['branch']))?$reports['branch']:'' }}";
        var dateval = "{{ (isset($reports['dates']))?$reports['dates']:'' }}";
        var elt = document.getElementById('tbl_exporttable_to_xls');
        var wb = XLSX.utils.table_to_book(elt, { sheet: "sheet1" });
        return dl ?
        XLSX.write(wb, { bookType: type, bookSST: true, type: 'base64' }):
        XLSX.writeFile(wb, fn || (branch+'-'+dateval+'-Stock-Details.' + (type || 'xlsx')));
    }
</script>
@if(isset($productVal) && count($productVal) > 0)
<script type="text/javascript">
    @if(isset($reports['branch']) && !empty($reports['branch']))
        var branchdata = "Branch: {{ $reports['branch'] }}";
    @else
        var branchdata = "All";
    @endif
    var table = $('.tbl_exporttable_to_xls').DataTable({
       // ... skipped ...
       dom: '<"row mx-1"<"col-sm-12 col-md-3" l><"col-sm-12 col-md-9"<"dt-action-buttons text-xl-end text-lg-start text-md-end text-start d-flex align-items-center justify-content-md-end justify-content-center flex-wrap me-1"<"me-3"f>B>>>t<"row mx-2"<"col-sm-12 col-md-6"i><"col-sm-12 col-md-6"p>>',
        language: {
            sLengthMenu: "_MENU_",
            search: "Search",
            searchPlaceholder: "Search.."
        },
        buttons: [
                    {
                        extend: 'excel',
                        text: 'Export To Excell',

                        title: branchdata,
                        messageTop: "Date: {{ $reports['dates'] }}",
                        exportOptions: {
                            modifier: {
                                page: 'all'
                            }
                        }
                    }
                ],
        ordering: false,
        responsive: {
            details: {
                display: $.fn.dataTable.Responsive.display.modal({
                    header: function(e) {
                        return "Details of " + e.data().name
                    }
                }),
            }
        },
    });

</script>
@endif

@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Day Book</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Day Book</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<div class="row"> 
    <div class="col-lg-12 col-md-12">
        <div class="card">
            <div class="card-body">
                <form method="post" action="{{ route('transactions.daybook.search') }}">
                    @csrf
                    <div class="row mb-2">
                        <?php /*
                        <div class="col">
                            <label class="form-label" for="fromdate">From Date</label>
                            <input type="date" class="form-control" name="fromdate" id="fromdate" required>
                        </div>
                        */ ?>
                        <div class="col">
                            <label class="form-label" for="todate">Date</label>
                            <input type="date" class="form-control" name="todate" id="todate" required>
                        </div>

                        <div class="col">
                            <label class="form-label" for="branch">Branch</label>
                            <select id="branch" name="branch" class="form-control branch">
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>

                        <div class="col text-center">
                            <label class="form-label" for="branch">&nbsp;</label>
                            <button type="submit" class="btn btn-primary me-sm-3 me-1">Search</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="col-lg-12 col-md-12">
        @if(isset($transactionLists) && count($transactionLists) > 0)
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h5 class="mb-0">
                    @if(isset($reports['branch']) && !empty($reports['branch']))
                        Branch: {{ $reports['branch'] }}
                    @endif
                </h5>
                <small class="text-muted float-end">Date: {{ $reports['dates'] }} </small>
            </div>
            <div class="card-body">
                <table class="table tbl_exporttable_to_xls" id="tbl_exporttable_to_xls">
                    <thead>
                        <tr>
                            <th>Type</th>
                            <th>Credit</th>
                            <th>Debit</th>
                        </tr>
                    </thead>
                    <tbody>
                        @php
                            $creditAmount = 0;
                            $debitAmount = 0;
                        @endphp
                        @foreach($transactionLists as $transaction)
                            @php
                                if(!is_null($transaction->account_group_name))
                                {
                                    $transactionName = $transaction->account_group_name;
                                }
                                elseif($transaction->transaction_type == 1)
                                {
                                    $transactionName = 'Sales';
                                }
                                elseif($transaction->transaction_type == 2)
                                {
                                    $transactionName = 'Purchase';
                                }
                                elseif($transaction->transaction_type == 3)
                                {
                                    $transactionName = 'Receipt';
                                }
                                elseif($transaction->transaction_type == 4)
                                {
                                    $transactionName = 'Payment';
                                }
                                elseif($transaction->transaction_type == 5)
                                {
                                    $transactionName = 'Opening Balance';
                                }
                                elseif($transaction->transaction_type == 6)
                                {
                                    $transactionName = 'Ledger';
                                }
                                elseif($transaction->transaction_type == 7)
                                {
                                    $transactionName = 'Sales Return';
                                }
                                elseif($transaction->transaction_type == 8)
                                {
                                    $transactionName = 'Purchase Return';
                                }
                                elseif($transaction->transaction_type == 9)
                                {
                                    $transactionName = 'Debit Note';
                                }
                                elseif($transaction->transaction_type == 10)
                                {
                                    $transactionName = 'Credit Note';
                                }
                                else
                                {
                                    $transactionName = 'Other';
                                }

                                if($transaction->transaction_type != 2)
                                {
                                    $totalCredit = $transaction->total_credit_amount;
                                }
                                else
                                {
                                    $totalCredit = 0.00;
                                }

                                if($transaction->transaction_type != 1)
                                {
                                    $totalDebit = $transaction->total_debit_amount;
                                }
                                else
                                {
                                    $totalDebit = 0.00;
                                }

                                $creditAmount = $creditAmount + $totalCredit;
                                $debitAmount = $debitAmount + $totalDebit;
                            @endphp
                            <tr>
                                <td>{{ $transactionName }}</td>
                                <td>{{ $totalCredit }}</td>
                                <td>{{ $totalDebit }}</td>
                            </tr>
                        @endforeach
                        <tr>
                            <th class="text-end">Total</th>
                            <th>{{ $creditAmount }}</th>
                            <th>{{ $debitAmount }}</th>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
        @endif
    </div>
</div>
<!--/ Permission Table -->
@endsection
