@extends('layouts.admin.master')
@section('title', 'Stock Transfer')

@section('vendor-style')
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.css">
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')

<script src="https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js"></script>
<script type="text/javascript">
$('.branch').select2({
    minimumResultsForSearch: '',
    width: '100%'
});

$(document).on('select2:open', function(e) {
    window.setTimeout(function () {
        document.querySelector('input.select2-search__field').focus();
    }, 0);
});
</script>

<script type="text/javascript">
    $(function() {

        // Remove button click
        $(document).on('click','.remove',function(){
            $(this).parents('tr').remove();
            i = i - 1;
            $('.reindex').each(function(i){
                $(this).find('.prdid').attr('name', 'prdid[' + (i + 1)+']');
                $(this).find('.code').attr('name', 'code[' + (i + 1)+']');
                $(this).find('.product').attr('name', 'search[' + (i + 1)+']');
                $(this).find('.quantity').attr('name', 'quantity[' + (i + 1)+']');
            });

            $('#itemList >tbody >tr').each(function(index) {
                $(this).find('.slno').html(index+1);
            });
        });

        var i = 1;
        // Add button click
        $(document).on('click', '.addProduct', function(e) {
            e.preventDefault();
            var size = $('#itemList >tbody >tr').length;
            var container = $(this).closest('[data-role="dynamic-fields"]');
            var newRow = $("<tr class='parentDiv reindex'>");
            var cols = "";
            cols += '<td class="slno text-center">'+size+'</td>';
            cols += '<td><input type="hidden" data-field-name="id" id="prdid_'+i+'" name="prdid['+i+']"class="prdid" required/><input type="text" data-field-name="code" id="code_'+i+'" name="code['+i+']" placeholder="Code" class="input form-control code search" required autofocus/></td>';
            cols += '<td><input type="text" data-field-name="name" id="search_'+i+'" name="search['+i+']" placeholder="Product" class="input form-control product search" required/></td>';
            cols += '<td><input type="number" value="1" name="quantity['+i+']" class="input quantity form-control" required step=".01"></td>';
            cols += '<td class="text-end"><a href="javascript:void(0);" class="btn btn-danger remove"><span class="fa fa-trash"></span></a></td>';
            newRow.append(cols);
            container.find("tr:last").before(newRow);
            $("#code_"+i).focus();
            i = i+1;
        });
    });
</script>

<script type="text/javascript">
    function getElementId(element)
    {
        var id, idArr;
        id = element.attr('id');
        idArr = id.split("_");
        return idArr[idArr.length - 1];
    }

    var route = "{{ route('product.autocomplete') }}";
    $(document).on('focus', '.search', function(e) {
        var dataField, thisElement;
        thisElement = $(this);
        dataField = thisElement.data('field-name');
        if(typeof dataField === 'undefined')
        {
            return false;
        }
        thisElement.autocomplete({
            source: function( data, cb ) {   
                $.ajax({
                    url: route,
                    method: 'GET',
                    dataType: 'json',
                    data: {
                        name:  data.term,
                        fieldName: dataField
                    },
                    success: function(res){
                        var result;
                        result = [
                            {
                                label: 'There is no matching record found for '+data.term,
                                value: ''
                            }
                        ];

                        if (res.length)
                        {
                            result = $.map(res, function(obj){
                                
                                return {
                                    label: obj[dataField],
                                    value: obj[dataField],
                                    data : obj
                                };
                            });
                        }
                        cb(result);
                    }
                });
            },
            autoFocus: true,            
            minLength: 2,
            select: function( event, selectedData ) {
                if(selectedData && selectedData.item && selectedData.item.data)
                {
                    var rowNo, data;
                    rowNo = getElementId(thisElement);
                    data = selectedData.item.data;
                    $('#prdid_'+rowNo).val(data.id);
                    $('#code_'+rowNo).val(data.code);
                    $('#search_'+rowNo).val(data.name);
                }
            }
        });
    });

    $(document).ready(function() {
        $('tr .input:first').focus();
            
        $(document).on("keydown", '.input', function(e) {
           var n = $(".input").length;
           if (e.which == 13) 
           { //Enter key
                e.preventDefault(); //to skip default behavior of the enter key
                var nextIndex = $('.input').index(this) + 1;
                if(nextIndex < n)
                {
                    $('.input')[nextIndex].focus();
                    $('.input')[nextIndex].select();
                }
                else
                {
                    $('.input')[nextIndex-1].blur();
                    $('.addProduct').click();
                }
           }
        });
    });
</script>
@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">Stock Transfer List</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Masters</a></li>
            <li class="breadcrumb-item active" aria-current="page">Stock Transfer List</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->
<div class="p-2">
    @if(count($errors) > 0)
        <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                @foreach ($errors->all() as $error)
                    <span>{{ $error }}</span>
                @endforeach
            </div>
        </div>
    @endif
    
    @if($message = Session::get('success'))
        <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
            <div class="d-flex flex-column ps-1">
                <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
            </div>
        </div>
    @endif
</div>
<!-- Permission Table -->
<form id="purchaseForm" method="post" action="{{ route('transfer.item.store') }}">
    @csrf
    <div class="row">
        <div class="col-lg-5 col-md-12">
            <div class="card">
                <div class="card-body">
                    <div class="row">
                        <div class="col-5">
                            <label class="form-label" for="branchfrom">Branch</label>
                            <select id="branchfrom" name="branchfrom" class="form-control branch" required>
                                <option value="">--Select--</option>
                                @foreach($companysFrom as $company)
                                <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                        <div class="col-2 text-center"><label class="form-label">&nbsp;</label>To</div>
                        <div class="col-5">
                            <label class="form-label" for="branchto">Branch</label>
                            <select id="branchto" name="branchto" class="form-control branch" required>
                                <option value="">--Select--</option>
                                @foreach($companys as $company)
                                <option value="{{$company->id}}">{{$company->name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="col-lg-7 col-md-12">
            <div class="card">
                <div class="card-body">
                    <table class="table" id="itemList">
                        <thead>
                            <tr>
                                <th>#</th>
                                <th>Code</th>
                                <th>Name</th>
                                <th>Quantity</th>
                            </tr>
                        </thead>
                        <tbody data-role="dynamic-fields">
                            <tr class="parentDiv">
                                <td class="text-center">1</td>
                                <td>
                                    <input type="hidden" data-field-name="id" id="prdid_0" name="prdid[0]"class="prdid" required/>
                                    <input type="text" data-field-name="code" id="code_0" name="code[0]" placeholder="Code" class="input form-control code search" required autofocus/>
                                </td>
                                <td><input type="text" data-field-name="name" id="search_0" name="search[0]" placeholder="Product" class="input form-control product search" required/></td>
                                <td><input type="number" value="1" name="quantity[0]" class="input quantity form-control" required step=".01"></td>
                                <td class="text-end">
                                    <a href="javascript:void(0);" class="btn btn-outline-danger"><span class="fa fa-hand-o-down"></span></a>
                                </td>
                            </tr>
                            <tr id="divlast"><td></td><td colspan="4" class="text-end"><a href="javascript:void(0);" class="btn btn-primary addProduct">Add <span class="fa fa-plus"></span></a></td></tr>
                        </tbody>
                    </table>
                    <div class="col-12 text-center demo-vertical-spacing">
                        <button type="submit" id="createbtn" class="btn btn-primary me-sm-3 me-1">Create</button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</form>
<!--/ Permission Table -->
@endsection
