@extends('layouts.admin.master')
@section('title', $pageTitle)

@section('vendor-style')
    <style type="text/css">
        .dt-buttons.btn-group{ position: relative; inset-inline-start: 0px; }
    </style>
@endsection

@section('vendor-script')

<script type="text/javascript">
    var table = $('.datatables-permissions').DataTable({
       // ... skipped ...
       dom: '<"row mx-1"<"col-sm-12 col-md-3" l><"col-sm-12 col-md-9"<"dt-action-buttons text-xl-end text-lg-start text-md-end text-start d-flex align-items-center justify-content-md-end justify-content-center flex-wrap me-1"<"me-3"f>B>>>t<"row mx-2"<"col-sm-12 col-md-6"i><"col-sm-12 col-md-6"p>>',
        language: {
            sLengthMenu: "_MENU_",
            search: "Search",
            searchPlaceholder: "Search.."
        },
        buttons: [{
            text: "New {{ $pageTitle }}",
            className: "add-new btn btn-primary mb-3 mb-md-0",
            attr: {
                //"href": "{{ route('employee.create') }}",
            },
            init: function(e, a, t) {
                $(a).removeClass("btn-secondary");
                $(a).click(function(){
                    @if($type == 3)
                        window.location.href = "{{ route('transactions.receipt.list', 3) }}";
                    @elseif($type == 4)
                        window.location.href = "{{ route('transactions.payment.list', 4) }}";
                    @elseif($type == 9)
                        window.location.href = "{{ route('transactions.payment.list', 9) }}";
                    @elseif($type == 10)
                        window.location.href = "{{ route('transactions.payment.list', 10) }}";
                    @else
                        window.location.href = "{{ route('transactions.payment.list', 5) }}";
                    @endif
                });
            }
        }],
        responsive: {
            details: {
                display: $.fn.dataTable.Responsive.display.modal({
                    header: function(e) {
                        return "Details of " + e.data().name
                    }
                }),
            }
        },
    });
</script>

@endsection

@section('content')

<!-- PAGE-HEADER -->
<div class="page-header">
    <h1 class="page-title">{{ $pageTitle }}</h1>
    <div>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0)">Accounts</a></li>
            <li class="breadcrumb-item active" aria-current="page">{{ $pageTitle }}</li>
        </ol>
    </div>
</div>
<!-- PAGE-HEADER END -->

<!-- Permission Table -->
<div class="card">
    <div class="p-2">
        @if(count($errors) > 0)
            <div class="alert alert-danger d-flex" role="alert"> <span class="badge badge-center rounded-pill bg-danger border-label-danger p-3 me-2"><i class="bx bx-store fs-6"></i></span>
                <div class="d-flex flex-column ps-1">
                    <h6 class="alert-heading d-flex align-items-center fw-bold mb-1">Error!!</h6>
                    @foreach ($errors->all() as $error)
                        <span>{{ $error }}</span>
                    @endforeach
                </div>
            </div>
        @endif
        
        @if($message = Session::get('success'))
            <div class="alert alert-success d-flex align-items-center" role="alert"> <span class="badge badge-center rounded-pill bg-success border-label-success p-3 me-2"><i class="bx bx-desktop fs-6"></i></span>
                <div class="d-flex flex-column ps-1">
                    <h6 class="alert-heading d-flex align-items-center fw-bold mb-0">{{ $message }}</h6>
                </div>
            </div>
        @endif
    </div>
    <div class="card-body">
        <div class="card-datatable">
            <table class="datatables-permissions table table-bordered text-nowrap border-bottom" id="file-datatable">
                <thead>
                    <tr>
                        <th>#</th>
                        <th>No</th>
                        <th>Date</th>
                        <th>Customer</th>
                        <th>Ledger</th>
                        <th>Branch</th>
                        <th>Credit</th>
                        <th>Debit</th>
                        <th width="200">Action</th>
                    </tr>
                </thead>
                <tbody>
                    @forelse ($transactions as $transaction)
                    <tr>
                        <td>{{$loop->iteration}}</td>
                        <td class="text-left">{{ $transaction->transaction_no }}</td>
                        <td class="text-left">{{ date("d/m/Y", strtotime($transaction->transaction_date)) }}</td>
                        <td class="text-left">{{ ($transaction->customer()->exists()) ? $transaction->customer->name : '' }}</td>
                        <td class="text-left">{{ ($transaction->ledger()->exists()) ? $transaction->ledger->name : '' }}</td>
                        <td class="text-left">{{ $transaction->branch->name }}</td>
                        <td class="text-left">{{ $transaction->credit_amount }}</td>
                        <td class="text-left">{{ $transaction->debit_amount }}</td>
                        <td>
                            <div class="g-2">
                                <a class="btn text-primary btn-sm" href="{{ route('transactions.edit', $transaction->id) }}" data-bs-toggle="tooltip" data-bs-original-title="Edit"><span class="fe fe-edit fs-14"></span></a>

                                <?php /*
                                <form action="{{ route('sales.destroy', $transaction->id) }}" method="POST" onsubmit="return confirm('Are you sure?');" class="d-inline-block">
                                    @csrf
                                    @method('DELETE')
                                    <button class="btn btn-sm text-danger" type="submit" data-bs-toggle="tooltip" data-bs-original-title="Delete"><span class="fe fe-trash-2 fs-14"></span></button>
                                </form>
                                */ ?>
                                    <a class="btn text-primary btn-sm printbtn" href="{{ route('transactions.print', $transaction->id) }}" target="_blank" data-bs-toggle="tooltip" data-bs-original-title="Print"><span class="fe fe-printer fs-14"></span></a>
                            </div>
                        </td>
                    </tr>
                    @empty
                        <!--<tr>
                            <td colspan="2" class="text-center">No permissions</td>
                        </tr>-->
                    @endforelse
                </tbody>
            </table>
        </div>
    </div>
</div>
<!--/ Permission Table -->
@endsection
