<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\PermissionController;
use App\Http\Controllers\AreaController;
use App\Http\Controllers\ManufacturerController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\CompanyController;
use App\Http\Controllers\CustomerController;
use App\Http\Controllers\EmployeeController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\VendorController;
use App\Http\Controllers\PurchaseController;
use App\Http\Controllers\DriverController;
use App\Http\Controllers\VehicleController;
use App\Http\Controllers\SaleController;
use App\Http\Controllers\BillProcessController;
use App\Http\Controllers\ProductionController;
use App\Http\Controllers\StockController;
use App\Http\Controllers\TransactionController;
use App\Http\Controllers\ReportController;
use App\Http\Controllers\AccountGroupController;
use App\Http\Controllers\LedgerController;
use App\Http\Controllers\SaleQuotationController;
use App\Http\Controllers\PlaceOfSupplyController;
use App\Http\Controllers\SearchController;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});

Route::get('/dashboard', function () {
    return redirect()->route('adminDashboard');
})->middleware(['auth'])->name('dashboard');


Route::middleware('guest')->group(function () {
    // Login
    Route::get('/login', [AdminController::class, 'index'])->name('login');
    Route::get('/', [AdminController::class, 'index'])->name('welcome');
});

// Admin routes
Route::prefix('admin')->group(function () {
    // Login
    Route::get('/login', [AdminController::class, 'index'])->name('loginform');
    Route::post('/login/validate', [AdminController::class, 'login'])->name('admin.login');

    // Auth routes
    Route::group(['middleware' => ['auth', 'revalidate']], function() {
        Route::get('/dashboard', [AdminController::class, 'dashboard'])->name('adminDashboard');
        Route::controller(AdminController::class)->group(function () {

            //Change Password
            Route::get('/change-password', 'changePassword')->name('changePassword');
            Route::post('/change-password', 'changePasswordSave')->name('update-password');
            // Logout
            Route::get('/logout', 'logout')->name('admin.logout');
        });

        // Role list
        Route::resource('roles', RoleController::class);//->middleware(['permission:Manage-Roles|Create-Role|Edit-Role']);
        
        //Route::group(['middleware' => ['role:Developer']], function () {
            // Permission list
            Route::get('/permissions', [PermissionController::class, 'index'])->name('permissionList');
            Route::post('/permissions/store', [PermissionController::class, 'store'])->name('permissions.store');
        //});


            Route::get('/area', [AreaController::class, 'index'])->name('areaList');
            Route::post('area/store', [AreaController::class, 'store'])->name('area.store');
            Route::get('/area/edit/{id}', [AreaController::class, 'edit'])->name('areaEdit');
            Route::patch('area/update/{id}', [AreaController::class, 'update'])->name('area.update');
            Route::delete('area/delete/{id}', [AreaController::class, 'destroy'])->name('area.destroy');

            Route::resource('manufacturer', ManufacturerController::class)->missing(function (Request $request) {
                return Redirect::route('manufacturer.index');
            });

            Route::resource('category', CategoryController::class)->missing(function (Request $request) {
                return Redirect::route('category.index');
            });

            Route::resource('company', CompanyController::class)->missing(function (Request $request) {
                return Redirect::route('company.index');
            });

            Route::get('/customer-search', [CustomerController::class, 'customerSearch'])->name('customerSearch');
            Route::post('/customer-details', [CustomerController::class, 'customerDetails'])->name('customerDetails');
            Route::resource('customer', CustomerController::class)->missing(function (Request $request) {
                return Redirect::route('customer.index');
            });

            Route::resource('employee', EmployeeController::class)->missing(function (Request $request) {
                return Redirect::route('employee.index');
            });

            Route::get('/product/list', [ProductController::class, 'autoComplete'])->name('product.list');
            Route::get('/product/list/dashboard', [AdminController::class, 'autoComplete'])->name('product.list.dashboard');
            Route::get('/product/price/list', [ProductController::class, 'priceList'])->name('product.price.list');
            Route::post('/product/category/list', [ProductController::class, 'categoryProductList'])->name('product.category.list');
            Route::post('/product/pricelist/update', [ProductController::class, 'priceListUpdate'])->name('product.pricelist.update');
            Route::post('/product/pricelist/update/lineitem', [ProductController::class, 'priceListUpdateItem'])->name('product.pricelist.update.item');
            Route::get('/product/search', [ProductController::class, 'productSearch'])->name('productSearch');
            Route::resource('product', ProductController::class)->missing(function (Request $request) {
                return Redirect::route('product.index');
            });

            Route::get('/vendor-search', [VendorController::class, 'vendorSearch'])->name('vendorSearch');
            Route::post('/vendor-details', [VendorController::class, 'vendorDetails'])->name('vendorDetails');
            Route::resource('vendor', VendorController::class)->missing(function (Request $request) {
                return Redirect::route('vendor.index');
            });

            Route::resource('driver', DriverController::class)->missing(function (Request $request) {
                return Redirect::route('driver.index');
            });

            Route::resource('vehicle', VehicleController::class)->missing(function (Request $request) {
                return Redirect::route('vehicle.index');
            });

            // Sales Client Start

            Route::get('/view-sales/{id}', [SaleController::class, 'viewClientSale'])->name('view.client.sale');
            Route::get('/sale-client/edit/{id}', [SaleController::class, 'editClientSale'])->name('edit.client.sale');
            Route::put('/sale-client/update/{id}', [SaleController::class, 'updateClientSale'])->name('update.client.sale');
            Route::post('/sale-client/item/delete', [SaleController::class, 'saleClientItemDelete'])->name('sale.client.item.delete');
            Route::get('/sale/client', [SaleController::class, 'listClientSale'])->name('sale.client.list');
            Route::get('/counter-sales', [SaleController::class, 'counterSale'])->name('counter.sale');
            Route::put('/sale-bill/settled/{id}', [SaleController::class, 'billSettled'])->name('bill.settled.sale');
            Route::get('/sale/estimate', [SaleController::class, 'saleEstimate'])->name('sale.estimate');
            Route::get('/counter/sales/{status}', [SaleController::class, 'counterSaleStatus'])->name('counter.sale.status');

            Route::get('/list/driver/autocomplete', [SaleController::class, 'driverAutocompleteList'])->name('driver.autocomplete');
            Route::get('/list/place/autocomplete', [SaleController::class, 'placeAutocompleteList'])->name('place.autocomplete');

            // Sales Client End

            /****Sale Print Start****/

            Route::get('/print/{id}', [SaleController::class, 'salePrint'])->name('view.print.sale');
            Route::get('/thermal-print/{id}', [SaleController::class, 'saleThermalPrint'])->name('view.thermal.print.sale');
            Route::get('/print/estimate/{id}', [SaleController::class, 'estimatePrint'])->name('view.print.sale.estimate');

            /****Sale Print End****/


            // Sales Start

                Route::get('/sales/list', [SaleController::class, 'autoComplete'])->name('sales.list');

                //Return Start
                    Route::get('/sales/return/list', [SaleController::class, 'returnIndex'])->name('sales.return.index');
                    Route::get('/sales/return/create', [SaleController::class, 'returnCreate'])->name('sales.return.create');
                    Route::post('/sales/return/store', [SaleController::class, 'returnStore'])->name('sales.return.store');

                    Route::get('/sales/return/{salesReturn}/edit', [SaleController::class, 'returnEdit'])->name('sales.return.edit');
                    Route::put('/sales/return/{salesReturn}/update', [SaleController::class, 'returnUpdate'])->name('sales.return.update');
                    Route::get('/sales/return/{salesReturn}/show', [SaleController::class, 'returnShow'])->name('sales.return.show');
                    Route::post('/sales/return/item/delete', [SaleController::class, 'returnItemDelete'])->name('sales.return.item.delete');
                    Route::get('/print/return/{id}', [SaleController::class, 'saleReturnPrint'])->name('view.print.salereturn');
                //Return End

                //Estimate Start
                    Route::get('/sales/estimate/list', [SaleController::class, 'estimateIndex'])->name('sales.estimate.index');
                //Estimate End

                // Sale Item Delete
                    Route::post('/sales/item/delete', [SaleController::class, 'itemDelete'])->name('sales.item.delete');
                // Sale Item Delete
                Route::resource('sales', SaleController::class)->missing(function (Request $request) {
                    return Redirect::route('sales.index');
                });

            //Sales End

            Route::get('/bill-process', [BillProcessController::class, 'index'])->name('bill.process');
            Route::post('/bill-details', [BillProcessController::class, 'billDetails'])->name('bill.details');
            Route::post('/bill-adjust', [BillProcessController::class, 'billAdjust'])->name('bill.adjust');

            // Purchase Start

                Route::get('/purchase/list', [PurchaseController::class, 'autoComplete'])->name('purchase.list');

                Route::get('/product-search', [PurchaseController::class, 'autoCompleteSearch'])->name('product.autocomplete');
                Route::post('/approve/purchase', [PurchaseController::class, 'approvePurchase'])->name('approvepurchase');

                // Return Start
                    Route::get('/purchase/return/list', [PurchaseController::class, 'returnIndex'])->name('purchase.return.index');
                    Route::get('/purchase/return/create', [PurchaseController::class, 'returnCreate'])->name('purchase.return.create');
                    Route::post('/purchase/return/store', [PurchaseController::class, 'returnStore'])->name('purchase.return.store');

                    Route::get('/purchase/return/{purchaseReturn}/edit', [PurchaseController::class, 'returnEdit'])->name('purchase.return.edit');
                    Route::put('/purchase/return/{purchaseReturn}/update', [PurchaseController::class, 'returnUpdate'])->name('purchase.return.update');
                    Route::get('/purchase/return/{purchaseReturn}/show', [PurchaseController::class, 'returnShow'])->name('purchase.return.show');
                    Route::post('/purchase/return/item/delete', [PurchaseController::class, 'returnItemDelete'])->name('purchase.return.item.delete');
                // Return End

                // Purchase Item Delete
                    Route::post('/purchase/item/delete', [PurchaseController::class, 'itemDelete'])->name('purchase.item.delete');
                // Purchase Item Delete

                // Purchase Barcode Print
                    Route::get('/purchase/barcode/print/{id}', [PurchaseController::class, 'barcodePrint'])->name('purchase.barcode.print');
                // Purchase Barcode Print

                Route::resource('purchase', PurchaseController::class)->missing(function (Request $request) {
                    return Redirect::route('purchase.index');
                });

            // Purchase End

            //Production Start
                Route::post('/bom/item-list', [ProductionController::class, 'bomLists'])->name('bomLists');
                Route::get('/product/bom/search', [ProductionController::class, 'autoCompleteSearchBOM'])->name('product.autocomplete.bom');
                Route::post('/bom/item/delete', [ProductionController::class, 'bomItemDelete'])->name('bomItemDelete');


                Route::get('/product/production/list', [ProductionController::class, 'productionList'])->name('product.production.list');
                Route::get('/product/production/create', [ProductionController::class, 'productionCreate'])->name('product.production.create');
                Route::post('/production/item/create', [ProductionController::class, 'productionItemStore'])->name('production.item.store');
                Route::resource('production', ProductionController::class)->missing(function (Request $request) {
                    return Redirect::route('production.index');
                });
            //Production Start


            //Stock Start

                Route::get('/products/stock', [StockController::class, 'stockList'])->name('product.stock.list');
                Route::get('/products/stock/list/{id}', [StockController::class, 'branchStockList'])->name('product.stock.list.branch');
                Route::get('/products/stock/branch/list/{id}', [StockController::class, 'branchStockListTable'])->name('product.stock.list.branchTable');

                Route::get('/stock/transfer/list', [StockController::class, 'stockTransferList'])->name('stock.transfer.list');
                Route::get('/stock/transfer/show/{id}', [StockController::class, 'stockTransferShow'])->name('stock.transfer.show');

                Route::get('/stock/transfer/create', [StockController::class, 'stockTransferCreate'])->name('stock.transfer.create');
                Route::post('/stock/transfer/store', [StockController::class, 'stockTransferStore'])->name('transfer.item.store');

                Route::post('/stock/quantity/update', [StockController::class, 'stockQuantityUpdate'])->name('stock.quantity.update');
            //Stock End



            //Report Start

                Route::get('/report/sales', [ReportController::class, 'saleReport'])->name('report.sales');
                Route::post('/report/sales/list', [ReportController::class, 'saleReportList'])->name('report.sales.list');

                Route::get('/report/sales/details', [ReportController::class, 'saleDetailsReport'])->name('report.sales.details');
                Route::post('/report/sales/details/list', [ReportController::class, 'saleDetailsReportList'])->name('report.sales.list.details');

                // Tax split details

                Route::get('/report/sales/tax-split/details', [ReportController::class, 'saleTaxSplitReport'])->name('report.sales.tax.split.details');
                Route::post('/report/sales/tax-split/details/list', [ReportController::class, 'saleTaxSplitReportList'])->name('report.sales.tax.split.list.details');

                // Stock Report
                Route::get('/report/stock/details', [ReportController::class, 'stockDetailsReport'])->name('report.stock.details');
                Route::post('/report/stock/list', [ReportController::class, 'stockDetailsReportList'])->name('report.stock.list.details');

                // Sale profit report

                Route::get('/report/sales/profit', [ReportController::class, 'saleProfitReport'])->name('report.profit.sales');
                Route::post('/report/sales/profit/list', [ReportController::class, 'saleProfitReportList'])->name('report.profit.sales.list');

                // Sale profit report end

                // Sale hsn report

                Route::get('/report/sales/hsn/update', [ReportController::class, 'saleHsnUpdate'])->name('report.sales.hsn.update'); // Update HSN Code
                Route::get('/report/sales/hsn', [ReportController::class, 'saleHsnReport'])->name('report.sales.hsn');
                Route::post('/report/sales/hsn/list', [ReportController::class, 'saleHsnReportList'])->name('report.sales.hsn.list');

                // Sale hsn report end

                Route::get('/report/sales/tax', [ReportController::class, 'saleTaxReport'])->name('report.sales.tax');
                Route::post('/report/sales/tax/list', [ReportController::class, 'salesTaxReportList'])->name('report.sales.tax.list');

                // R1 Start
                    Route::get('/report/sales/tax/r1', [ReportController::class, 'saleTaxReportR1'])->name('report.sales.tax.r1');
                    Route::post('/report/sales/tax/list/r1', [ReportController::class, 'salesTaxReportListR1'])->name('report.sales.tax.r1.list');
                // R1 End

                Route::get('/report/sales/tax/client', [ReportController::class, 'clientSaleTaxReport'])->name('report.sales.tax.client');
                Route::post('/report/sales/tax/client/list', [ReportController::class, 'clientSalesTaxReportList'])->name('report.sales.tax.client.list');

                Route::get('/report/purchase/tax', [ReportController::class, 'purchaseTaxReport'])->name('report.purchase.tax');
                Route::post('/report/purchase/tax/list', [ReportController::class, 'purchaseTaxReportList'])->name('report.purchase.tax.list');

                Route::get('/report/sales/return', [ReportController::class, 'salesReturnReport'])->name('report.sales.return');
                Route::post('/report/sales/return/list', [ReportController::class, 'salesReturnReportList'])->name('report.sales.return.list');

                Route::get('/report/purchase/return', [ReportController::class, 'purchaseReturnReport'])->name('report.purchase.return');
                Route::post('/report/purchase/return/list', [ReportController::class, 'purchaseReturnReportList'])->name('report.purchase.return.list');

                Route::get('/report/sales/item-wise', [ReportController::class, 'salesItemWiseReport'])->name('report.sales.item.wise');
                Route::post('/report/sales/item-wise/list', [ReportController::class, 'salesItemWiseReportList'])->name('report.sales.item.wise.list');

                Route::get('/report/purchase/item-wise', [ReportController::class, 'purchaseItemWiseReport'])->name('report.purchase.item.wise');
                Route::post('/report/purchase/item-wise/list', [ReportController::class, 'purchaseItemWiseReportList'])->name('report.purchase.item.wise.list');

                // Search Transactions Start

                    Route::get('/report/transaction/search', [ReportController::class, 'transactionSearch'])->name('report.transaction.search');
                    Route::post('/report/transaction/search/list', [ReportController::class, 'transactionSearchResult'])->name('report.transaction.search.list');

                // Search Transactions End



            //Report End


            // Transactions Start
                Route::controller(TransactionController::class)->group(function () {
                    Route::get('/transactions/list/{type}', 'index')->name('transactions.index');
                    Route::get('/transactions/receipt/list/{type}', 'transactionReceipt')->name('transactions.receipt.list');
                    Route::get('/transactions/payment/list/{type}', 'transactionPayment')->name('transactions.payment.list');
                    Route::post('/transactions/getdue', 'calculateDueAmount')->name('transactions.calculate.due');
                    Route::post('/transactions/store', 'store')->name('transactions.store');
                    Route::get('/transactions/{transaction}/edit', 'edit')->name('transactions.edit');
                    Route::put('/transactions/{transaction}/update', 'update')->name('transactions.update');
                    Route::get('/transactions/print/{id}', 'transactionPrint')->name('transactions.print');

                    Route::get('/accounts/sundry-creditor', 'sundryCreditor')->name('transactions.accounts.creditor');
                    Route::get('/accounts/sundry-debtor', 'sundryDebtor')->name('transactions.accounts.debtor');

                    Route::get('/accounts/sundry-creditor/due-report', 'sundryCreditorDueReport')->name('transactions.accounts.creditor.duerpt');

                    Route::get('/accounts/get/sundry-creditor/{id}', 'getSundryCreditor')->name('get.sundry.creditor');

                    Route::get('/accounts/day-book', 'dayBook')->name('transactions.daybook');
                    Route::post('/accounts/day-book/search', 'searchDayBook')->name('transactions.daybook.search');
                    Route::get('/purchase-list/invoice/autocomplete', 'purchaseAutocompleteInvoice')->name('purchases.invoice.autocomplete');
                    Route::get('/sale-list/invoice/autocomplete', 'salesAutocompleteInvoice')->name('sale.invoice.autocomplete');
                });
            // Transactions End

            // Search Start
                Route::controller(SearchController::class)->group(function () {
                    Route::get('/search/accounts', 'accountSearchIndex')->name('search.accounts');
                    Route::post('/search/account/list', 'accountSearchList')->name('search.accounts.list');
                });
            // Search End

            // Account Group Start

                Route::resource('accountGroup', AccountGroupController::class)->missing(function (Request $request) {
                    return Redirect::route('accountGroup.index');
                });

            // Account Group End

            // Ledger Start
                Route::get('/accounts/ledger/transaction/search/{id}', [LedgerController::class, 'getLedger'])->name('ledger.transaction.search');
                Route::resource('ledger', LedgerController::class)->missing(function (Request $request) {
                    return Redirect::route('ledger.index');
                });

            // Ledger End

            // Sale Quot Start
                Route::controller(SaleQuotationController::class)->group(function () {
                    Route::get('/sales/quot/list/', 'index')->name('quot.index');
                    Route::get('/sales/quot/create/', 'create')->name('quot.create');
                    Route::post('/sales/quot/store', 'store')->name('quot.store');
                    Route::get('/sales/quot/{saleQuotation}/edit', 'edit')->name('quot.edit');
                    Route::put('/sales/quot/{saleQuotation}/update', 'update')->name('quot.update');
                    Route::get('/sales/quot/{saleQuotation}/invoice', 'convertInvoice')->name('quot.convert.invoice');
                    Route::get('/sales/quot/{saleQuotation}/print', 'salePrint')->name('quot.print');
                });
            // Sale Quot End

            // Place Of Supply Start
                Route::controller(PlaceOfSupplyController::class)->group(function () {
                    Route::get('/place/supply/list/', 'index')->name('place.supply.index');
                    Route::get('/place/supply/create/', 'create')->name('place.supply.create');
                    Route::post('/place/supply/store', 'store')->name('place.supply.store');
                    Route::get('/place/supply/{placeOfSupply}/edit', 'edit')->name('place.supply.edit');
                    Route::put('/place/supply/{placeOfSupply}/update', 'update')->name('place.supply.update');
                    Route::delete('/place/supply/{placeOfSupply}/destroy', 'destroy')->name('place.supply.destroy');
                });
            // Place Of Supply End


                Route::get('/backup/database', function(){
                    $exitCode = Artisan::call('database:backup');
                })->name('backup.data');





    });
    // Auth routes end
});






require __DIR__.'/auth.php';
